@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 # Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -12,20 +14,32 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_concurrency import processutils
-from trove.cmd.common import with_initialize
-from trove.common import profile
+
+import gettext
+import sys
 
 
-@with_initialize
-def main(CONF):
-    from trove.common import cfg
-    from trove.common import wsgi
+gettext.install('trove', unicode=1)
 
-    cfg.set_api_config_defaults()
-    profile.setup_profiler('api', CONF.host)
+
+from trove.common import cfg
+from trove.common import debug_utils
+from trove.openstack.common import log as logging
+from trove.common import wsgi
+from trove.db import get_db_api
+
+
+CONF = cfg.CONF
+
+
+def main():
+    cfg.parse_args(sys.argv)
+    logging.setup(None)
+
+    debug_utils.setup()
+
+    get_db_api().configure_db(CONF)
     conf_file = CONF.find_file(CONF.api_paste_config)
-    workers = CONF.trove_api_workers or processutils.get_worker_count()
-    launcher = wsgi.launch('trove', CONF.bind_port, conf_file,
-                           host=CONF.bind_host, workers=workers)
+    launcher = wsgi.launch('trove', CONF.bind_port or 8779, conf_file,
+                           workers=CONF.trove_api_workers)
     launcher.wait()
