@@ -14,15 +14,12 @@
 #    under the License.
 
 import re
-
-from oslo_log import log as logging
-from oslo_utils import strutils
 import webob.exc
+import wsgi
 
 from trove.common import exception
-from trove.common.i18n import _
-from trove.common.utils import req_to_text
-from trove.common import wsgi
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 
@@ -31,22 +28,22 @@ class AuthorizationMiddleware(wsgi.Middleware):
 
     def __init__(self, application, auth_providers, **local_config):
         self.auth_providers = auth_providers
-        LOG.debug("Auth middleware providers: %s", auth_providers)
+        LOG.debug(_("Auth middleware providers: %s") % auth_providers)
         super(AuthorizationMiddleware, self).__init__(application,
                                                       **local_config)
 
     def process_request(self, request):
         roles = request.headers.get('X_ROLE', '').split(',')
-        LOG.debug("Processing auth request with roles: %s", roles)
+        LOG.debug(_("Processing auth request with roles: %s") % roles)
         tenant_id = request.headers.get('X-Tenant-Id', None)
-        LOG.debug("Processing auth request with tenant_id: %s", tenant_id)
+        LOG.debug(_("Processing auth request with tenant_id: %s") % tenant_id)
         for provider in self.auth_providers:
             provider.authorize(request, tenant_id, roles)
 
     @classmethod
     def factory(cls, global_config, **local_config):
         def _factory(app):
-            LOG.debug("Created auth middleware with config: %s",
+            LOG.debug(_("Created auth middleware with config: %s") %
                       local_config)
             return cls(app, [TenantBasedAuth()], **local_config)
         return _factory
@@ -62,17 +59,14 @@ class TenantBasedAuth(object):
         match_for_tenant = self.tenant_scoped_url.match(request.path_info)
         if (match_for_tenant and
                 tenant_id == match_for_tenant.group('tenant_id')):
-            LOG.debug(strutils.mask_password(
-                ("Authorized tenant '%(tenant_id)s' request: "
-                 "%(request)s") %
-                {'tenant_id': tenant_id, 'request': req_to_text(request)}))
+            LOG.debug(logging.mask_password(
+                      _("Authorized tenant '%(tenant_id)s' request: "
+                        "%(request)s") %
+                      {'tenant_id': tenant_id, 'request': request}))
             return True
-
-        log_fmt = "User with tenant id %s cannot access this resource."
-        exc_fmt = _("User with tenant id %s cannot access this resource.")
-
-        LOG.error(log_fmt, tenant_id)
-        raise webob.exc.HTTPForbidden(exc_fmt % tenant_id)
+        msg = _("User with tenant id %s cannot access this resource")
+        LOG.debug(msg % tenant_id)
+        raise webob.exc.HTTPForbidden(msg)
 
 
 def admin_context(f):
