@@ -18,11 +18,12 @@
 
 import sys
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
+
+from trove.openstack.common import log
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
 CONF = cfg.CONF
 
 __debug_state = None
@@ -39,9 +40,8 @@ pydev_debug_opts = [
     cfg.StrOpt("pydev_debug_host",
                help="Pydev debug server host (localhost by default)."),
 
-    cfg.PortOpt("pydev_debug_port",
-                default=5678,
-                help="Pydev debug server port (5678 by default)."),
+    cfg.IntOpt("pydev_debug_port",
+               help="Pydev debug server port (5678 by default)."),
 
     cfg.StrOpt("pydev_path",
                help="Set path to pydevd library, used if pydevd is "
@@ -82,23 +82,6 @@ def enabled():
     """
     assert __debug_state is not None, ("debug_utils are not initialized. "
                                        "Please call setup() method first")
-
-    # if __debug_state is set and we have monkey patched
-    # eventlet.thread, issue a warning.
-    # You can't safely use eventlet.is_monkey_patched() on the
-    # threading module so you have to do this little dance.
-    # Discovered after much head scratching, see also
-    #
-    # http://stackoverflow.com/questions/32452110/
-    #     does-eventlet-do-monkey-patch-for-threading-module
-    #
-    # note multi-line URL
-    if __debug_state:
-        import threading
-        if threading.current_thread.__module__ == 'eventlet.green.threading':
-            LOG.warning(_("Enabling debugging with eventlet monkey"
-                          " patched produce unexpected behavior."))
-
     return __debug_state
 
 
@@ -117,9 +100,8 @@ def __setup_remote_pydev_debug_safe(pydev_debug_host=None,
             pydev_debug_port=pydev_debug_port,
             pydev_path=pydev_path)
     except Exception as e:
-        LOG.warning(_("Can't connect to remote debug server."
-                      " Continuing to work in standard mode."
-                      " Error: %s."), e)
+        LOG.info("Cann't connect to remote debug server. Continue working in "
+                 "standard mode. Error: %s", e)
         return False
 
 
@@ -140,11 +122,13 @@ def __setup_remote_pydev_debug(pydev_debug_host=None, pydev_debug_port=None,
         otherwise exception should be raised
     """
 
+    if pydev_debug_port is None:
+        pydev_debug_port = 5678
     try:
         import pydevd
         LOG.debug("pydevd module was imported from system path")
     except ImportError:
-        LOG.debug("Can't load pydevd module from system path. Try loading it "
+        LOG.debug("Cann't load pydevd module from system path. Try load it "
                   "from pydev_path: %s", pydev_path)
         assert pydev_path, "pydev_path is not set"
         if pydev_path not in sys.path:
