@@ -13,61 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import bisect
-import collections
-import six.moves.urllib.parse as urllib_parse
+import urllib
+import urlparse
 
 
 def url_quote(s):
     if s is None:
         return s
-    return urllib_parse.quote(str(s))
-
-
-def paginate_list(li, limit=None, marker=None, include_marker=False,
-                  key=lambda x: x):
-    """Sort the given list and return a sublist containing a page of items.
-
-    :param list li:             The list to be paginated.
-    :param int limit:           Maximum number of items to be returned.
-    :param marker:              Key of the first item to appear on the sublist.
-    :param bool include_marker: Include the marker value itself in the sublist.
-    :param lambda key:          Sorting expression.
-    :return:
-    """
-    sli = sorted(li, key=key)
-    index = [key(item) for item in sli]
-    if marker is None:
-        marker = ''
-    if include_marker:
-        pos = bisect.bisect_left(index, marker)
-    else:
-        pos = bisect.bisect(index, marker)
-
-    if limit and pos + limit < len(sli):
-        page = sli[pos:pos + limit]
-        return page, key(page[-1])
-    else:
-        return sli[pos:], None
-
-
-def paginate_object_list(li, attr_name, limit=None, marker=None,
-                         include_marker=False):
-    """Wrapper for paginate_list to handle lists of generic objects paginated
-    based on an attribute.
-    """
-    return paginate_list(li, limit=limit, marker=marker,
-                         include_marker=include_marker,
-                         key=lambda x: getattr(x, attr_name))
-
-
-def paginate_dict_list(li, key, limit=None, marker=None, include_marker=False):
-    """Wrapper for paginate_list to handle lists of dicts paginated
-    based on a key.
-    """
-    return paginate_list(li, limit=limit, marker=marker,
-                         include_marker=include_marker,
-                         key=lambda x: x[key])
+    return urllib.quote(str(s))
 
 
 class PaginatedDataView(object):
@@ -133,19 +86,17 @@ class AppUrl(object):
         # from the kwargs given. So change_query_params(foo='bar')
         # would remove from the URL any old instance of foo=something and
         # then add &foo=bar to the URL.
-        parsed_url = urllib_parse.urlparse(self.url)
+        parsed_url = urlparse.urlparse(self.url)
         # Build a dictionary out of the query parameters in the URL
-        # with an OrderedDict to preserve the order of the URL.
-        query_params = collections.OrderedDict(
-            urllib_parse.parse_qsl(parsed_url.query))
+        query_params = dict(urlparse.parse_qsl(parsed_url.query))
         # Use kwargs to change or update any values in the query dict.
         query_params.update(kwargs)
 
         # Build a new query based on the updated query dict.
-        new_query_params = urllib_parse.urlencode(query_params)
+        new_query_params = urllib.urlencode(query_params)
         return self.__class__(
             # Force HTTPS.
-            urllib_parse.ParseResult('https',
-                                     parsed_url.netloc, parsed_url.path,
-                                     parsed_url.params, new_query_params,
-                                     parsed_url.fragment).geturl())
+            urlparse.ParseResult('https',
+                                 parsed_url.netloc, parsed_url.path,
+                                 parsed_url.params, new_query_params,
+                                 parsed_url.fragment).geturl())
