@@ -14,37 +14,36 @@
 #    under the License.
 """Wsgi helper utilities for trove"""
 
+import eventlet.wsgi
 import math
+import jsonschema
+import paste.urlmap
 import re
 import time
 import traceback
 import uuid
-
-import eventlet.wsgi
-import jsonschema
-from oslo_log import log as logging
-from oslo_serialization import jsonutils
-from oslo_service import service
-from oslo_utils import encodeutils
-import paste.urlmap
 import webob
 import webob.dec
 import webob.exc
 
-from trove.common import base_wsgi
-from trove.common import cfg
 from trove.common import context as rd_context
 from trove.common import exception
-from trove.common.i18n import _
-from trove.common import pastedeploy
 from trove.common import utils
+from trove.openstack.common.gettextutils import _
+from trove.openstack.common import jsonutils
+
+from trove.openstack.common import pastedeploy
+from trove.openstack.common import service
+from trove.openstack.common import wsgi as openstack_wsgi
+from trove.openstack.common import log as logging
+from trove.common import cfg
 
 CONTEXT_KEY = 'trove.context'
-Router = base_wsgi.Router
-Debug = base_wsgi.Debug
-Middleware = base_wsgi.Middleware
-JSONDictSerializer = base_wsgi.JSONDictSerializer
-RequestDeserializer = base_wsgi.RequestDeserializer
+Router = openstack_wsgi.Router
+Debug = openstack_wsgi.Debug
+Middleware = openstack_wsgi.Middleware
+JSONDictSerializer = openstack_wsgi.JSONDictSerializer
+RequestDeserializer = openstack_wsgi.RequestDeserializer
 
 CONF = cfg.CONF
 # Raise the default from 8192 to accommodate large tokens
@@ -54,6 +53,8 @@ eventlet.patcher.monkey_patch(all=False, socket=True)
 
 LOG = logging.getLogger('trove.common.wsgi')
 
+CONF = cfg.CONF
+
 
 def versioned_urlmap(*args, **kwargs):
     urlmap = paste.urlmap.urlmap_factory(*args, **kwargs)
@@ -76,11 +77,10 @@ def launch(app_name, port, paste_config_file, data={},
         launcher.wait()
 
     """
-    LOG.debug("Trove started on %s", host)
     app = pastedeploy.paste_deploy_app(paste_config_file, app_name, data)
-    server = base_wsgi.Service(app, port, host=host,
-                               backlog=backlog, threads=threads)
-    return service.launch(CONF, server, workers, restart_method='mutate')
+    server = openstack_wsgi.Service(app, port, host=host,
+                                    backlog=backlog, threads=threads)
+    return service.launch(server, workers)
 
 
 # Note: taken from Nova
@@ -149,7 +149,7 @@ class VersionedURLMap(object):
         return app(environ, start_response)
 
 
-class Router(base_wsgi.Router):
+class Router(openstack_wsgi.Router):
     # Original router did not allow for serialization of the 404 error.
     # To fix this the _dispatch was modified to use Fault() objects.
     @staticmethod
@@ -168,7 +168,7 @@ class Router(base_wsgi.Router):
         return app
 
 
-class Request(base_wsgi.Request):
+class Request(openstack_wsgi.Request):
     @property
     def params(self):
         return utils.stringify_keys(super(Request, self).params)
@@ -197,16 +197,16 @@ class Request(base_wsgi.Request):
     @utils.cached_property
     def accept_version(self):
         accept_header = self.headers.get('ACCEPT', "")
-        accept_version_re = re.compile(r".*?application/vnd.openstack.trove"
-                                       r"(\+.+?)?;"
-                                       r"version=(?P<version_no>\d+\.?\d*)")
+        accept_version_re = re.compile(".*?application/vnd.openstack.trove"
+                                       "(\+.+?)?;"
+                                       "version=(?P<version_no>\d+\.?\d*)")
 
         match = accept_version_re.search(accept_header)
         return match.group("version_no") if match else None
 
     @utils.cached_property
     def url_version(self):
-        versioned_url_re = re.compile(r"/v(?P<version_no>\d+\.?\d*)")
+        versioned_url_re = re.compile("/v(?P<version_no>\d+\.?\d*)")
         match = versioned_url_re.search(self.path)
         return match.group("version_no") if match else None
 
@@ -229,7 +229,7 @@ class Result(object):
         return self._data
 
 
-class Resource(base_wsgi.Resource):
+class Resource(openstack_wsgi.Resource):
     def __init__(self, controller, deserializer, serializer,
                  exception_map=None):
         exception_map = exception_map or {}
@@ -267,7 +267,7 @@ class Resource(base_wsgi.Resource):
             LOG.exception(exception_uuid + ": " + str(error))
             return Fault(webob.exc.HTTPInternalServerError(
                 "Internal Server Error. Please keep this ID to help us "
-                "figure out what went wrong: (%s)." % exception_uuid,
+                "figure out what went wrong: (%s)" % exception_uuid,
                 request=request))
 
     def _get_http_error(self, error):
@@ -301,7 +301,7 @@ class Resource(base_wsgi.Resource):
             # If action_result is not a Fault then there really was a
             # serialization error which we log. Otherwise return the Fault.
             if not isinstance(action_result, Fault):
-                LOG.exception("Unserializable result detected.")
+                LOG.exception("unserializable result detected.")
                 raise
             return action_result
 
@@ -317,15 +317,6 @@ class Controller(object):
             exception.Forbidden,
             exception.SwiftAuthError,
         ],
-        webob.exc.HTTPForbidden: [
-            exception.ReplicaSourceDeleteForbidden,
-            exception.BackupTooLarge,
-            exception.ModuleAccessForbidden,
-            exception.ModuleAppliedToInstance,
-            exception.PolicyNotAuthorized,
-            exception.LogAccessForbidden,
-            exception.TroveOperationAuthError,
-        ],
         webob.exc.HTTPBadRequest: [
             exception.InvalidModelError,
             exception.BadRequest,
@@ -334,7 +325,6 @@ class Controller(object):
             exception.DatabaseAlreadyExists,
             exception.UserAlreadyExists,
             exception.LocalStorageNotSpecified,
-            exception.ModuleAlreadyExists,
         ],
         webob.exc.HTTPNotFound: [
             exception.NotFound,
@@ -343,12 +333,7 @@ class Controller(object):
             exception.UserNotFound,
             exception.DatabaseNotFound,
             exception.QuotaResourceUnknown,
-            exception.BackupFileNotFound,
-            exception.ClusterNotFound,
-            exception.DatastoreNotFound,
-            exception.SwiftNotFound,
-            exception.ModuleTypeNotFound,
-            exception.RootHistoryNotFound,
+            exception.BackupFileNotFound
         ],
         webob.exc.HTTPConflict: [
             exception.BackupNotCompleteError,
@@ -362,15 +347,11 @@ class Controller(object):
         webob.exc.HTTPServerError: [
             exception.VolumeCreationFailure,
             exception.UpdateGuestError,
-            exception.SwiftConnectionError,
         ],
         webob.exc.HTTPNotImplemented: [
             exception.VolumeNotSupported,
             exception.LocalStorageNotSupported,
-            exception.DatastoreOperationNotSupported,
-            exception.ClusterInstanceOperationNotSupported,
-            exception.ClusterDatastoreNotSupported,
-            exception.LogsNotAvailable
+            exception.DatastoreOperationNotSupported
         ],
     }
 
@@ -378,13 +359,13 @@ class Controller(object):
 
     @classmethod
     def get_schema(cls, action, body):
-        LOG.debug("Getting schema for %(name)s:%(action)s",
-                  {'name': cls.__class__.__name__, 'action': action})
+        LOG.debug("Getting schema for %s:%s" %
+                  (cls.__class__.__name__, action))
         if cls.schemas:
             matching_schema = cls.schemas.get(action, {})
             if matching_schema:
-                LOG.debug("Found Schema: %s",
-                          matching_schema.get("name", matching_schema))
+                LOG.debug("Found Schema: %s" % matching_schema.get("name",
+                                                                   "none"))
             return matching_schema
 
     @staticmethod
@@ -421,13 +402,13 @@ class Controller(object):
             self.exception_map)
 
     def _extract_limits(self, params):
-        return {key: params[key] for key in params.keys()
-                if key in ["limit", "marker"]}
+        return dict([(key, params[key]) for key in params.keys()
+                     if key in ["limit", "marker"]])
 
 
-class TroveResponseSerializer(base_wsgi.ResponseSerializer):
+class TroveResponseSerializer(openstack_wsgi.ResponseSerializer):
     def serialize_body(self, response, data, content_type, action):
-        """Overrides body serialization in base_wsgi.ResponseSerializer.
+        """Overrides body serialization in openstack_wsgi.ResponseSerializer.
 
         If the "data" argument is the Result class, its data
         method is called and *that* is passed to the superclass implementation
@@ -457,7 +438,7 @@ class Fault(webob.exc.HTTPException):
     code_wrapper = {
         400: webob.exc.HTTPBadRequest,
         401: webob.exc.HTTPUnauthorized,
-        403: webob.exc.HTTPForbidden,
+        403: webob.exc.HTTPUnauthorized,
         404: webob.exc.HTTPNotFound,
     }
 
@@ -486,8 +467,7 @@ class Fault(webob.exc.HTTPException):
         name = exc.__class__.__name__
         if name in named_exceptions:
             return named_exceptions[name]
-
-        # If the exception isn't in our list, at least strip off the
+            # If the exception isn't in our list, at least strip off the
         # HTTP from the name, and then drop the case on the first letter.
         name = name.split("HTTP").pop()
         name = name[:1].lower() + name[1:]
@@ -511,7 +491,7 @@ class Fault(webob.exc.HTTPException):
 
         content_type = req.best_match_content_type()
         serializer = {
-            'application/json': JSONDictSerializer(),
+            'application/json': openstack_wsgi.JSONDictSerializer(),
         }[content_type]
 
         self.wrapped_exc.body = serializer.serialize(fault_data, content_type)
@@ -519,24 +499,16 @@ class Fault(webob.exc.HTTPException):
         return self.wrapped_exc
 
 
-class ContextMiddleware(base_wsgi.Middleware):
+class ContextMiddleware(openstack_wsgi.Middleware):
     def __init__(self, application):
         self.admin_roles = CONF.admin_roles
         super(ContextMiddleware, self).__init__(application)
 
     def _extract_limits(self, params):
-        return {key: params[key] for key in params.keys()
-                if key in ["limit", "marker"]}
+        return dict([(key, params[key]) for key in params.keys()
+                     if key in ["limit", "marker"]])
 
     def process_request(self, request):
-        service_catalog = None
-        catalog_header = request.headers.get('X-Service-Catalog', None)
-        if catalog_header:
-            try:
-                service_catalog = jsonutils.loads(catalog_header)
-            except ValueError:
-                raise webob.exc.HTTPInternalServerError(
-                    _('Invalid service catalog json.'))
         tenant_id = request.headers.get('X-Tenant-Id', None)
         auth_token = request.headers["X-Auth-Token"]
         user_id = request.headers.get('X-User-ID', None)
@@ -548,29 +520,27 @@ class ContextMiddleware(base_wsgi.Middleware):
                 break
         limits = self._extract_limits(request.params)
         context = rd_context.TroveContext(auth_token=auth_token,
-                                          project_id=tenant_id,
-                                          user_id=user_id,
+                                          tenant=tenant_id,
+                                          user=user_id,
                                           is_admin=is_admin,
                                           limit=limits.get('limit'),
-                                          marker=limits.get('marker'),
-                                          service_catalog=service_catalog,
-                                          roles=roles)
+                                          marker=limits.get('marker'))
         request.environ[CONTEXT_KEY] = context
 
     @classmethod
     def factory(cls, global_config, **local_config):
         def _factory(app):
-            LOG.debug("Created context middleware with config: %s",
+            LOG.debug(_("Created context middleware with config: %s") %
                       local_config)
             return cls(app)
 
         return _factory
 
 
-class FaultWrapper(base_wsgi.Middleware):
+class FaultWrapper(openstack_wsgi.Middleware):
     """Calls down the middleware stack, making exceptions into faults."""
 
-    @webob.dec.wsgify(RequestClass=base_wsgi.Request)
+    @webob.dec.wsgify(RequestClass=openstack_wsgi.Request)
     def __call__(self, req):
         try:
             resp = req.get_response(self.application)
@@ -582,8 +552,7 @@ class FaultWrapper(base_wsgi.Middleware):
                 return resp
             return resp
         except Exception as ex:
-            LOG.exception("Caught error: %s.",
-                          encodeutils.exception_to_unicode(ex))
+            LOG.exception(_("Caught error: %s"), unicode(ex))
             exc = webob.exc.HTTPInternalServerError()
             return Fault(exc)
 
@@ -659,3 +628,10 @@ class DictSerializer(ActionDispatcher):
 
     def default(self, data):
         return ""
+
+
+class JSONDictSerializer(DictSerializer):
+    """Default JSON request body serialization."""
+
+    def default(self, data):
+        return jsonutils.dumps(data)
