@@ -13,7 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_utils import strutils
+from trove.openstack.common import log as logging
+
+LOG = logging.getLogger(__name__)
 
 
 class ConfigurationView(object):
@@ -26,14 +28,8 @@ class ConfigurationView(object):
             "id": self.configuration.id,
             "name": self.configuration.name,
             "description": self.configuration.description,
-            "created": self.configuration.created,
-            "updated": self.configuration.updated,
-            "datastore_version_id":
-            self.configuration.datastore_version_id,
-            "datastore_name":
-            self.configuration.datastore.name,
-            "datastore_version_name":
-            self.configuration.datastore_version.name}
+            "datastore_version_id": self.configuration.datastore_version_id,
+        }
 
         return {"configuration": configuration_dict}
 
@@ -95,50 +91,17 @@ class DetailedConfigurationView(object):
             "id": self.configuration.id,
             "name": self.configuration.name,
             "description": self.configuration.description,
-            "values": strutils.mask_dict_password(values),
-            "created": self.configuration.created,
-            "updated": self.configuration.updated,
-            "instance_count":
-            getattr(self.configuration, "instance_count", 0),
-            "datastore_name": self.configuration.datastore.name,
-            "datastore_version_id":
-            self.configuration.datastore_version_id,
-            "datastore_version_name":
-            self.configuration.datastore_version.name
+            "values": values,
+            "datastore_version_id": self.configuration.datastore_version_id,
         }
 
         return {"configuration": configuration_dict}
 
 
-class ConfigurationParameterView(object):
-
-    def __init__(self, config):
-        self.config = config
-
-    def data(self):
-        # v1 api is to be a 'true' or 'false' json boolean instead of 1/0
-        restart_required = True if self.config.restart_required else False
-        ret = {
-            "name": self.config.name,
-            "datastore_version_id": self.config.datastore_version_id,
-            "restart_required": restart_required,
-            "type": self.config.data_type,
-        }
-        if self.config.max_size:
-            ret["max"] = int(self.config.max_size)
-        if self.config.min_size:
-            ret["min"] = int(self.config.min_size)
-        return ret
-
-
 class ConfigurationParametersView(object):
 
-    def __init__(self, configs):
-        self.configs = configs
+    def __init__(self, configuration_parameters):
+        self.configuration_parameters = configuration_parameters
 
     def data(self):
-        params = []
-        for p in self.configs:
-            param = ConfigurationParameterView(p)
-            params.append(param.data())
-        return {"configuration-parameters": params}
+        return self.configuration_parameters
