@@ -13,14 +13,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from trove.common import cfg
+import optparse
+
 from trove.common import utils
+from trove.common import cfg
 
 CONF = cfg.CONF
 
+db_api_opt = CONF.db_api_implementation
+
 
 def get_db_api():
-    return utils.import_module(CONF.db_api_implementation)
+    return utils.import_module(db_api_opt)
 
 
 class Query(object):
@@ -86,3 +90,26 @@ class Queryable(object):
             model, query_func=getattr(get_db_api(), item), **conditions)
 
 db_query = Queryable()
+
+
+def add_options(parser):
+    """Adds any configuration options that the db layer might have.
+
+    :param parser: An optparse.OptionParser object
+    :retval None
+
+    """
+    help_text = ("The following configuration options are specific to the "
+                 "Trove database.")
+
+    group = optparse.OptionGroup(
+        parser,
+        "Registry Database Options",
+        help_text)
+    group.add_option(
+        '--sql-connection',
+        metavar="CONNECTION",
+        default=None,
+        help="A valid SQLAlchemy connection string for the "
+             "registry database. Default: %(default)s.")
+    parser.add_option_group(group)
