@@ -12,17 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-from oslo_utils import strutils
-
+from trove.db import get_db_api
+from trove.db import db_query
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import models
 from trove.common import pagination
-from trove.common import timeutils
 from trove.common import utils
-from trove.db import db_query
-from trove.db import get_db_api
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 
@@ -34,7 +31,7 @@ class DatabaseModelBase(models.ModelBase):
     def create(cls, **values):
         init_vals = {
             'id': utils.generate_uuid(),
-            'created': timeutils.utcnow(),
+            'created': utils.utcnow(),
         }
         if hasattr(cls, 'deleted'):
             init_vals['deleted'] = False
@@ -59,20 +56,18 @@ class DatabaseModelBase(models.ModelBase):
     def save(self):
         if not self.is_valid():
             raise exception.InvalidModelError(errors=self.errors)
-        self['updated'] = timeutils.utcnow()
-        LOG.debug("Saving %(name)s: %(dict)s",
-                  {'name': self.__class__.__name__,
-                   'dict': strutils.mask_dict_password(self.__dict__)})
+        self['updated'] = utils.utcnow()
+        LOG.debug(_("Saving %(name)s: %(dict)s") %
+                  {'name': self.__class__.__name__, 'dict': self.__dict__})
         return self.db_api.save(self)
 
     def delete(self):
-        self['updated'] = timeutils.utcnow()
-        LOG.debug("Deleting %(name)s: %(dict)s",
-                  {'name': self.__class__.__name__,
-                   'dict': strutils.mask_dict_password(self.__dict__)})
+        self['updated'] = utils.utcnow()
+        LOG.debug(_("Deleting %(name)s: %(dict)s") %
+                  {'name': self.__class__.__name__, 'dict': self.__dict__})
 
         if self.preserve_on_delete:
-            self['deleted_at'] = timeutils.utcnow()
+            self['deleted_at'] = utils.utcnow()
             self['deleted'] = True
             return self.db_api.save(self)
         else:
@@ -82,7 +77,7 @@ class DatabaseModelBase(models.ModelBase):
         for key in values:
             if hasattr(self, key):
                 setattr(self, key, values[key])
-        self['updated'] = timeutils.utcnow()
+        self['updated'] = utils.utcnow()
         return self.db_api.save(self)
 
     def __init__(self, **kwargs):
@@ -92,7 +87,7 @@ class DatabaseModelBase(models.ModelBase):
 
     def merge_attributes(self, values):
         """dict.update() behaviour."""
-        for k, v in values.items():
+        for k, v in values.iteritems():
             self[k] = v
 
     @classmethod
@@ -100,28 +95,18 @@ class DatabaseModelBase(models.ModelBase):
         model = cls.get_by(**conditions)
 
         if model is None:
-            raise exception.ModelNotFoundError(_("%(s_name)s Not Found") %
-                                               {"s_name": cls.__name__})
+            raise exception.ModelNotFoundError(_("%s Not Found") %
+                                               cls.__name__)
 
         if ((context and not context.is_admin and hasattr(model, 'tenant_id')
              and model.tenant_id != context.tenant)):
-            log_fmt = ("Tenant %(s_tenant)s tried to access "
-                       "%(s_name)s, owned by %(s_owner)s.")
-            exc_fmt = _("Tenant %(s_tenant)s tried to access "
-                        "%(s_name)s, owned by %(s_owner)s.")
-            msg_content = {
-                "s_tenant": context.tenant,
-                "s_name": cls.__name__,
-                "s_owner": model.tenant_id}
-            LOG.error(log_fmt, msg_content)
-            raise exception.ModelNotFoundError(exc_fmt % msg_content)
+            LOG.error("Tenant %s tried to access %s, owned by %s."
+                      % (context.tenant, cls.__name__, model.tenant_id))
+            raise exception.ModelNotFoundError(_("%s Not Found") %
+                                               cls.__name__)
 
         return model
 
-    @classmethod
-    def find_by_filter(cls, **kwargs):
-        return db_query.find_by_filter(cls, **cls._process_conditions(kwargs))
-
     @classmethod
     def get_by(cls, **kwargs):
         return get_db_api().find_by(cls, **cls._process_conditions(kwargs))
