@@ -14,32 +14,24 @@
 #    under the License.
 
 from sqlalchemy import MetaData
+from sqlalchemy import Table
 from sqlalchemy import orm
 from sqlalchemy.orm import exc as orm_exc
-from sqlalchemy import Table
 
 
 def map(engine, models):
     meta = MetaData()
     meta.bind = engine
-    if mapping_exists(models['instances']):
+    if mapping_exists(models['instance']):
         return
 
-    orm.mapper(models['instances'], Table('instances', meta, autoload=True))
-    orm.mapper(models['instance_faults'],
-               Table('instance_faults', meta, autoload=True))
+    orm.mapper(models['instance'], Table('instances', meta, autoload=True))
     orm.mapper(models['root_enabled_history'],
                Table('root_enabled_history', meta, autoload=True))
-    orm.mapper(models['datastores'],
+    orm.mapper(models['datastore'],
                Table('datastores', meta, autoload=True))
-    orm.mapper(models['datastore_versions'],
+    orm.mapper(models['datastore_version'],
                Table('datastore_versions', meta, autoload=True))
-    orm.mapper(models['datastore_version_metadata'],
-               Table('datastore_version_metadata', meta, autoload=True))
-    orm.mapper(models['capabilities'],
-               Table('capabilities', meta, autoload=True))
-    orm.mapper(models['capability_overrides'],
-               Table('capability_overrides', meta, autoload=True))
     orm.mapper(models['service_statuses'],
                Table('service_statuses', meta, autoload=True))
     orm.mapper(models['dns_records'],
@@ -54,11 +46,11 @@ def map(engine, models):
                Table('reservations', meta, autoload=True))
     orm.mapper(models['backups'],
                Table('backups', meta, autoload=True))
-    orm.mapper(models['security_groups'],
+    orm.mapper(models['security_group'],
                Table('security_groups', meta, autoload=True))
-    orm.mapper(models['security_group_rules'],
+    orm.mapper(models['security_group_rule'],
                Table('security_group_rules', meta, autoload=True))
-    orm.mapper(models['security_group_instance_associations'],
+    orm.mapper(models['security_group_instance_association'],
                Table('security_group_instance_associations', meta,
                      autoload=True))
     orm.mapper(models['configurations'],
@@ -67,15 +59,6 @@ def map(engine, models):
                Table('configuration_parameters', meta, autoload=True))
     orm.mapper(models['conductor_lastseen'],
                Table('conductor_lastseen', meta, autoload=True))
-    orm.mapper(models['clusters'],
-               Table('clusters', meta, autoload=True))
-    orm.mapper(models['datastore_configuration_parameters'],
-               Table('datastore_configuration_parameters', meta,
-                     autoload=True))
-    orm.mapper(models['modules'],
-               Table('modules', meta, autoload=True))
-    orm.mapper(models['instance_modules'],
-               Table('instance_modules', meta, autoload=True))
 
 
 def mapping_exists(model):
