@@ -15,7 +15,7 @@
 
 """Various conveniences used for migration scripts."""
 
-from oslo_log import log as logging
+from trove.openstack.common import log as logging
 import sqlalchemy.types
 
 
@@ -29,8 +29,7 @@ class String(sqlalchemy.types.String):
 
 class Text(sqlalchemy.types.Text):
     def __init__(self, length=None, *args, **kwargs):
-        super(Text, self).__init__(*args, **kwargs)
-        self.with_variant(sqlalchemy.types.Text(length=length), 'mysql')
+        super(Text, self).__init__(*args, length=length, **kwargs)
 
 
 class Boolean(sqlalchemy.types.Boolean):
@@ -65,13 +64,13 @@ class Float(sqlalchemy.types.Float):
 
 def create_tables(tables):
     for table in tables:
-        logger.info("creating table %(table)s", {'table': table})
+        logger.info("creating table %(table)s" % {'table': table})
         table.create()
 
 
 def drop_tables(tables):
     for table in tables:
-        logger.info("dropping table %(table)s", {'table': table})
+        logger.info("dropping table %(table)s" % {'table': table})
         table.drop()
 
 
