@@ -16,9 +16,10 @@
 from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 
-from trove.db.sqlalchemy.migrate_repo.schema import create_tables
-from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
+from trove.db.sqlalchemy.migrate_repo.schema import create_tables
+from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
+from trove.db.sqlalchemy.migrate_repo.schema import String
 
 
 meta = MetaData()
@@ -33,3 +34,8 @@ dns_records = Table(
 def upgrade(migrate_engine):
     meta.bind = migrate_engine
     create_tables([dns_records])
+
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+    drop_tables([dns_records])
