@@ -15,6 +15,7 @@
 from sqlalchemy.schema import MetaData
 
 from trove.db.sqlalchemy.migrate_repo.schema import Integer
+from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
 
 
@@ -30,5 +31,15 @@ def upgrade(migrate_engine):
                                'TYPE INTEGER USING flavor_id::integer')
     else:
         instances = Table('instances', meta, autoload=True)
-        # modify column
+        #modify column
         instances.c.flavor_id.alter(type=Integer())
+
+
+def downgrade(migrate_engine):
+    meta = MetaData()
+    meta.bind = migrate_engine
+    # int->char casts in pgsql still work fine without any USING clause,
+    #  so downgrade is not affected.
+    # modify column:
+    instances = Table('instances', meta, autoload=True)
+    instances.c.flavor_id.alter(type=String(36))
