@@ -19,6 +19,7 @@ from sqlalchemy.schema import UniqueConstraint
 
 from trove.db.sqlalchemy.migrate_repo.schema import Boolean
 from trove.db.sqlalchemy.migrate_repo.schema import create_tables
+from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
 
@@ -59,4 +60,14 @@ def upgrade(migrate_engine):
     instances.drop_column('service_type')
     # Table 'service_images' is deprecated since this version.
     # Leave it for few releases.
-    # drop_tables([service_images])
+    #drop_tables([service_images])
+
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+    drop_tables([datastores, datastore_versions])
+    instances = Table('instances', meta, autoload=True)
+    instances.drop_column('datastore_version_id')
+    service_type = Column('service_type', String(36))
+    instances.create_column(service_type)
+    instances.update().values({'service_type': 'mysql'}).execute()
