@@ -17,13 +17,12 @@ from sqlalchemy import ForeignKey
 from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 
-from trove.db.sqlalchemy.migrate_repo.schema import Boolean
 from trove.db.sqlalchemy.migrate_repo.schema import create_tables
 from trove.db.sqlalchemy.migrate_repo.schema import DateTime
+from trove.db.sqlalchemy.migrate_repo.schema import Boolean
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
 
-
 meta = MetaData()
 
 configurations = Table(
@@ -54,6 +53,13 @@ def upgrade(migrate_engine):
     meta.bind = migrate_engine
     create_tables([configurations])
     create_tables([configuration_parameters])
+
     instances = Table('instances', meta, autoload=True)
     instances.create_column(Column('configuration_id', String(36),
                                    ForeignKey("configurations.id")))
+
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+    # Not dropping the tables for concern if rollback needed would cause
+    # consumers to recreate configurations.
