@@ -15,10 +15,11 @@
 from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 
-from trove.db.sqlalchemy.migrate_repo.schema import create_tables
 from trove.db.sqlalchemy.migrate_repo.schema import Float
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
+from trove.db.sqlalchemy.migrate_repo.schema import create_tables
+from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
 
 meta = MetaData()
 
@@ -33,3 +34,8 @@ conductor_lastseen = Table(
 def upgrade(migrate_engine):
     meta.bind = migrate_engine
     create_tables([conductor_lastseen])
+
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+    drop_tables([conductor_lastseen])
