@@ -13,28 +13,46 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
+from trove.openstack.common import log as logging
 
+from trove.common.remote import create_nova_client
 from trove.instance.models import DBInstance
-
+from trove.extensions.mgmt.instances.models import MgmtInstances
 
 LOG = logging.getLogger(__name__)
 
 
-class Account(object):
-    """Shows all trove instance ids owned by an account."""
+class Server(object):
+    """Disguises the Nova account instance dict as a server object."""
 
-    def __init__(self, id, instance_ids):
+    def __init__(self, server):
+        self.id = server['id']
+        self.status = server['status']
+        self.name = server['name']
+        self.host = server.get('host') or server['hostId']
+
+    @staticmethod
+    def list_from_account_server_list(servers):
+        """Converts a list of server account dicts to this object."""
+        return [Server(server) for server in servers]
+
+
+class Account(object):
+    """Contains all instances owned by an account."""
+
+    def __init__(self, id, instances):
         self.id = id
-        self.instance_ids = instance_ids
+        self.instances = instances
 
     @staticmethod
     def load(context, id):
+        client = create_nova_client(context)
+        account = client.accounts.get_instances(id)
         db_infos = DBInstance.find_all(tenant_id=id, deleted=False)
-        instance_ids = []
-        for db_info in db_infos:
-            instance_ids.append(db_info.id)
-        return Account(id, instance_ids)
+        servers = [Server(server) for server in account.servers]
+        instances = MgmtInstances.load_status_from_existing(context, db_infos,
+                                                            servers)
+        return Account(id, instances)
 
 
 class AccountsSummary(object):
@@ -50,7 +68,7 @@ class AccountsSummary(object):
         db_infos = DBInstance.find_all(deleted=False)
         tenant_ids_for_instances = [db_info.tenant_id for db_info in db_infos]
         tenant_ids = set(tenant_ids_for_instances)
-        LOG.debug("All tenants with instances: %s", tenant_ids)
+        LOG.debug("All tenants with instances: %s" % tenant_ids)
         accounts = []
         for tenant_id in tenant_ids:
             num_instances = tenant_ids_for_instances.count(tenant_id)
