@@ -13,25 +13,26 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
 
-from trove.common.auth import admin_context
 from trove.common import wsgi
+from trove.common.auth import admin_context
 from trove.extensions.mgmt.host import models
 from trove.extensions.mgmt.host import views
 from trove.instance.service import InstanceController
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 
 
 class HostController(InstanceController):
-    """Controller for instance functionality."""
+    """Controller for instance functionality"""
 
     @admin_context
     def index(self, req, tenant_id, detailed=False):
         """Return all hosts."""
-        LOG.info("req : '%s'\n\n", req)
-        LOG.info("Indexing a host for tenant '%s'", tenant_id)
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Indexing a host for tenant '%s'") % tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
         hosts = models.SimpleHost.load_all(context)
         return wsgi.Result(views.HostsView(hosts).data(), 200)
@@ -39,9 +40,9 @@ class HostController(InstanceController):
     @admin_context
     def show(self, req, tenant_id, id):
         """Return a single host."""
-        LOG.info("req : '%s'\n\n", req)
-        LOG.info("Showing a host for tenant '%s'", tenant_id)
-        LOG.info("id : '%s'\n\n", id)
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Showing a host for tenant '%s'") % tenant_id)
+        LOG.info(_("id : '%s'\n\n") % id)
         context = req.environ[wsgi.CONTEXT_KEY]
         host = models.DetailedHost.load(context, id)
         return wsgi.Result(views.HostDetailedView(host).data(), 200)
