@@ -13,79 +13,58 @@
 #    under the License.
 import datetime
 
-from oslo_log import log as logging
-
 from trove.common import cfg
-from trove.common import clients
-from trove.common import exception
-from trove.common import timeutils
-from trove.extensions.mysql import models as mysql_models
+from trove.common import remote
+from trove.common import utils
+from trove.openstack.common import log as logging
+from trove.openstack.common.notifier import api as notifier
+from trove.instance import models as imodels
+from trove.instance.models import load_instance, InstanceServiceStatus
 from trove.instance import models as instance_models
-from trove import rpc
+from trove.extensions.mysql import models as mysql_models
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-def load_mgmt_instances(context, deleted=None, client=None,
-                        include_clustered=None, project_id=None):
+def load_mgmt_instances(context, deleted=None, client=None):
     if not client:
-        client = clients.create_nova_client(
-            context, CONF.service_credentials.region_name
-        )
-
-    search_opts = {'all_tenants': False}
-    mgmt_servers = client.servers.list(search_opts=search_opts, limit=-1)
-    LOG.info("Found %d servers in Nova",
+        client = remote.create_nova_client(context)
+    try:
+        mgmt_servers = client.rdservers.list()
+    except AttributeError:
+        mgmt_servers = client.servers.list(search_opts={'all_tenants': 1})
+    LOG.info("Found %d servers in Nova" %
              len(mgmt_servers if mgmt_servers else []))
-
-    args = {}
     if deleted is not None:
-        args['deleted'] = deleted
-    if not include_clustered:
-        args['cluster_id'] = None
-    if project_id:
-        args['tenant_id'] = project_id
-
-    db_infos = instance_models.DBInstance.find_all(**args)
-
+        db_infos = instance_models.DBInstance.find_all(deleted=deleted)
+    else:
+        db_infos = instance_models.DBInstance.find_all()
     instances = MgmtInstances.load_status_from_existing(context, db_infos,
                                                         mgmt_servers)
     return instances
 
 
-def load_mgmt_instance(cls, context, id, include_deleted):
+def load_mgmt_instance(cls, context, id):
     try:
-        instance = instance_models.load_instance(
-            cls, context, id, needs_server=True,
-            include_deleted=include_deleted)
-        client = clients.create_nova_client(
-            context, CONF.service_credentials.region_name
-        )
+        instance = load_instance(cls, context, id, needs_server=True)
+        client = remote.create_nova_client(context)
         try:
             server = client.rdservers.get(instance.server_id)
         except AttributeError:
             server = client.servers.get(instance.server_id)
-        if hasattr(server, 'host'):
-            instance.server.host = server.host
-        elif hasattr(server, 'hostId'):
-            instance.server.host = server.hostId
-        if hasattr(server, 'deleted'):
-            instance.server.deleted = server.deleted
-        if hasattr(server, 'deleted_at'):
-            instance.server.deleted_at = server.deleted_at
-        if hasattr(server, 'local_id'):
-            instance.server.local_id = server.local_id
+        instance.server.host = server.host
+        instance.server.deleted = server.deleted
+        instance.server.deleted_at = server.deleted_at
+        instance.server.local_id = server.local_id
         assert instance.server is not None
     except Exception as e:
         LOG.error(e)
-        instance = instance_models.load_instance(
-            cls, context, id, needs_server=False,
-            include_deleted=include_deleted)
+        instance = load_instance(cls, context, id, needs_server=False)
     return instance
 
 
-class SimpleMgmtInstance(instance_models.BaseInstance):
+class SimpleMgmtInstance(imodels.BaseInstance):
     def __init__(self, context, db_info, server, datastore_status):
         super(SimpleMgmtInstance, self).__init__(context, db_info, server,
                                                  datastore_status)
@@ -93,7 +72,7 @@ class SimpleMgmtInstance(instance_models.BaseInstance):
     @property
     def status(self):
         if self.deleted:
-            return instance_models.InstanceStatus.SHUTDOWN
+            return imodels.InstanceStatus.SHUTDOWN
         return super(SimpleMgmtInstance, self).status
 
     @property
@@ -105,8 +84,8 @@ class SimpleMgmtInstance(instance_models.BaseInstance):
         return self.db_info.deleted_at
 
     @classmethod
-    def load(cls, context, id, include_deleted=False):
-        return load_mgmt_instance(cls, context, id, include_deleted)
+    def load(cls, context, id):
+        return load_mgmt_instance(cls, context, id)
 
     @property
     def task_description(self):
@@ -122,9 +101,9 @@ class DetailedMgmtInstance(SimpleMgmtInstance):
         self.root_history = None
 
     @classmethod
-    def load(cls, context, id, include_deleted=False):
-        instance = load_mgmt_instance(cls, context, id, include_deleted)
-        client = clients.create_cinder_client(context)
+    def load(cls, context, id):
+        instance = load_mgmt_instance(cls, context, id)
+        client = remote.create_cinder_client(context)
         try:
             instance.volume = client.volumes.get(instance.volume_id)
         except Exception:
@@ -136,7 +115,7 @@ class DetailedMgmtInstance(SimpleMgmtInstance):
         return instance
 
 
-class MgmtInstance(instance_models.Instance):
+class MgmtInstance(imodels.Instance):
     def get_diagnostics(self):
         return self.get_guest().get_diagnostics()
 
@@ -146,21 +125,20 @@ class MgmtInstance(instance_models.Instance):
     def get_hwinfo(self):
         return self.get_guest().get_hwinfo()
 
-    def rpc_ping(self):
-        return self.get_guest().rpc_ping()
 
-
-class MgmtInstances(instance_models.Instances):
+class MgmtInstances(imodels.Instances):
     @staticmethod
     def load_status_from_existing(context, db_infos, servers):
         def load_instance(context, db, status, server=None):
             return SimpleMgmtInstance(context, db, server, status)
 
-        find_server = instance_models.create_server_list_matcher(servers)
-
-        instances = instance_models.Instances._load_servers_status(
-            load_instance, context, db_infos, find_server)
-
+        if context is None:
+            raise TypeError("Argument context not defined.")
+        find_server = imodels.create_server_list_matcher(servers)
+        instances = imodels.Instances._load_servers_status(load_instance,
+                                                           context,
+                                                           db_infos,
+                                                           find_server)
         _load_servers(instances, find_server)
         return instances
 
@@ -173,17 +151,20 @@ def _load_servers(instances, find_server):
             server = find_server(db.id, db.compute_instance_id)
             instance.server = server
         except Exception as ex:
-            LOG.warning(ex)
+            LOG.error(ex)
     return instances
 
 
 def publish_exist_events(transformer, admin_context):
-    notifier = rpc.get_notifier("taskmanager")
     notifications = transformer()
     # clear out admin_context.auth_token so it does not get logged
     admin_context.auth_token = None
     for notification in notifications:
-        notifier.info(admin_context, "trove.instance.exists", notification)
+        notifier.notify(admin_context,
+                        CONF.host,
+                        "trove.instance.exists",
+                        'INFO',
+                        notification)
 
 
 class NotificationTransformer(object):
@@ -192,11 +173,12 @@ class NotificationTransformer(object):
 
     @staticmethod
     def _get_audit_period():
-        now = timeutils.utcnow()
-        start_time = now - datetime.timedelta(
-            seconds=CONF.exists_notification_interval)
-        audit_start = timeutils.isotime(start_time)
-        audit_end = timeutils.isotime(now)
+        now = datetime.datetime.now()
+        audit_start = utils.isotime(now, subsecond=True)
+        audit_end = utils.isotime(
+            now + datetime.timedelta(
+                seconds=CONF.exists_notification_ticks * CONF.report_interval),
+            subsecond=True)
         return audit_start, audit_end
 
     def _get_service_id(self, datastore_manager, id_map):
@@ -204,8 +186,8 @@ class NotificationTransformer(object):
             datastore_manager_id = id_map[datastore_manager]
         else:
             datastore_manager_id = cfg.UNKNOWN_SERVICE_ID
-            LOG.error("Datastore ID for Manager (%s) is not configured",
-                      datastore_manager)
+            LOG.error("Datastore ID for Manager (%s) is not configured"
+                      % datastore_manager)
         return datastore_manager_id
 
     def transform_instance(self, instance, audit_start, audit_end):
@@ -233,18 +215,8 @@ class NotificationTransformer(object):
         messages = []
         db_infos = instance_models.DBInstance.find_all(deleted=False)
         for db_info in db_infos:
-            try:
-                service_status = instance_models.InstanceServiceStatus.find_by(
-                    instance_id=db_info.id)
-            except exception.ModelNotFoundError:
-                # There is a small window of opportunity during when the db
-                # resource for an instance exists, but no InstanceServiceStatus
-                # for it has yet been created. We skip sending the notification
-                # message for all such instances. These instance are too new
-                # and will get picked up the next round of notifications.
-                LOG.debug("InstanceServiceStatus not found for %s. "
-                          "Will wait to send notification.", db_info.id)
-                continue
+            service_status = InstanceServiceStatus.find_by(
+                instance_id=db_info.id)
             instance = SimpleMgmtInstance(None, db_info, None, service_status)
             message = self.transform_instance(instance, audit_start, audit_end)
             messages.append(message)
@@ -255,15 +227,15 @@ class NovaNotificationTransformer(NotificationTransformer):
     def __init__(self, **kwargs):
         super(NovaNotificationTransformer, self).__init__(**kwargs)
         self.context = kwargs['context']
-        self.nova_client = clients.create_admin_nova_client(self.context)
+        self.nova_client = remote.create_admin_nova_client(self.context)
         self._flavor_cache = {}
 
     def _lookup_flavor(self, flavor_id):
         if flavor_id in self._flavor_cache:
-            LOG.debug("Flavor cache hit for %s", flavor_id)
+            LOG.debug("Flavor cache hit for %s" % flavor_id)
             return self._flavor_cache[flavor_id]
         # fetch flavor resource from nova
-        LOG.info("Flavor cache miss for %s", flavor_id)
+        LOG.info("Flavor cache miss for %s" % flavor_id)
         flavor = self.nova_client.flavors.get(flavor_id)
         self._flavor_cache[flavor_id] = flavor.name if flavor else 'unknown'
         return self._flavor_cache[flavor_id]
