@@ -15,43 +15,40 @@
 
 
 from novaclient import exceptions as nova_exceptions
-from oslo_log import log as logging
 
 from trove.backup.models import Backup
-import trove.common.apischema as apischema
-from trove.common.auth import admin_context
 from trove.common import exception
-from trove.common.i18n import _
-from trove.common import notification
-from trove.common.notification import StartNotification
 from trove.common import wsgi
+from trove.common.auth import admin_context
+from trove.instance import models as instance_models
 from trove.extensions.mgmt.instances import models
 from trove.extensions.mgmt.instances import views
 from trove.extensions.mgmt.instances.views import DiagnosticsView
 from trove.extensions.mgmt.instances.views import HwInfoView
 from trove.extensions.mysql import models as mysql_models
-from trove.instance import models as instance_models
 from trove.instance.service import InstanceController
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+import trove.common.apischema as apischema
 
 
 LOG = logging.getLogger(__name__)
 
 
 class MgmtInstanceController(InstanceController):
-    """Controller for instance functionality."""
+    """Controller for instance functionality"""
     schemas = apischema.mgmt_instance
 
     @classmethod
     def get_action_schema(cls, body, action_schema):
-        action_type = list(body.keys())[0]
+        action_type = body.keys()[0]
         return action_schema.get(action_type, {})
 
     @admin_context
     def index(self, req, tenant_id, detailed=False):
         """Return all instances."""
-        LOG.info("Indexing a database instance for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req})
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Indexing a database instance for tenant '%s'") % tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
         deleted = None
         deleted_q = req.GET.get('deleted', '').lower()
@@ -59,13 +56,10 @@ class MgmtInstanceController(InstanceController):
             deleted = True
         elif deleted_q in ['false']:
             deleted = False
-        clustered_q = req.GET.get('include_clustered', '').lower()
-        include_clustered = clustered_q == 'true'
         try:
-            instances = models.load_mgmt_instances(
-                context, deleted=deleted, include_clustered=include_clustered)
+            instances = models.load_mgmt_instances(context, deleted=deleted)
         except nova_exceptions.ClientException as e:
-            LOG.exception(e)
+            LOG.error(e)
             return wsgi.Result(str(e), 403)
 
         view_cls = views.MgmtInstancesView
@@ -74,15 +68,12 @@ class MgmtInstanceController(InstanceController):
     @admin_context
     def show(self, req, tenant_id, id):
         """Return a single instance."""
-        LOG.info("Showing a database instance %(id)s for tenant "
-                 "'%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Showing a database instance for tenant '%s'") % tenant_id)
+        LOG.info(_("id : '%s'\n\n") % id)
+
         context = req.environ[wsgi.CONTEXT_KEY]
-        deleted_q = req.GET.get('deleted', '').lower()
-        include_deleted = deleted_q == 'true'
-        server = models.DetailedMgmtInstance.load(context, id,
-                                                  include_deleted)
+        server = models.DetailedMgmtInstance.load(context, id)
         root_history = mysql_models.RootHistory.load(context=context,
                                                      instance_id=id)
         return wsgi.Result(
@@ -94,10 +85,9 @@ class MgmtInstanceController(InstanceController):
 
     @admin_context
     def action(self, req, body, tenant_id, id):
-        LOG.info("Committing an ACTION against a database "
-                 "instance %(id)s for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
+        LOG.info("req : '%s'\n\n" % req)
+        LOG.info("Committing an ACTION against instance %s for tenant '%s'"
+                 % (id, tenant_id))
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
         context = req.environ[wsgi.CONTEXT_KEY]
@@ -106,8 +96,7 @@ class MgmtInstanceController(InstanceController):
             'stop': self._action_stop,
             'reboot': self._action_reboot,
             'migrate': self._action_migrate,
-            'reset-task-status': self._action_reset_task_status,
-            'rebuild': self._action_rebuild
+            'reset-task-status': self._action_reset_task_status
         }
         selected_action = None
         for key in body:
@@ -121,70 +110,50 @@ class MgmtInstanceController(InstanceController):
                 raise exception.BadRequest(msg)
 
         if selected_action:
-            return selected_action(context, instance, req, body)
+            return selected_action(context, instance, body)
         else:
             raise exception.BadRequest(_("Invalid request body."))
 
-    def _action_stop(self, context, instance, req, body):
-        LOG.debug("Stopping MySQL on instance %s.", instance.id)
+    def _action_stop(self, context, instance, body):
+        LOG.debug("Stopping MySQL on instance %s." % instance.id)
         instance.stop_db()
         return wsgi.Result(None, 202)
 
-    def _action_reboot(self, context, instance, req, body):
-        LOG.debug("Rebooting instance %s.", instance.id)
-
-        context.notification = notification.DBaaSInstanceReboot(
-            context,
-            request=req
-        )
-        with StartNotification(context, instance_id=instance.id):
-            instance.reboot()
-
+    def _action_reboot(self, context, instance, body):
+        LOG.debug("Rebooting instance %s." % instance.id)
+        instance.reboot()
         return wsgi.Result(None, 202)
 
-    def _action_migrate(self, context, instance, req, body):
-        LOG.debug("Migrating instance %s.", instance.id)
-        LOG.debug("body['migrate']= %s", body['migrate'])
+    def _action_migrate(self, context, instance, body):
+        LOG.debug("Migrating instance %s." % instance.id)
+        LOG.debug("body['migrate']= %s" % body['migrate'])
         host = body['migrate'].get('host', None)
-
-        context.notification = notification.DBaaSInstanceMigrate(context,
-                                                                 request=req)
-        with StartNotification(context, host=host):
-            instance.migrate(host)
+        instance.migrate(host)
         return wsgi.Result(None, 202)
 
-    def _action_reset_task_status(self, context, instance, req, body):
-        LOG.debug("Setting Task-Status to NONE on instance %s.", instance.id)
+    def _action_reset_task_status(self, context, instance, body):
+        LOG.debug("Setting Task-Status to NONE on instance %s." %
+                  instance.id)
         instance.reset_task_status()
 
-        LOG.debug("Failing backups for instance %s.", instance.id)
+        LOG.debug("Failing backups for instance %s." % instance.id)
         Backup.fail_for_instance(instance.id)
 
         return wsgi.Result(None, 202)
 
-    def _action_rebuild(self, context, instance, req, body):
-        LOG.info("Rebuild instance %s.", instance.id)
-        req_body = body['rebuild']
-        image_id = req_body['image_id']
-
-        instance.rebuild(image_id)
-        return wsgi.Result(None, 202)
-
     @admin_context
     def root(self, req, tenant_id, id):
         """Return the date and time root was enabled on an instance,
             if ever.
         """
-        LOG.info("Showing root history for a database "
-                 "instance %(id)s for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
-
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Showing root history for tenant '%s'") % tenant_id)
+        LOG.info(_("id : '%s'\n\n") % id)
         context = req.environ[wsgi.CONTEXT_KEY]
         try:
             instance_models.Instance.load(context=context, id=id)
         except exception.TroveError as e:
-            LOG.exception(e)
+            LOG.error(e)
             return wsgi.Result(str(e), 404)
         rhv = views.RootHistoryView(id)
         reh = mysql_models.RootHistory.load(context=context, instance_id=id)
@@ -196,10 +165,8 @@ class MgmtInstanceController(InstanceController):
     @admin_context
     def hwinfo(self, req, tenant_id, id):
         """Return a single instance hardware info."""
-        LOG.info("Showing hardware info for a database "
-                 "instance %(id)s for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Showing hardware info for instance '%s'") % id)
 
         context = req.environ[wsgi.CONTEXT_KEY]
         instance = models.MgmtInstance.load(context=context, id=id)
@@ -209,28 +176,13 @@ class MgmtInstanceController(InstanceController):
 
     @admin_context
     def diagnostics(self, req, tenant_id, id):
-        """Return instance diagnostics for a single instance."""
-        LOG.info("Showing diagnostic info for a database "
-                 "instance %(id)s for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
+        """Return a single instance diagnostics."""
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Showing a instance diagnostics for instance '%s'") % id)
+        LOG.info(_("id : '%s'\n\n") % id)
 
         context = req.environ[wsgi.CONTEXT_KEY]
         instance = models.MgmtInstance.load(context=context, id=id)
 
         diagnostics = instance.get_diagnostics()
         return wsgi.Result(DiagnosticsView(id, diagnostics).data(), 200)
-
-    @admin_context
-    def rpc_ping(self, req, tenant_id, id):
-        """Checks if instance is reachable via rpc."""
-        LOG.info("Sending RPC PING for a database "
-                 "instance %(id)s for tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
-
-        context = req.environ[wsgi.CONTEXT_KEY]
-        instance = models.MgmtInstance.load(context=context, id=id)
-
-        instance.rpc_ping()
-        return wsgi.Result(None, 204)
