@@ -13,39 +13,32 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-
-from trove.common.auth import admin_context
-from trove.common import exception
-from trove.common.i18n import _
 from trove.common import wsgi
+from trove.common import exception
+from trove.common.auth import admin_context
 from trove.extensions.mgmt.quota import views
-from trove.quota.models import Quota
+from trove.openstack.common import log as logging
 from trove.quota.quota import QUOTAS as quota_engine
+from trove.quota.models import Quota
 
 LOG = logging.getLogger(__name__)
 
 
 class QuotaController(wsgi.Controller):
-    """Controller for quota functionality."""
+    """Controller for quota  functionality"""
 
     @admin_context
     def show(self, req, tenant_id, id):
         """Return all quotas for this tenant."""
-        LOG.info("Indexing quota info for tenant '%(id)s'\n"
-                 "req : '%(req)s'\n\n", {"id": id, "req": req})
-
-        usages = quota_engine.get_all_quota_usages_by_tenant(id)
-        limits = quota_engine.get_all_quotas_by_tenant(id)
-        for key in usages.keys():
-            setattr(usages[key], "limit", limits[key].hard_limit)
-        return wsgi.Result(views.QuotaUsageView(usages).data(), 200)
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Indexing quota info for tenant '%s'") % id)
+        quotas = quota_engine.get_all_quotas_by_tenant(id)
+        return wsgi.Result(views.QuotaView(quotas).data(), 200)
 
     @admin_context
     def update(self, req, body, tenant_id, id):
-        LOG.info("Updating quota limits for tenant '%(id)s'\n"
-                 "req : '%(req)s'\n\n", {"id": id, "req": req})
-
+        LOG.info("req : '%s'\n\n" % req)
+        LOG.info("Updating quota limits for tenant '%s'" % id)
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
 
@@ -55,9 +48,6 @@ class QuotaController(wsgi.Controller):
         for resource, limit in body['quotas'].items():
             if limit is None:
                 continue
-            elif limit < -1:
-                raise exception.QuotaLimitTooSmall(limit=limit,
-                                                   resource=resource)
             if resource == "xmlns":
                 continue
             if resource not in registered_resources:
