@@ -17,7 +17,7 @@
 Model classes that extend the instances functionality for volumes.
 """
 
-from oslo_log import log as logging
+from trove.openstack.common import log as logging
 
 from trove.common.remote import create_cinder_client
 
@@ -41,8 +41,8 @@ class StorageDevice(object):
 class StorageDevices(object):
 
     @staticmethod
-    def load(context, region_name):
-        client = create_cinder_client(context, region_name)
+    def load(context):
+        client = create_cinder_client(context)
         rdstorages = client.rdstorage.list()
         for rdstorage in rdstorages:
             LOG.debug("rdstorage=" + str(rdstorage))
