@@ -13,11 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from trove.openstack.common import log as logging
+
 from trove.common import extensions
 from trove.extensions.account import service
 
 
-class Account(extensions.ExtensionDescriptor):
+LOG = logging.getLogger(__name__)
+
+
+class Account(extensions.ExtensionsDescriptor):
 
     def get_name(self):
         return "Account"
