@@ -13,16 +13,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from trove.openstack.common import log as logging
+
 from trove.common import extensions
-from trove.extensions.mgmt.clusters.service import MgmtClusterController
-from trove.extensions.mgmt.configuration import service as conf_service
-from trove.extensions.mgmt.datastores.service import DatastoreVersionController
 from trove.extensions.mgmt.instances.service import MgmtInstanceController
+from trove.extensions.mgmt.host.service import HostController
 from trove.extensions.mgmt.quota.service import QuotaController
-from trove.extensions.mgmt.upgrade.service import UpgradeController
+from trove.extensions.mgmt.host.instance import service as hostservice
+from trove.extensions.mgmt.volume.service import StorageController
 
 
-class Mgmt(extensions.ExtensionDescriptor):
+LOG = logging.getLogger(__name__)
+
+
+class Mgmt(extensions.ExtensionsDescriptor):
 
     def get_name(self):
         return "Mgmt"
@@ -41,22 +45,20 @@ class Mgmt(extensions.ExtensionDescriptor):
 
     def get_resources(self):
         resources = []
-
         instances = extensions.ResourceExtension(
             '{tenant_id}/mgmt/instances',
             MgmtInstanceController(),
             member_actions={'root': 'GET',
                             'diagnostics': 'GET',
                             'hwinfo': 'GET',
-                            'rpc_ping': 'GET',
                             'action': 'POST'})
         resources.append(instances)
 
-        clusters = extensions.ResourceExtension(
-            '{tenant_id}/mgmt/clusters',
-            MgmtClusterController(),
-            member_actions={'action': 'POST'})
-        resources.append(clusters)
+        hosts = extensions.ResourceExtension(
+            '{tenant_id}/mgmt/hosts',
+            HostController(),
+            member_actions={})
+        resources.append(hosts)
 
         quota = extensions.ResourceExtension(
             '{tenant_id}/mgmt/quotas',
@@ -64,22 +66,18 @@ class Mgmt(extensions.ExtensionDescriptor):
             member_actions={})
         resources.append(quota)
 
-        upgrade = extensions.ResourceExtension(
-            '{tenant_id}/mgmt/instances/{instance_id}/upgrade',
-            UpgradeController(),
+        storage = extensions.ResourceExtension(
+            '{tenant_id}/mgmt/storage',
+            StorageController(),
             member_actions={})
-        resources.append(upgrade)
+        resources.append(storage)
 
-        datastore_configuration_parameters = extensions.ResourceExtension(
-            '{tenant_id}/mgmt/datastores/versions/{version_id}/parameters',
-            conf_service.ConfigurationsParameterController(),
-            member_actions={})
-        resources.append(datastore_configuration_parameters)
-
-        datastore_version = extensions.ResourceExtension(
-            '{tenant_id}/mgmt/datastore-versions',
-            DatastoreVersionController(),
-            member_actions={})
-        resources.append(datastore_version)
+        host_instances = extensions.ResourceExtension(
+            'instances',
+            hostservice.HostInstanceController(),
+            parent={'member_name': 'host',
+                    'collection_name': '{tenant_id}/mgmt/hosts'},
+            collection_actions={'action': 'POST'})
+        resources.append(host_instances)
 
         return resources
