@@ -13,16 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
+from trove.openstack.common import log as logging
 
 from trove.common import extensions
-from trove.extensions.common import service as common_service
-from trove.extensions.mysql import service as mysql_service
+from trove.extensions.mysql import service
+
 
 LOG = logging.getLogger(__name__)
 
 
-class Mysql(extensions.ExtensionDescriptor):
+class Mysql(extensions.ExtensionsDescriptor):
 
     def get_name(self):
         return "Mysql"
@@ -44,14 +44,14 @@ class Mysql(extensions.ExtensionDescriptor):
 
         resource = extensions.ResourceExtension(
             'databases',
-            mysql_service.SchemaController(),
+            service.SchemaController(),
             parent={'member_name': 'instance',
                     'collection_name': '{tenant_id}/instances'})
         resources.append(resource)
 
         resource = extensions.ResourceExtension(
             'users',
-            mysql_service.UserController(),
+            service.UserController(),
             parent={'member_name': 'instance',
                     'collection_name': '{tenant_id}/instances'},
             member_actions={'update': 'PUT'},
@@ -61,7 +61,7 @@ class Mysql(extensions.ExtensionDescriptor):
         collection_url = '{tenant_id}/instances/:instance_id/users'
         resource = extensions.ResourceExtension(
             'databases',
-            mysql_service.UserAccessController(),
+            service.UserAccessController(),
             parent={'member_name': 'user',
                     'collection_name': collection_url},
             collection_actions={'update': 'PUT'})
@@ -69,17 +69,9 @@ class Mysql(extensions.ExtensionDescriptor):
 
         resource = extensions.ResourceExtension(
             'root',
-            common_service.RootController(),
+            service.RootController(),
             parent={'member_name': 'instance',
-                    'collection_name': '{tenant_id}/instances'},
-            collection_actions={'delete': 'DELETE'})
-        resources.append(resource)
-
-        resource = extensions.ResourceExtension(
-            'root',
-            common_service.RootController(),
-            parent={'member_name': 'instance',
-                    'collection_name': '{tenant_id}/clusters'})
+                    'collection_name': '{tenant_id}/instances'})
         resources.append(resource)
 
         return resources
