@@ -17,14 +17,15 @@
 """
 Model classes for Security Groups and Security Group Rules on instances.
 """
-from oslo_log import log as logging
-
+import trove.common.remote
 from trove.common import cfg
 from trove.common import exception
-from trove.common.i18n import _
-from trove.common.models import NetworkRemoteModelBase
 from trove.db.models import DatabaseModelBase
+from trove.common.models import NovaRemoteModelBase
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
+from novaclient import exceptions as nova_exceptions
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -32,17 +33,16 @@ LOG = logging.getLogger(__name__)
 
 def persisted_models():
     return {
-        'security_groups': SecurityGroup,
-        'security_group_rules': SecurityGroupRule,
-        'security_group_instance_associations':
+        'security_group': SecurityGroup,
+        'security_group_rule': SecurityGroupRule,
+        'security_group_instance_association':
         SecurityGroupInstanceAssociation,
     }
 
 
 class SecurityGroup(DatabaseModelBase):
-    _data_fields = ['name', 'description', 'user', 'tenant_id',
+    _data_fields = ['id', 'name', 'description', 'user', 'tenant_id',
                     'created', 'updated', 'deleted', 'deleted_at']
-    _table_name = 'security_groups'
 
     @property
     def instance_id(self):
@@ -50,14 +50,15 @@ class SecurityGroup(DatabaseModelBase):
             .get_instance_id_by_security_group_id(self.id)
 
     @classmethod
-    def create_sec_group(cls, name, description, context, region_name):
+    def create_sec_group(cls, name, description, context):
         try:
-            remote_sec_group = RemoteSecurityGroup.create(
-                name, description, context, region_name)
+            remote_sec_group = RemoteSecurityGroup.create(name,
+                                                          description,
+                                                          context)
 
             if not remote_sec_group:
                 raise exception.SecurityGroupCreationError(
-                    _("Failed to create Security Group."))
+                    "Failed to create Security Group")
             else:
                 return cls.create(
                     id=remote_sec_group.data()['id'],
@@ -66,17 +67,16 @@ class SecurityGroup(DatabaseModelBase):
                     user=context.user,
                     tenant_id=context.tenant)
 
-        except exception.SecurityGroupCreationError:
-            LOG.exception("Failed to create remote security group.")
-            raise
+        except exception.SecurityGroupCreationError as e:
+            LOG.exception("Failed to create remote security group")
+            raise e
 
     @classmethod
-    def create_for_instance(cls, instance_id, context, region_name):
+    def create_for_instance(cls, instance_id, context):
         # Create a new security group
         name = "%s_%s" % (CONF.trove_security_group_name_prefix, instance_id)
         description = _("Security Group for %s") % instance_id
-        sec_group = cls.create_sec_group(name, description, context,
-                                         region_name)
+        sec_group = cls.create_sec_group(name, description, context)
 
         # Currently this locked down by default, since we don't create any
         # default security group rules for the security group.
@@ -89,7 +89,7 @@ class SecurityGroup(DatabaseModelBase):
         return sec_group
 
     @classmethod
-    def get_security_group_by_id_or_instance_id(cls, id, tenant_id):
+    def get_security_group_by_id_or_instance_id(self, id, tenant_id):
         try:
             return SecurityGroup.find_by(id=id,
                                          tenant_id=tenant_id,
@@ -102,22 +102,22 @@ class SecurityGroup(DatabaseModelBase):
         return SecurityGroupRule.find_all(group_id=self.id,
                                           deleted=False)
 
-    def delete(self, context, region_name):
+    def delete(self, context):
         try:
             sec_group_rules = self.get_rules()
             if sec_group_rules:
                 for rule in sec_group_rules:
-                    rule.delete(context, region_name)
+                    rule.delete(context)
 
-            RemoteSecurityGroup.delete(self.id, context, region_name)
+            RemoteSecurityGroup.delete(self.id, context)
             super(SecurityGroup, self).delete()
 
         except exception.TroveError:
-            LOG.exception('Failed to delete security group.')
+            LOG.exception('Failed to delete security group')
             raise exception.TroveError("Failed to delete Security Group")
 
     @classmethod
-    def delete_for_instance(cls, instance_id, context, region_name):
+    def delete_for_instance(cls, instance_id, context):
         try:
             association = SecurityGroupInstanceAssociation.find_by(
                 instance_id=instance_id,
@@ -125,24 +125,23 @@ class SecurityGroup(DatabaseModelBase):
             if association:
                 sec_group = association.get_security_group()
                 if sec_group:
-                    sec_group.delete(context, region_name)
+                    sec_group.delete(context)
                 association.delete()
         except (exception.ModelNotFoundError,
                 exception.TroveError):
-            LOG.info('Security Group with id: %(id)s '
-                     'already had been deleted',
-                     {'id': instance_id})
+            LOG.info(_('Security Group with id: %(id)s '
+                       'already had been deleted')
+                     % {'id': instance_id})
 
 
 class SecurityGroupRule(DatabaseModelBase):
-    _data_fields = ['group_id', 'parent_group_id', 'protocol',
-                    'from_port', 'to_port', 'cidr', 'created',
-                    'updated', 'deleted', 'deleted_at']
-    _table_name = 'security_group_rules'
+    _data_fields = ['id', 'parent_group_id', 'protocol', 'from_port',
+                    'to_port', 'cidr', 'group_id', 'created', 'updated',
+                    'deleted', 'deleted_at']
 
     @classmethod
     def create_sec_group_rule(cls, sec_group, protocol, from_port,
-                              to_port, cidr, context, region_name):
+                              to_port, cidr, context):
         try:
             remote_rule_id = RemoteSecurityGroup.add_rule(
                 sec_group_id=sec_group['id'],
@@ -150,12 +149,11 @@ class SecurityGroupRule(DatabaseModelBase):
                 from_port=from_port,
                 to_port=to_port,
                 cidr=cidr,
-                context=context,
-                region_name=region_name)
+                context=context)
 
             if not remote_rule_id:
                 raise exception.SecurityGroupRuleCreationError(
-                    "Failed to create Remote Security Group Rule")
+                    "Failed to create Security Group Rule")
             else:
                 # Create db record
                 return cls.create(
@@ -166,30 +164,29 @@ class SecurityGroupRule(DatabaseModelBase):
                     cidr=cidr,
                     group_id=sec_group['id'])
 
-        except exception.SecurityGroupRuleCreationError:
-            LOG.exception("Failed to create remote security group rule.")
-            raise
+        except exception.SecurityGroupRuleCreationError as e:
+            LOG.exception("Failed to create remote security group")
+            raise e
 
     def get_security_group(self, tenant_id):
         return SecurityGroup.find_by(id=self.group_id,
                                      tenant_id=tenant_id,
                                      deleted=False)
 
-    def delete(self, context, region_name):
+    def delete(self, context):
         try:
             # Delete Remote Security Group Rule
-            RemoteSecurityGroup.delete_rule(self.id, context, region_name)
+            RemoteSecurityGroup.delete_rule(self.id, context)
             super(SecurityGroupRule, self).delete()
         except exception.TroveError:
-            LOG.exception('Failed to delete remote security group rule.')
+            LOG.exception('Failed to delete security group')
             raise exception.SecurityGroupRuleDeletionError(
-                "Failed to delete Remote Security Group Rule")
+                "Failed to delete Security Group")
 
 
 class SecurityGroupInstanceAssociation(DatabaseModelBase):
-    _data_fields = ['security_group_id', 'instance_id', 'created',
-                    'updated', 'deleted', 'deleted_at']
-    _table_name = 'security_group_instance_associations'
+    _data_fields = ['id', 'security_group_id', 'instance_id',
+                    'created', 'updated', 'deleted', 'deleted_at']
 
     def get_security_group(self):
         return SecurityGroup.find_by(id=self.security_group_id,
@@ -210,48 +207,74 @@ class SecurityGroupInstanceAssociation(DatabaseModelBase):
         return association.instance_id
 
 
-class RemoteSecurityGroup(NetworkRemoteModelBase):
+class RemoteSecurityGroup(NovaRemoteModelBase):
 
     _data_fields = ['id', 'name', 'description', 'rules']
 
-    def __init__(self, security_group=None, id=None, context=None,
-                 region_name=None):
+    def __init__(self, security_group=None, id=None, context=None):
         if id is None and security_group is None:
-            msg = _("Security Group does not have id defined!")
+            msg = "Security Group does not have id defined!"
             raise exception.InvalidModelError(msg)
         elif security_group is None:
-            driver = self.get_driver(context,
-                                     region_name or CONF.os_region_name)
-            self._data_object = driver.get_sec_group_by_id(group_id=id)
+            try:
+                client = trove.common.remote.create_nova_client(context)
+                self._data_object = client.security_groups.get(id)
+            except nova_exceptions.NotFound as e:
+                raise exception.NotFound(id=id)
+            except nova_exceptions.ClientException as e:
+                raise exception.TroveError(str(e))
         else:
             self._data_object = security_group
 
     @classmethod
-    def create(cls, name, description, context, region_name):
-        """Creates a new Security Group."""
-        driver = cls.get_driver(context, region_name)
-        sec_group = driver.create_security_group(
-            name=name, description=description)
+    def create(cls, name, description, context):
+        """Creates a new Security Group"""
+        client = trove.common.remote.create_nova_client(context)
+        try:
+            sec_group = client.security_groups.create(name=name,
+                                                      description=description)
+        except nova_exceptions.ClientException as e:
+            LOG.exception('Failed to create remote security group')
+            raise exception.SecurityGroupCreationError(str(e))
+
         return RemoteSecurityGroup(security_group=sec_group)
 
     @classmethod
-    def delete(cls, sec_group_id, context, region_name):
-        """Deletes a Security Group."""
-        driver = cls.get_driver(context, region_name)
-        driver.delete_security_group(sec_group_id)
+    def delete(cls, sec_group_id, context):
+        client = trove.common.remote.create_nova_client(context)
+
+        try:
+            client.security_groups.delete(sec_group_id)
+        except nova_exceptions.ClientException as e:
+            LOG.exception('Failed to delete remote security group')
+            raise exception.SecurityGroupDeletionError(str(e))
 
     @classmethod
     def add_rule(cls, sec_group_id, protocol, from_port,
-                 to_port, cidr, context, region_name):
-        """Adds a new rule to an existing security group."""
-        driver = cls.get_driver(context, region_name)
-        sec_group_rule = driver.add_security_group_rule(
-            sec_group_id, protocol, from_port, to_port, cidr)
+                 to_port, cidr, context):
 
-        return sec_group_rule.id
+        client = trove.common.remote.create_nova_client(context)
+
+        try:
+            sec_group_rule = client.security_group_rules.create(
+                parent_group_id=sec_group_id,
+                ip_protocol=protocol,
+                from_port=from_port,
+                to_port=to_port,
+                cidr=cidr)
+
+            return sec_group_rule.id
+        except nova_exceptions.ClientException as e:
+            LOG.exception('Failed to add rule to remote security group')
+            raise exception.SecurityGroupRuleCreationError(str(e))
 
     @classmethod
-    def delete_rule(cls, sec_group_rule_id, context, region_name):
-        """Deletes a rule from an existing security group."""
-        driver = cls.get_driver(context, region_name)
-        driver.delete_security_group_rule(sec_group_rule_id)
+    def delete_rule(cls, sec_group_rule_id, context):
+        client = trove.common.remote.create_nova_client(context)
+
+        try:
+            client.security_group_rules.delete(sec_group_rule_id)
+
+        except nova_exceptions.ClientException as e:
+            LOG.exception('Failed to delete rule to remote security group')
+            raise exception.SecurityGroupRuleDeletionError(str(e))
