@@ -13,33 +13,33 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-
-from oslo_log import log as logging
-
 from trove.common import cfg
 from trove.common import exception
 from trove.common import wsgi
+from trove.common import utils
 from trove.datastore.models import DatastoreVersion
 from trove.extensions.security_group import models
 from trove.extensions.security_group import views
 from trove.instance import models as instance_models
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
 class SecurityGroupController(wsgi.Controller):
-    """Controller for security groups functionality."""
+    """Controller for security groups functionality"""
 
     def index(self, req, tenant_id):
         """Return all security groups tied to a particular tenant_id."""
-        LOG.debug("Index() called with %s", tenant_id)
+        LOG.debug("Index() called with %s" % (tenant_id))
 
         sec_groups = models.SecurityGroup().find_all(tenant_id=tenant_id,
                                                      deleted=False)
 
         # Construct the mapping from Security Groups to Security Group Rules
-        rules_map = {g.id: g.get_rules() for g in sec_groups}
+        rules_map = dict([(g.id, g.get_rules()) for g in sec_groups])
 
         return wsgi.Result(
             views.SecurityGroupsView(sec_groups,
@@ -48,8 +48,7 @@ class SecurityGroupController(wsgi.Controller):
 
     def show(self, req, tenant_id, id):
         """Return a single security group."""
-        LOG.debug("Show() called with %(tenant_id)s, %(id)s",
-                  {'tenant_id': tenant_id, 'id': id})
+        LOG.debug("Show() called with %s, %s" % (tenant_id, id))
 
         sec_group = \
             models.SecurityGroup.get_security_group_by_id_or_instance_id(
@@ -62,27 +61,25 @@ class SecurityGroupController(wsgi.Controller):
 
 
 class SecurityGroupRuleController(wsgi.Controller):
-    """Controller for security group rule functionality."""
+    """Controller for security group rule functionality"""
 
     def delete(self, req, tenant_id, id):
-        LOG.debug("Delete Security Group Rule called %(tenant_id)s, %(id)s",
-                  {'tenant_id': tenant_id, 'id': id})
+        LOG.debug("Delete Security Group Rule called %s, %s" % (tenant_id, id))
 
         context = req.environ[wsgi.CONTEXT_KEY]
         sec_group_rule = models.SecurityGroupRule.find_by(id=id, deleted=False)
         sec_group = sec_group_rule.get_security_group(tenant_id)
 
         if sec_group is None:
-            LOG.error("Attempting to delete Group Rule that does not "
-                      "exist or does not belong to tenant %s", tenant_id)
+            LOG.error("Attempting to delete Group Rule that does not exist or "
+                      "does not belong to tenant %s" % tenant_id)
             raise exception.Forbidden("Unauthorized")
 
-        sec_group_rule.delete(context, CONF.os_region_name)
-        sec_group.save()
+        sec_group_rule.delete(context)
         return wsgi.Result(None, 204)
 
     def create(self, req, body, tenant_id):
-        LOG.debug("Creating a Security Group Rule for tenant '%s'", tenant_id)
+        LOG.debug("Creating a Security Group Rule for tenant '%s'" % tenant_id)
 
         context = req.environ[wsgi.CONTEXT_KEY]
         self._validate_create_body(body)
@@ -103,22 +100,20 @@ class SecurityGroupRuleController(wsgi.Controller):
             rules = []
             try:
                 for port_or_range in set(ports):
-                    from_, to_ = port_or_range[0], port_or_range[-1]
+                    from_, to_ = utils.gen_ports(port_or_range)
                     rule = models.SecurityGroupRule.create_sec_group_rule(
-                        sec_group, protocol, from_, to_,
-                        body['security_group_rule']['cidr'], context,
-                        CONF.os_region_name)
+                        sec_group, protocol, int(from_), int(to_),
+                        body['security_group_rule']['cidr'], context)
                     rules.append(rule)
             except (ValueError, AttributeError) as e:
-                raise exception.BadRequest(message=str(e))
+                raise exception.BadRequest(msg=str(e))
             return rules
 
         tcp_rules = _create_rules(sec_group, tcp_ports, 'tcp')
         udp_rules = _create_rules(sec_group, udp_ports, 'udp')
 
-        sec_group.save()
-
         all_rules = tcp_rules + udp_rules
+
         view = views.SecurityGroupRulesView(
             all_rules, req, tenant_id).create()
         return wsgi.Result(view, 201)
@@ -129,8 +124,8 @@ class SecurityGroupRuleController(wsgi.Controller):
             body['security_group_rule']['group_id']
             body['security_group_rule']['cidr']
         except KeyError as e:
-            LOG.error("Create Security Group Rules Required field(s) "
-                      "- %s", e)
+            LOG.error(_("Create Security Group Rules Required field(s) "
+                        "- %s") % e)
             raise exception.SecurityGroupRuleCreationError(
                 "Required element/key - %s was not specified" % e)
 
