@@ -14,8 +14,8 @@
 #    under the License.
 
 
-from trove.common import cfg
 from trove.common.views import create_links
+from trove.common import cfg
 
 CONF = cfg.CONF
 
@@ -28,23 +28,11 @@ class FlavorView(object):
 
     def data(self):
 
-        # If the flavor id is not an int, we simply return
-        # no id and rely on str_id instead.
-        if isinstance(self.flavor.id, int) or (
-                self.flavor.id.isdigit() and
-                not self.flavor.id.startswith('0')):
-            f_id = int(self.flavor.id)
-        else:
-            f_id = None
-
         flavor = {
-            'id': f_id,
+            'id': int(self.flavor.id),
             'links': self._build_links(),
             'name': self.flavor.name,
             'ram': self.flavor.ram,
-            'vcpus': self.flavor.vcpus,
-            'disk': self.flavor.disk,
-            'str_id': str(self.flavor.id),
         }
 
         if not CONF.trove_volume_support and CONF.device_path is not None:
