@@ -23,42 +23,21 @@ handles RPC calls relating to Platform specific operations.
 
 """
 
-from itertools import chain
 import os
 
-from oslo_log import log as logging
-
+from trove.openstack.common import log
+from itertools import chain
 from trove.common import cfg
-from trove.common.i18n import _
-from trove.common import utils
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
 defaults = {
-    'mysql':
-    'trove.guestagent.datastore.mysql.manager.Manager',
-    'percona':
-    'trove.guestagent.datastore.experimental.percona.manager.Manager',
-    'pxc':
-    'trove.guestagent.datastore.experimental.pxc.manager.Manager',
-    'redis':
-    'trove.guestagent.datastore.experimental.redis.manager.Manager',
-    'cassandra':
-    'trove.guestagent.datastore.experimental.cassandra.manager.Manager',
-    'couchbase':
-    'trove.guestagent.datastore.experimental.couchbase.manager.Manager',
-    'mongodb':
-    'trove.guestagent.datastore.experimental.mongodb.manager.Manager',
-    'postgresql':
-    'trove.guestagent.datastore.experimental.postgresql.manager.Manager',
-    'couchdb':
-    'trove.guestagent.datastore.experimental.couchdb.manager.Manager',
-    'vertica':
-    'trove.guestagent.datastore.experimental.vertica.manager.Manager',
-    'db2':
-    'trove.guestagent.datastore.experimental.db2.manager.Manager',
-    'mariadb':
-    'trove.guestagent.datastore.experimental.mariadb.manager.Manager'
+    'mysql': 'trove.guestagent.datastore.mysql.manager.Manager',
+    'percona': 'trove.guestagent.datastore.mysql.manager.Manager',
+    'redis': 'trove.guestagent.datastore.redis.manager.Manager',
+    'cassandra': 'trove.guestagent.datastore.cassandra.manager.Manager',
+    'couchbase': 'trove.guestagent.datastore.couchbase.manager.Manager',
+    'mongodb': 'trove.guestagent.datastore.mongodb.manager.Manager',
 }
 CONF = cfg.CONF
 
@@ -68,8 +47,15 @@ def get_custom_managers():
 
 
 def datastore_registry():
-    return dict(chain(defaults.items(),
-                get_custom_managers().items()))
+    return dict(chain(defaults.iteritems(),
+                get_custom_managers().iteritems()))
+
+
+def to_gb(bytes):
+    if bytes == 0:
+        return 0.0
+    size = bytes / 1024.0 ** 3
+    return round(size, 2)
 
 
 def get_filesystem_volume_stats(fs_path):
@@ -77,13 +63,13 @@ def get_filesystem_volume_stats(fs_path):
         stats = os.statvfs(fs_path)
     except OSError:
         LOG.exception("Error getting volume stats.")
-        raise RuntimeError(_("Filesystem not found (%s)") % fs_path)
+        raise RuntimeError("Filesystem not found (%s)" % fs_path)
 
     total = stats.f_blocks * stats.f_bsize
     free = stats.f_bfree * stats.f_bsize
     # return the size in GB
-    used_gb = utils.to_gb(total - free)
-    total_gb = utils.to_gb(total)
+    used_gb = to_gb(total - free)
+    total_gb = to_gb(total)
 
     output = {
         'block_size': stats.f_bsize,
