@@ -15,15 +15,13 @@
 from datetime import datetime
 from datetime import timedelta
 
-from oslo_log import log as logging
-
 from trove.common import cfg
 from trove.common import exception
-from trove.common.i18n import _
-from trove.common import timeutils
 from trove.common import utils
 from trove.db import get_db_api
 from trove.db import models as dbmodels
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 
@@ -39,8 +37,7 @@ def persisted_models():
 class AgentHeartBeat(dbmodels.DatabaseModelBase):
     """Defines the state of a Guest Agent."""
 
-    _data_fields = ['instance_id', 'updated_at', 'guest_agent_version',
-                    'deleted', 'deleted_at']
+    _data_fields = ['instance_id', 'updated_at']
     _table_name = 'agent_heartbeats'
 
     def __init__(self, **kwargs):
@@ -57,37 +54,11 @@ class AgentHeartBeat(dbmodels.DatabaseModelBase):
     def save(self):
         if not self.is_valid():
             raise exception.InvalidModelError(errors=self.errors)
-        self['updated_at'] = timeutils.utcnow()
-        LOG.debug("Saving %(name)s: %(dict)s",
+        self['updated_at'] = utils.utcnow()
+        LOG.debug(_("Saving %(name)s: %(dict)s") %
                   {'name': self.__class__.__name__, 'dict': self.__dict__})
         return get_db_api().save(self)
 
-    @classmethod
-    def find_all_by_version(cls, guest_agent_version, deleted=0):
-        if guest_agent_version is None:
-            raise exception.ModelNotFoundError()
-
-        heartbeats = cls.find_all(guest_agent_version=guest_agent_version,
-                                  deleted=deleted)
-
-        if heartbeats is None or heartbeats.count() == 0:
-            raise exception.ModelNotFoundError(
-                guest_agent_version=guest_agent_version)
-
-        return heartbeats
-
-    @classmethod
-    def find_by_instance_id(cls, instance_id):
-        if instance_id is None:
-            raise exception.ModelNotFoundError(instance_id=instance_id)
-
-        try:
-            return cls.find_by(instance_id=instance_id)
-
-        except exception.NotFound:
-            LOG.exception(_("Error finding instance %s"), instance_id)
-            raise exception.ModelNotFoundError(instance_id=instance_id)
-
     @staticmethod
     def is_active(agent):
         return (datetime.now() - agent.updated_at <
