@@ -16,21 +16,18 @@
 """
 Manages packages on the Guest VM.
 """
-import os
+import commands
 import re
-import subprocess
 from tempfile import NamedTemporaryFile
 
-from oslo_log import log as logging
-from oslo_utils import encodeutils
 import pexpect
-import six
 
 from trove.common import exception
-from trove.common.exception import ProcessExecutionError
-from trove.common.i18n import _
 from trove.common import utils
+from trove.common.exception import ProcessExecutionError
 from trove.guestagent.common import operating_system
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 
 LOG = logging.getLogger(__name__)
@@ -40,24 +37,6 @@ REINSTALL_FIRST = 2
 CONFLICT_REMOVED = 3
 
 
-def getoutput(*cmd):
-    """Get the stdout+stderr of a command, ignore errors.
-
-    Similar to commands.getstatusoutput(cmd)[1] of Python 2.
-    """
-
-    try:
-        proc = subprocess.Popen(cmd,
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.STDOUT)
-    except OSError:
-        # ignore errors like program not found
-        return six.text_type("")
-
-    stdout = proc.communicate()[0]
-    return encodeutils.safe_decode(stdout)
-
-
 class PkgAdminLockError(exception.TroveError):
     pass
 
@@ -94,20 +73,12 @@ class PkgBrokenError(exception.TroveError):
     pass
 
 
-class PkgConfigureError(exception.TroveError):
-    pass
-
-
-class BasePackagerMixin(object):
+class BasePackagerMixin:
 
     def pexpect_kill_proc(self, child):
         child.delayafterclose = 1
         child.delayafterterminate = 1
-        try:
-            child.close(force=True)
-        except pexpect.ExceptionPexpect:
-            # Close fails to terminate a sudo process on some OSes.
-            subprocess.call(['sudo', 'kill', str(child.pid)])
+        child.close(force=True)
 
     def pexpect_wait_and_close_proc(self, child):
         child.expect(pexpect.EOF)
@@ -121,11 +92,11 @@ class BasePackagerMixin(object):
             self.pexpect_wait_and_close_proc(child)
         except pexpect.TIMEOUT:
             self.pexpect_kill_proc(child)
-            raise PkgTimeout(_("Process timeout after %i seconds.") % time_out)
+            raise PkgTimeout("Process timeout after %i seconds." % time_out)
         return (i, match)
 
 
-class RPMPackagerMixin(BasePackagerMixin):
+class RedhatPackagerMixin(BasePackagerMixin):
 
     def _rpm_remove_nodeps(self, package_name):
         """
@@ -137,65 +108,8 @@ class RPMPackagerMixin(BasePackagerMixin):
             utils.execute("rpm", "-e", "--nodeps", package_name,
                           run_as_root=True, root_helper="sudo")
         except ProcessExecutionError:
-            LOG.exception("Error removing conflict %(package)s",
-                          package_name)
+            LOG.error(_("Error removing conflict %s") % package_name)
 
-    def _install(self, packages, time_out):
-        """must be overridden by an RPM based PackagerMixin"""
-        raise NotImplementedError()
-
-    def _remove(self, package_name, time_out):
-        """must be overridden by an RPM based PackagerMixin"""
-        raise NotImplementedError()
-
-    def pkg_install(self, packages, config_opts, time_out):
-        result = self._install(packages, time_out)
-        if result != OK:
-            while result == CONFLICT_REMOVED:
-                result = self._install(packages, time_out)
-            if result != OK:
-                raise PkgPackageStateError(_("Cannot install packages."))
-
-    def pkg_is_installed(self, packages):
-        packages = packages if isinstance(packages, list) else packages.split()
-        std_out = getoutput("rpm", "-qa")
-        for pkg in packages:
-            found = False
-            for line in std_out.split("\n"):
-                if line.find(pkg) != -1:
-                    found = True
-                    break
-            if not found:
-                return False
-        return True
-
-    def pkg_version(self, package_name):
-        std_out = getoutput("rpm", "-qa",
-                            "--qf", "'%{VERSION}-%{RELEASE}\n'",
-                            package_name)
-        # Need to capture the version string
-        # check the command output
-        for line in std_out.split("\n"):
-            regex = re.compile("[0-9.]+-.*")
-            matches = regex.match(line)
-            if matches:
-                line = matches.group()
-                return line
-
-        LOG.error("Unexpected output from rpm command. (%(output)s)",
-                  {'output': std_out})
-
-    def pkg_remove(self, package_name, time_out):
-        """Removes a package."""
-        if self.pkg_version(package_name) is None:
-            return
-        result = self._remove(package_name, time_out)
-        if result != OK:
-            raise PkgPackageStateError(_("Package %s is in a bad state.")
-                                       % package_name)
-
-
-class RedhatPackagerMixin(RPMPackagerMixin):
     def _install(self, packages, time_out):
         """Attempts to install packages.
 
@@ -204,8 +118,8 @@ class RedhatPackagerMixin(RPMPackagerMixin):
         Raises an exception if a non-recoverable error or timeout occurs.
 
         """
-        cmd = "sudo yum --color=never -y install %s" % " ".join(packages)
-        output_expects = [r'\[sudo\] password for .*:',
+        cmd = "sudo yum --color=never -y install %s" % packages
+        output_expects = ['\[sudo\] password for .*:',
                           'No package (.*) available.',
                           ('file .* from install of .* conflicts with file'
                            ' from package (.*?)\r\n'),
@@ -218,22 +132,21 @@ class RedhatPackagerMixin(RPMPackagerMixin):
                           '.*already installed and latest version',
                           'Updated:',
                           'Installed:']
-        LOG.debug("Running package install command: %s", cmd)
+        LOG.debug("Running package install command: %s" % cmd)
         i, match = self.pexpect_run(cmd, output_expects, time_out)
         if i == 0:
-            raise PkgPermissionError(_("Invalid permissions."))
+            raise PkgPermissionError("Invalid permissions.")
         elif i == 1:
-            raise PkgNotFoundError(_("Could not find package %s") %
-                                   match.group(1))
+            raise PkgNotFoundError("Could not find pkg %s" % match.group(1))
         elif i == 2 or i == 3 or i == 4:
             self._rpm_remove_nodeps(match.group(1))
             return CONFLICT_REMOVED
         elif i == 5:
-            raise PkgScriptletError(_("Package scriptlet failed"))
+            raise PkgScriptletError("Package scriptlet failed")
         elif i == 6 or i == 7:
-            raise PkgDownloadError(_("Package download problem"))
+            raise PkgDownloadError("Package download problem")
         elif i == 8:
-            raise PkgSignError(_("GPG key retrieval failed"))
+            raise PkgSignError("GPG key retrieval failed")
         return OK
 
     def _remove(self, package_name, time_out):
@@ -245,18 +158,64 @@ class RedhatPackagerMixin(RPMPackagerMixin):
 
         """
         cmd = "sudo yum --color=never -y remove %s" % package_name
-        LOG.debug("Running package remove command: %s", cmd)
-        output_expects = [r'\[sudo\] password for .*:',
+        output_expects = ['\[sudo\] password for .*:',
                           'No Packages marked for removal',
                           'Removed:']
         i, match = self.pexpect_run(cmd, output_expects, time_out)
         if i == 0:
-            raise PkgPermissionError(_("Invalid permissions."))
+            raise PkgPermissionError("Invalid permissions.")
         elif i == 1:
-            raise PkgNotFoundError(_("Could not find package %s") %
-                                   package_name)
+            raise PkgNotFoundError("Could not find pkg %s" % package_name)
         return OK
 
+    def pkg_install(self, packages, config_opts, time_out):
+        result = self._install(packages, time_out)
+        if result != OK:
+            while result == CONFLICT_REMOVED:
+                result = self._install(packages, time_out)
+            if result != OK:
+                raise PkgPackageStateError("Cannot install packages.")
+
+    def pkg_is_installed(self, packages):
+        pkg_list = packages.split()
+        cmd = "rpm -qa"
+        p = commands.getstatusoutput(cmd)
+        std_out = p[1]
+        for pkg in pkg_list:
+            found = False
+            for line in std_out.split("\n"):
+                if line.find(pkg) != -1:
+                    found = True
+                    break
+            if not found:
+                return False
+        return True
+
+    def pkg_version(self, package_name):
+        cmd_list = ["rpm", "-qa", "--qf", "'%{VERSION}-%{RELEASE}\n'",
+                    package_name]
+        p = commands.getstatusoutput(' '.join(cmd_list))
+        # Need to capture the version string
+        # check the command output
+        std_out = p[1]
+        for line in std_out.split("\n"):
+            regex = re.compile("[0-9.]+-.*")
+            matches = regex.match(line)
+            if matches:
+                line = matches.group()
+                return line
+        msg = _("version() saw unexpected output from rpm!")
+        LOG.error(msg)
+
+    def pkg_remove(self, package_name, time_out):
+        """Removes a package."""
+        if self.pkg_version(package_name) is None:
+            return
+        result = self._remove(package_name, time_out)
+        if result != OK:
+            raise PkgPackageStateError("Package %s is in a bad state."
+                                       % package_name)
+
 
 class DebianPackagerMixin(BasePackagerMixin):
 
@@ -268,7 +227,7 @@ class DebianPackagerMixin(BasePackagerMixin):
             utils.execute("dpkg", "--configure", "-a", run_as_root=True,
                           root_helper="sudo")
         except ProcessExecutionError:
-            LOG.exception("Error fixing dpkg")
+            LOG.error(_("Error fixing dpkg"))
 
     def _fix_package_selections(self, packages, config_opts):
         """
@@ -282,7 +241,9 @@ class DebianPackagerMixin(BasePackagerMixin):
                 package_name = m.group(1)
             else:
                 package_name = package
-            std_out = getoutput("sudo", "debconf-show", package_name)
+            command = "sudo debconf-show %s" % package_name
+            p = commands.getstatusoutput(command)
+            std_out = p[1]
             for line in std_out.split("\n"):
                 for selection, value in config_opts.items():
                     m = re.match(".* (.*/%s):.*" % selection, line)
@@ -292,16 +253,11 @@ class DebianPackagerMixin(BasePackagerMixin):
         if selections:
             with NamedTemporaryFile(delete=False) as f:
                 fname = f.name
-                f.write(encodeutils.safe_encode(selections))
-            try:
-                utils.execute("debconf-set-selections", fname,
-                              run_as_root=True, root_helper="sudo")
-                utils.execute("dpkg", "--configure", "-a",
-                              run_as_root=True, root_helper="sudo")
-            except ProcessExecutionError:
-                raise PkgConfigureError(_("Error configuring package."))
-            finally:
-                os.remove(fname)
+                f.write(selections)
+            utils.execute("debconf-set-selections %s && dpkg --configure -a"
+                          % fname, run_as_root=True, root_helper="sudo",
+                          shell=True)
+            os.remove(fname)
 
     def _install(self, packages, time_out):
         """Attempts to install packages.
@@ -314,7 +270,7 @@ class DebianPackagerMixin(BasePackagerMixin):
         cmd = "sudo -E DEBIAN_FRONTEND=noninteractive apt-get -y " \
               "--force-yes --allow-unauthenticated -o " \
               "DPkg::options::=--force-confmiss --reinstall " \
-              "install %s" % " ".join(packages)
+              "install %s" % packages
         output_expects = ['.*password*',
                           'E: Unable to locate package (.*)',
                           "Couldn't find package (.*)",
@@ -326,13 +282,12 @@ class DebianPackagerMixin(BasePackagerMixin):
                            "broken packages."),
                           "Setting up (.*)",
                           "is already the newest version"]
-        LOG.debug("Running package install command: %s", cmd)
+        LOG.debug("Running package install command: %s" % cmd)
         i, match = self.pexpect_run(cmd, output_expects, time_out)
         if i == 0:
-            raise PkgPermissionError(_("Invalid permissions."))
+            raise PkgPermissionError("Invalid permissions.")
         elif i == 1 or i == 2 or i == 3:
-            raise PkgNotFoundError(_("Could not find package %s") %
-                                   match.group(1))
+            raise PkgNotFoundError("Could not find apt %s" % match.group(1))
         elif i == 4:
             return RUN_DPKG_FIRST
         elif i == 5:
@@ -359,13 +314,11 @@ class DebianPackagerMixin(BasePackagerMixin):
                            "'sudo dpkg --configure -a'"),
                           "Unable to lock the administration directory",
                           "Removing %s*" % package_name]
-        LOG.debug("Running remove package command %s", cmd)
         i, match = self.pexpect_run(cmd, output_expects, time_out)
         if i == 0:
-            raise PkgPermissionError(_("Invalid permissions."))
+            raise PkgPermissionError("Invalid permissions.")
         elif i == 1:
-            raise PkgNotFoundError(_("Could not find package %s") %
-                                   package_name)
+            raise PkgNotFoundError("Could not find pkg %s" % package_name)
         elif i == 2 or i == 3:
             return REINSTALL_FIRST
         elif i == 4:
@@ -380,7 +333,7 @@ class DebianPackagerMixin(BasePackagerMixin):
             utils.execute("apt-get", "update", run_as_root=True,
                           root_helper="sudo")
         except ProcessExecutionError:
-            LOG.exception("Error updating the apt sources")
+            LOG.error(_("Error updating the apt sources"))
 
         result = self._install(packages, time_out)
         if result != OK:
@@ -388,7 +341,7 @@ class DebianPackagerMixin(BasePackagerMixin):
                 self._fix(time_out)
             result = self._install(packages, time_out)
             if result != OK:
-                raise PkgPackageStateError(_("Packages are in a bad state."))
+                raise PkgPackageStateError("Packages is in a bad state.")
         # even after successful install, packages can stay unconfigured
         # config_opts - is dict with name/value for questions asked by
         # interactive configure script
@@ -396,9 +349,10 @@ class DebianPackagerMixin(BasePackagerMixin):
             self._fix_package_selections(packages, config_opts)
 
     def pkg_version(self, package_name):
-        std_out = getoutput("apt-cache", "policy", package_name)
+        p = commands.getstatusoutput("apt-cache policy %s" % package_name)
+        std_out = p[1]
         for line in std_out.split("\n"):
-            m = re.match(r"\s+Installed: (.*)", line)
+            m = re.match("\s+Installed: (.*)", line)
             if m:
                 version = m.group(1)
                 if version == "(none)":
@@ -406,8 +360,8 @@ class DebianPackagerMixin(BasePackagerMixin):
                 return version
 
     def pkg_is_installed(self, packages):
-        packages = packages if isinstance(packages, list) else packages.split()
-        for pkg in packages:
+        pkg_list = packages.split()
+        for pkg in pkg_list:
             m = re.match('(.+)=(.+)', pkg)
             if m:
                 package_name = m.group(1)
@@ -418,7 +372,7 @@ class DebianPackagerMixin(BasePackagerMixin):
             installed_version = self.pkg_version(package_name)
             if ((package_version and installed_version == package_version) or
                (installed_version and not package_version)):
-                LOG.debug("Package %s already installed.", package_name)
+                LOG.debug(_("Package %s already installed.") % package_name)
             else:
                 return False
         return True
@@ -436,13 +390,21 @@ class DebianPackagerMixin(BasePackagerMixin):
                 self._fix(time_out)
             result = self._remove(package_name, time_out)
             if result != OK:
-                raise PkgPackageStateError(_("Package %s is in a bad state.")
+                raise PkgPackageStateError("Package %s is in a bad state."
                                            % package_name)
 
 
-if operating_system.get_os() == operating_system.REDHAT:
-    class Package(RedhatPackagerMixin):
-        pass
-else:
-    class Package(DebianPackagerMixin):
-        pass
+class BasePackage(type):
+
+    def __new__(meta, name, bases, dct):
+        if operating_system.get_os() == operating_system.REDHAT:
+            bases += (RedhatPackagerMixin, )
+        else:
+            # The default is debian
+            bases += (DebianPackagerMixin,)
+        return super(BasePackage, meta).__new__(meta, name, bases, dct)
+
+
+class Package(object):
+
+    __metaclass__ = BasePackage
