@@ -13,10 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from trove.openstack.common import log as logging
 import routes
 
 from trove.common import wsgi
 
+LOG = logging.getLogger(__name__)
+
 
 class Controller(wsgi.Controller):
     """Base controller class."""
@@ -24,7 +27,7 @@ class Controller(wsgi.Controller):
 
 
 class API(wsgi.Router):
-    """Defines the API routes."""
+    """API"""
     def __init__(self):
         mapper = routes.Mapper()
         super(API, self).__init__(mapper)
