@@ -14,12 +14,12 @@
 #    under the License.
 #
 
-from oslo_log import log as logging
-
-from trove.common.strategies.strategy import Strategy
+from trove.guestagent.strategy import Strategy
+from trove.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 def get_backup_strategy(backup_driver, ns=__name__):
+    LOG.debug("Getting backup strategy: %s" % backup_driver)
     return Strategy.get_strategy(backup_driver, ns)
