@@ -13,15 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
+
+from trove.guestagent.strategy import Strategy
+from trove.openstack.common import log as logging
+from trove.common import cfg, utils
+from eventlet.green import subprocess
 import os
 import signal
 
-from oslo_log import log as logging
-
-from eventlet.green import subprocess
-from trove.common import cfg, utils
-from trove.common.strategies.strategy import Strategy
-
 CONF = cfg.CONF
 
 LOG = logging.getLogger(__name__)
@@ -32,11 +31,11 @@ class BackupError(Exception):
 
 
 class UnknownBackupType(Exception):
-    """Unknown backup type."""
+    """Unknown backup type"""
 
 
 class BackupRunner(Strategy):
-    """Base class for Backup Strategy implementations."""
+    """Base class for Backup Strategy implementations """
     __strategy_type__ = 'backup_runner'
     __strategy_ns__ = 'trove.guestagent.strategies.backup'
 
@@ -58,8 +57,7 @@ class BackupRunner(Strategy):
     def backup_type(self):
         return type(self).__name__
 
-    def _run(self):
-        LOG.debug("BackupRunner running cmd: %s", self.command)
+    def run(self):
         self.process = subprocess.Popen(self.command, shell=True,
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE,
@@ -67,9 +65,10 @@ class BackupRunner(Strategy):
         self.pid = self.process.pid
 
     def __enter__(self):
-        """Start up the process."""
+        """Start up the process"""
         self._run_pre_backup()
-        self._run()
+        self.run()
+        self._run_post_backup()
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
@@ -77,7 +76,7 @@ class BackupRunner(Strategy):
         if exc_type is not None:
             return False
 
-        if getattr(self, 'process', None):
+        if hasattr(self, 'process'):
             try:
                 # Send a sigterm to the session leader, so that all
                 # child processes are killed and cleaned up on terminate
@@ -92,8 +91,6 @@ class BackupRunner(Strategy):
             if not self.check_process():
                 raise BackupError
 
-        self._run_post_backup()
-
         return True
 
     def metadata(self):
@@ -102,7 +99,7 @@ class BackupRunner(Strategy):
 
     @property
     def filename(self):
-        """Subclasses may overwrite this to declare a format (.tar)."""
+        """Subclasses may overwrite this to declare a format (.tar)"""
         return self.base_filename
 
     @property
