@@ -17,18 +17,16 @@
 
 import re
 
-from oslo_log import log as logging
-
-from trove.common.i18n import _
-from trove.guestagent.datastore.mysql.service import MySqlApp
-from trove.guestagent.datastore.mysql_common.service import ADMIN_USER_NAME
+from trove.guestagent.datastore.mysql.service import ADMIN_USER_NAME
+from trove.guestagent.datastore.mysql.service import get_auth_password
 from trove.guestagent.strategies.backup import base
+from trove.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 class MySQLDump(base.BackupRunner):
-    """Implementation of Backup Strategy for MySQLDump."""
+    """Implementation of Backup Strategy for MySQLDump """
     __strategy_name__ = 'mysqldump'
 
     @property
@@ -36,7 +34,7 @@ class MySQLDump(base.BackupRunner):
         user_and_pass = (
             ' --password=%(password)s -u %(user)s '
             '2>/tmp/mysqldump.log' %
-            {'password': MySqlApp.get_auth_password(),
+            {'password': get_auth_password(),
              'user': ADMIN_USER_NAME})
         cmd = ('mysqldump'
                ' --all-databases'
@@ -44,74 +42,46 @@ class MySQLDump(base.BackupRunner):
                ' --opt' + user_and_pass)
         return cmd + self.zip_cmd + self.encrypt_cmd
 
-    def check_process(self):
-        """Check the output from mysqldump ignoring 'Warning'."""
-        LOG.debug('Checking mysqldump process output.')
-        with open('/tmp/mysqldump.log', 'r') as backup_log:
-            output = backup_log.read()
-            if not output:
-                return True
-
-            LOG.debug(output)
-            for line in output.splitlines():
-                if not re.search('Warning', line.strip()):
-                    LOG.error("Mysqldump did not complete successfully.")
-                    return False
-
-        return True
-
 
 class InnoBackupEx(base.BackupRunner):
-    """Implementation of Backup Strategy for InnoBackupEx."""
+    """Implementation of Backup Strategy for InnoBackupEx """
     __strategy_name__ = 'innobackupex'
 
-    @property
-    def user_and_pass(self):
-        return ('--user=%(user)s --password=%(password)s --host=localhost '
-                '--socket=%(socket_file)s' %
-                {'user': ADMIN_USER_NAME,
-                 'password': MySqlApp.get_auth_password(),
-                 'socket_file': '/var/run/mysqld/mysqld.sock'})
-
     @property
     def cmd(self):
         cmd = ('sudo innobackupex'
                ' --stream=xbstream'
-               ' %(extra_opts)s ' +
-               self.user_and_pass + ' ' +
-               MySqlApp.get_data_dir() +
-               ' 2>/tmp/innobackupex.log'
+               ' %(extra_opts)s'
+               ' /var/lib/mysql 2>/tmp/innobackupex.log'
                )
         return cmd + self.zip_cmd + self.encrypt_cmd
 
     def check_process(self):
-        """Check the output from innobackupex for 'completed OK!'."""
-        LOG.debug('Checking innobackupex process output.')
+        """Check the output from innobackupex for 'completed OK!'"""
+        LOG.debug('Checking innobackupex process output')
         with open('/tmp/innobackupex.log', 'r') as backup_log:
             output = backup_log.read()
+            LOG.info(output)
             if not output:
-                LOG.error("Innobackupex log file empty.")
+                LOG.error("Innobackupex log file empty")
                 return False
-
-            LOG.debug(output)
             last_line = output.splitlines()[-1].strip()
             if not re.search('completed OK!', last_line):
-                LOG.error("Innobackupex did not complete successfully.")
+                LOG.error("Innobackupex did not complete successfully")
                 return False
 
         return True
 
     def metadata(self):
-        LOG.debug('Getting metadata for backup %s', self.base_filename)
+        LOG.debug('Getting metadata from backup')
         meta = {}
-        lsn = re.compile(r"The latest check point \(for incremental\): "
-                         r"'(\d+)'")
+        lsn = re.compile("The latest check point \(for incremental\): '(\d+)'")
         with open('/tmp/innobackupex.log', 'r') as backup_log:
             output = backup_log.read()
             match = lsn.search(output)
             if match:
                 meta = {'lsn': match.group(1)}
-        LOG.info("Metadata for backup %s: %s", self.base_filename, meta)
+        LOG.info("Metadata for backup: %s", str(meta))
         return meta
 
     @property
@@ -124,7 +94,7 @@ class InnoBackupExIncremental(InnoBackupEx):
 
     def __init__(self, *args, **kwargs):
         if not kwargs.get('lsn'):
-            raise AttributeError(_('lsn attribute missing, bad parent?'))
+            raise AttributeError('lsn attribute missing, bad parent?')
         super(InnoBackupExIncremental, self).__init__(*args, **kwargs)
         self.parent_location = kwargs.get('parent_location')
         self.parent_checksum = kwargs.get('parent_checksum')
@@ -135,9 +105,8 @@ class InnoBackupExIncremental(InnoBackupEx):
                ' --stream=xbstream'
                ' --incremental'
                ' --incremental-lsn=%(lsn)s'
-               ' %(extra_opts)s ' +
-               self.user_and_pass + ' ' +
-               MySqlApp.get_data_dir() +
+               ' %(extra_opts)s'
+               ' /var/lib/mysql'
                ' 2>/tmp/innobackupex.log')
         return cmd + self.zip_cmd + self.encrypt_cmd
 
