@@ -14,13 +14,12 @@
 #    under the License.
 #
 
-from oslo_log import log as logging
-
 from trove.guestagent.strategy import Strategy
+from trove.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 def get_storage_strategy(storage_driver, ns=__name__):
-    LOG.debug("Getting storage strategy: %s." % storage_driver)
+    LOG.debug("Getting storage strategy: %s" % storage_driver)
     return Strategy.get_strategy(storage_driver, ns)
