@@ -21,8 +21,8 @@ class InstanceTask(object):
     """
     Stores the different kind of tasks being performed by an instance.
     """
-    # TODO(tim.simpson): Figure out someway to migrate this to the TaskManager
-    #                    once that revs up.
+    #TODO(tim.simpson): Figure out someway to migrate this to the TaskManager
+    #                   once that revs up.
     _lookup = {}
 
     def __init__(self, code, action, db_text, is_error=False):
@@ -75,13 +75,6 @@ class InstanceTasks(object):
     MIGRATING = InstanceTask(0x06, 'MIGRATING', 'Migrating the instance.')
     RESTART_REQUIRED = InstanceTask(0x07, 'RESTART_REQUIRED',
                                     'Instance requires a restart.')
-    PROMOTING = InstanceTask(0x08, 'PROMOTING',
-                             'Promoting the instance to replica source.')
-    EJECTING = InstanceTask(0x09, 'EJECTING',
-                            'Ejecting the replica source.')
-    LOGGING = InstanceTask(0x0a, 'LOGGING', 'Transferring guest logs.')
-    DETACHING = InstanceTask(0x0b, 'DETACHING',
-                             'Detaching the instance from replica source.')
 
     BUILDING_ERROR_DNS = InstanceTask(0x50, 'BUILDING', 'Build error: DNS.',
                                       is_error=True)
@@ -91,36 +84,14 @@ class InstanceTasks(object):
     BUILDING_ERROR_VOLUME = InstanceTask(0x52, 'BUILDING',
                                          'Build error: Volume.',
                                          is_error=True)
-    BUILDING_ERROR_SEC_GROUP = InstanceTask(0x53, 'BUILDING',
-                                            'Build error: Secgroup '
-                                            'or rule.',
-                                            is_error=True)
-    BUILDING_ERROR_REPLICA = InstanceTask(0x54, 'BUILDING',
-                                          'Build error: Replica.',
-                                          is_error=True)
-    PROMOTION_ERROR = InstanceTask(0x55, 'PROMOTING',
-                                         'Replica Promotion Error.',
-                                         is_error=True)
-    EJECTION_ERROR = InstanceTask(0x56, 'EJECTING',
-                                        'Replica Source Ejection Error.',
-                                        is_error=True)
-    GROWING_ERROR = InstanceTask(0x57, 'GROWING',
-                                       'Growing Cluster Error.',
-                                       is_error=True)
-    SHRINKING_ERROR = InstanceTask(0x58, 'SHRINKING',
-                                         'Shrinking Cluster Error.',
-                                         is_error=True)
-    UPGRADING = InstanceTask(0x59, 'UPGRADING', 'Upgrading the instance.')
-    UPGRADING_ERROR = InstanceTask(0x5a, 'UPGRADING',
-                                         'Upgrading Cluster Error.',
-                                         is_error=True)
-    BUILDING_ERROR_TIMEOUT_GA = InstanceTask(0x5b, 'ERROR',
+    BUILDING_ERROR_TIMEOUT_GA = InstanceTask(0x54, 'ERROR',
                                              'Build error: '
                                              'guestagent timeout.',
                                              is_error=True)
-    BUILDING_ERROR_PORT = InstanceTask(0x5c, 'BUILDING',
-                                       'Build error: Port.',
-                                       is_error=True)
+    BUILDING_ERROR_SEC_GROUP = InstanceTask(0x53, 'BUILDING',
+                                            'Build error: Security group '
+                                            'or rule.',
+                                            is_error=True)
 
 # Dissuade further additions at run-time.
 InstanceTask.__init__ = None
