@@ -15,12 +15,11 @@
 
 """Quotas for DB instances and resources."""
 
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import importutils
-import six
-
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+from oslo.config import cfg
 from trove.common import exception
+from trove.openstack.common import importutils
 from trove.quota.models import Quota
 from trove.quota.models import QuotaUsage
 from trove.quota.models import Reservation
@@ -58,8 +57,9 @@ class DbQuotaDriver(object):
         """
 
         all_quotas = Quota.find_all(tenant_id=tenant_id).all()
-        result_quotas = {quota.resource: quota for quota in all_quotas
-                         if quota.resource in resources}
+        result_quotas = dict((quota.resource, quota)
+                             for quota in all_quotas
+                             if quota.resource in resources)
 
         if len(result_quotas) != len(resources):
             for resource in resources:
@@ -93,8 +93,9 @@ class DbQuotaDriver(object):
         """
 
         all_usages = QuotaUsage.find_all(tenant_id=tenant_id).all()
-        result_usages = {usage.resource: usage for usage in all_usages
-                         if usage.resource in resources}
+        result_usages = dict((usage.resource, usage)
+                             for usage in all_usages
+                             if usage.resource in resources)
         if len(result_usages) != len(resources):
             for resource in resources:
                 # Not in the DB, return default value
@@ -119,41 +120,6 @@ class DbQuotaDriver(object):
 
         return quotas
 
-    def check_quotas(self, tenant_id, resources, deltas):
-        """Check quotas for a tenant.
-
-        This method checks quotas against current usage,
-        reserved resources and the desired deltas.
-
-        If any of the proposed values is over the defined quota, an
-        QuotaExceeded exception will be raised with the sorted list of the
-        resources which are too high.
-
-        :param tenant_id: The ID of the tenant reserving the resources.
-        :param resources: A dictionary of the registered resources.
-        :param deltas: A dictionary of the proposed delta changes.
-        """
-
-        unregistered_resources = [delta for delta in deltas
-                                  if delta not in resources]
-        if unregistered_resources:
-            raise exception.QuotaResourceUnknown(
-                unknown=unregistered_resources)
-
-        quotas = self.get_all_quotas_by_tenant(tenant_id, deltas.keys())
-        quota_usages = self.get_all_quota_usages_by_tenant(tenant_id,
-                                                           deltas.keys())
-
-        overs = [resource for resource in deltas
-                 if (int(deltas[resource]) > 0 and
-                     quotas[resource].hard_limit >= 0 and
-                     (quota_usages[resource].in_use +
-                      quota_usages[resource].reserved +
-                      int(deltas[resource])) > quotas[resource].hard_limit)]
-
-        if overs:
-            raise exception.QuotaExceeded(overs=sorted(overs))
-
     def reserve(self, tenant_id, resources, deltas):
         """Check quotas and reserve resources for a tenant.
 
@@ -170,12 +136,27 @@ class DbQuotaDriver(object):
         :param deltas: A dictionary of the proposed delta changes.
         """
 
-        self.check_quotas(tenant_id, resources, deltas)
+        unregistered_resources = [delta for delta in deltas
+                                  if delta not in resources]
+        if unregistered_resources:
+            raise exception.QuotaResourceUnknown(unknown=
+                                                 unregistered_resources)
+
+        quotas = self.get_all_quotas_by_tenant(tenant_id, deltas.keys())
         quota_usages = self.get_all_quota_usages_by_tenant(tenant_id,
                                                            deltas.keys())
 
+        overs = [resource for resource in deltas
+                 if (int(deltas[resource]) > 0 and
+                    (quota_usages[resource].in_use +
+                     quota_usages[resource].reserved +
+                     int(deltas[resource])) > quotas[resource].hard_limit)]
+
+        if overs:
+            raise exception.QuotaExceeded(overs=sorted(overs))
+
         reservations = []
-        for resource in sorted(deltas):
+        for resource in deltas:
             reserved = deltas[resource]
             usage = quota_usages[resource]
             usage.reserved += reserved
@@ -230,7 +211,7 @@ class QuotaEngine(object):
 
         if not quota_driver_class:
             quota_driver_class = CONF.quota_driver
-        if isinstance(quota_driver_class, six.string_types):
+        if isinstance(quota_driver_class, basestring):
             quota_driver_class = importutils.import_object(quota_driver_class,
                                                            self._resources)
         self._driver = quota_driver_class
@@ -254,12 +235,6 @@ class QuotaEngine(object):
 
         return self._driver.get_quota_by_tenant(tenant_id, resource)
 
-    def get_quota_usage(self, quota):
-        """Get the usage for a quota."""
-
-        return self._driver.get_quota_usage_by_tenant(quota.tenant_id,
-                                                      quota.resource)
-
     def get_defaults(self):
         """Retrieve the default quotas."""
 
@@ -274,18 +249,6 @@ class QuotaEngine(object):
         return self._driver.get_all_quotas_by_tenant(tenant_id,
                                                      self._resources)
 
-    def get_all_quota_usages_by_tenant(self, tenant_id):
-        """Retrieve the quota usages for the given tenant.
-
-        :param tenant_id: The ID of the tenant to return quota usages for.
-        """
-
-        return self._driver.get_all_quota_usages_by_tenant(tenant_id,
-                                                           self._resources)
-
-    def check_quotas(self, tenant_id, **deltas):
-        self._driver.check_quotas(tenant_id, self._resources, deltas)
-
     def reserve(self, tenant_id, **deltas):
         """Check quotas and reserve resources.
 
@@ -309,7 +272,7 @@ class QuotaEngine(object):
 
         reservations = self._driver.reserve(tenant_id, self._resources, deltas)
 
-        LOG.debug("Created reservations %(reservations)s",
+        LOG.debug(_("Created reservations %(reservations)s") %
                   {'reservations': reservations})
 
         return reservations
@@ -324,8 +287,8 @@ class QuotaEngine(object):
         try:
             self._driver.commit(reservations)
         except Exception:
-            LOG.exception("Failed to commit reservations "
-                          "%(reservations)s", {'reservations': reservations})
+            LOG.exception(_("Failed to commit reservations "
+                          "%(reservations)s") % {'reservations': reservations})
 
     def rollback(self, reservations):
         """Roll back reservations.
@@ -337,8 +300,8 @@ class QuotaEngine(object):
         try:
             self._driver.rollback(reservations)
         except Exception:
-            LOG.exception("Failed to roll back reservations "
-                          "%(reservations)s", {'reservations': reservations})
+            LOG.exception(_("Failed to roll back reservations "
+                          "%(reservations)s") % {'reservations': reservations})
 
     @property
     def resources(self):
@@ -348,28 +311,24 @@ class QuotaEngine(object):
 QUOTAS = QuotaEngine()
 
 ''' Define all kind of resources here '''
-
-resources = [Resource(Resource.INSTANCES, 'max_instances_per_tenant'),
-             Resource(Resource.BACKUPS, 'max_backups_per_tenant'),
-             Resource(Resource.VOLUMES, 'max_volumes_per_tenant')]
+resources = [Resource(Resource.INSTANCES, 'max_instances_per_user'),
+             Resource(Resource.BACKUPS, 'max_backups_per_user')]
+if CONF.trove_volume_support:
+    resources.append(Resource(Resource.VOLUMES, 'max_volumes_per_user'))
 
 QUOTAS.register_resources(resources)
 
 
-def run_with_quotas(tenant_id, deltas, f, *args, **kwargs):
-    """Quota wrapper."""
+def run_with_quotas(tenant_id, deltas, f):
+    """Quota wrapper """
 
     reservations = QUOTAS.reserve(tenant_id, **deltas)
     result = None
     try:
-        result = f(*args, **kwargs)
+        result = f()
     except Exception:
         QUOTAS.rollback(reservations)
         raise
     else:
         QUOTAS.commit(reservations)
     return result
-
-
-def check_quotas(tenant_id, deltas):
-    QUOTAS.check_quotas(tenant_id, **deltas)
