@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
+from trove.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
