@@ -15,24 +15,27 @@
 
 
 from nose.tools import assert_equal
-from proboscis.asserts import assert_raises
-from proboscis.asserts import assert_true
-from proboscis import before_class
-from proboscis import test
 from troveclient.compat import exceptions
 
+from proboscis import before_class
+from proboscis import test
+from proboscis.asserts import assert_raises
+from proboscis.asserts import assert_true
+
 from trove import tests
-from trove.tests.util.check import TypeCheck
 from trove.tests.util import create_dbaas_client
 from trove.tests.util import test_config
 from trove.tests.util.users import Requirements
+from trove.tests.util.check import TypeCheck
 
+GROUP = "dbaas.api.datastores"
 NAME = "nonexistent"
 
 
-@test(groups=[tests.DBAAS_API_DATASTORES],
-      depends_on_groups=[tests.DBAAS_API_VERSIONS])
+@test(groups=[tests.DBAAS_API, GROUP, tests.PRE_INSTANCES],
+      depends_on_groups=["services.initialize"])
 class Datastores(object):
+
     @before_class
     def setUp(self):
         rd_user = test_config.users.find_user(
@@ -47,31 +50,19 @@ class Datastores(object):
         datastores = self.rd_client.datastores.list()
         for datastore in datastores:
             with TypeCheck('Datastore', datastore) as check:
-                check.has_field("id", str)
-                check.has_field("name", str)
+                check.has_field("id", basestring)
+                check.has_field("name", basestring)
                 check.has_field("links", list)
-                check.has_field("versions", list)
 
     @test
-    def test_datastore_get(self):
-        # Test get by name
-        datastore_by_name = self.rd_client.datastores.get(
-            test_config.dbaas_datastore)
-        with TypeCheck('Datastore', datastore_by_name) as check:
-            check.has_field("id", str)
-            check.has_field("name", str)
+    def test_datastore_get_attrs(self):
+        datastore = self.rd_client.datastores.get(test_config.
+                                                  dbaas_datastore)
+        with TypeCheck('Datastore', datastore) as check:
+            check.has_field("id", basestring)
+            check.has_field("name", basestring)
             check.has_field("links", list)
-        assert_equal(datastore_by_name.name, test_config.dbaas_datastore)
-
-        # test get by id
-        datastore_by_id = self.rd_client.datastores.get(
-            datastore_by_name.id)
-        with TypeCheck('Datastore', datastore_by_id) as check:
-            check.has_field("id", str)
-            check.has_field("name", str)
-            check.has_field("links", list)
-            check.has_field("versions", list)
-        assert_equal(datastore_by_id.id, datastore_by_name.id)
+        assert_equal(datastore.name, test_config.dbaas_datastore)
 
     @test
     def test_datastore_not_found(self):
@@ -82,116 +73,100 @@ class Datastores(object):
             assert_equal(e.message,
                          "Datastore '%s' cannot be found." % NAME)
 
-    @test
-    def test_create_inactive_datastore_by_admin(self):
-        datastores = self.rd_admin.datastores.list()
-        for ds in datastores:
-            if ds.name == test_config.dbaas_datastore_name_no_versions:
-                for version in ds.versions:
-                    if version['name'] == 'inactive_version':
-                        return
-
-        # Create datastore version for testing
-        # 'Test_Datastore_1' is also used in other test cases.
-        # Will be deleted in test_delete_datastore_version
-        self.rd_admin.mgmt_datastore_versions.create(
-            "inactive_version", test_config.dbaas_datastore_name_no_versions,
-            "test_manager", None, image_tags=['trove'],
-            active='false', default='false'
-        )
-
-    @test(depends_on=[test_create_inactive_datastore_by_admin])
-    def test_datastore_with_no_active_versions_is_hidden(self):
-        datastores = self.rd_client.datastores.list()
-        name_list = [datastore.name for datastore in datastores]
-
-        assert_true(
-            test_config.dbaas_datastore_name_no_versions not in name_list)
-
-    @test(depends_on=[test_create_inactive_datastore_by_admin])
-    def test_datastore_with_no_active_versions_is_visible_for_admin(self):
-        datastores = self.rd_admin.datastores.list()
-        name_list = [datastore.name for datastore in datastores]
-        assert_true(test_config.dbaas_datastore_name_no_versions in name_list)
-
-
-@test(groups=[tests.DBAAS_API_DATASTORES])
-class DatastoreVersions(object):
-    @before_class
-    def setUp(self):
-        rd_user = test_config.users.find_user(
-            Requirements(is_admin=False, services=["trove"]))
-        self.rd_client = create_dbaas_client(rd_user)
-        self.datastore_active = self.rd_client.datastores.get(
-            test_config.dbaas_datastore)
-        self.datastore_version_active = self.rd_client.datastore_versions.list(
-            self.datastore_active.id)[0]
-
     @test
     def test_datastore_version_list_attrs(self):
-        versions = self.rd_client.datastore_versions.list(
-            self.datastore_active.name)
+        versions = self.rd_client.datastore_versions.list(test_config.
+                                                          dbaas_datastore)
         for version in versions:
             with TypeCheck('DatastoreVersion', version) as check:
-                check.has_field("id", str)
-                check.has_field("name", str)
+                check.has_field("id", basestring)
+                check.has_field("name", basestring)
                 check.has_field("links", list)
 
     @test
     def test_datastore_version_get_attrs(self):
         version = self.rd_client.datastore_versions.get(
-            self.datastore_active.name, self.datastore_version_active.name)
+            test_config.dbaas_datastore, test_config.dbaas_datastore_version)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", str)
-            check.has_field("name", str)
-            check.has_field("datastore", str)
+            check.has_field("id", basestring)
+            check.has_field("name", basestring)
+            check.has_field("datastore", basestring)
             check.has_field("links", list)
-        assert_equal(version.name, self.datastore_version_active.name)
+        assert_equal(version.name, test_config.dbaas_datastore_version)
 
     @test
     def test_datastore_version_get_by_uuid_attrs(self):
         version = self.rd_client.datastore_versions.get_by_uuid(
-            self.datastore_version_active.id)
+            test_config.dbaas_datastore_version_id)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", str)
-            check.has_field("name", str)
-            check.has_field("datastore", str)
+            check.has_field("id", basestring)
+            check.has_field("name", basestring)
+            check.has_field("datastore", basestring)
             check.has_field("links", list)
-        assert_equal(version.name, self.datastore_version_active.name)
+        assert_equal(version.name, test_config.dbaas_datastore_version)
 
     @test
     def test_datastore_version_not_found(self):
-        assert_raises(exceptions.BadRequest,
-                      self.rd_client.datastore_versions.get,
-                      self.datastore_active.name, NAME)
+        try:
+            assert_raises(exceptions.NotFound,
+                          self.rd_client.datastore_versions.get,
+                          test_config.dbaas_datastore, NAME)
+        except exceptions.BadRequest as e:
+            assert_equal(e.message,
+                         "Datastore version '%s' cannot be found." % NAME)
+
+    @test
+    def test_datastore_get_by_uuid(self):
+        datastore = self.rd_client.datastores.get(
+            test_config.dbaas_datastore_id)
+        with TypeCheck('Datastore', datastore) as check:
+            check.has_field("id", basestring)
+            check.has_field("name", basestring)
+            check.has_field("links", list)
+        assert_equal(datastore.id, test_config.dbaas_datastore_id)
 
     @test
     def test_datastore_version_list_by_uuid(self):
         versions = self.rd_client.datastore_versions.list(
-            self.datastore_active.id)
+            test_config.dbaas_datastore_id)
         for version in versions:
             with TypeCheck('DatastoreVersion', version) as check:
-                check.has_field("id", str)
-                check.has_field("name", str)
+                check.has_field("id", basestring)
+                check.has_field("name", basestring)
                 check.has_field("links", list)
 
     @test
     def test_datastore_version_get_by_uuid(self):
         version = self.rd_client.datastore_versions.get(
-            self.datastore_active.id, self.datastore_version_active.id)
+            test_config.dbaas_datastore_id,
+            test_config.dbaas_datastore_version)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", str)
-            check.has_field("name", str)
-            check.has_field("datastore", str)
+            check.has_field("id", basestring)
+            check.has_field("name", basestring)
+            check.has_field("datastore", basestring)
             check.has_field("links", list)
-        assert_equal(version.name, self.datastore_version_active.name)
+        assert_equal(version.name, test_config.dbaas_datastore_version)
 
     @test
     def test_datastore_version_invalid_uuid(self):
         try:
             self.rd_client.datastore_versions.get_by_uuid(
-                self.datastore_version_active.id)
+                test_config.dbaas_datastore_version)
         except exceptions.BadRequest as e:
             assert_equal(e.message,
                          "Datastore version '%s' cannot be found." %
                          test_config.dbaas_datastore_version)
+
+    @test
+    def test_datastore_with_no_active_versions_is_hidden(self):
+        datastores = self.rd_client.datastores.list()
+        id_list = [datastore.id for datastore in datastores]
+        id_no_versions = test_config.dbaas_datastore_id_no_versions
+        assert_true(id_no_versions not in id_list)
+
+    @test
+    def test_datastore_with_no_active_versions_is_visible_for_admin(self):
+        datastores = self.rd_admin.datastores.list()
+        id_list = [datastore.id for datastore in datastores]
+        id_no_versions = test_config.dbaas_datastore_id_no_versions
+        assert_true(id_no_versions in id_list)
