@@ -13,36 +13,47 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import time
 
 from proboscis import after_class
-from proboscis import asserts
 from proboscis import before_class
+from proboscis import test
+from proboscis import asserts
 from proboscis.decorators import time_out
 from proboscis import SkipTest
-from proboscis import test
+
+from trove import tests
+from trove.tests.util.check import Checker
 from troveclient.compat.exceptions import BadRequest
 from troveclient.compat.exceptions import HTTPNotImplemented
-
-from trove.common import cfg
-from trove.common.utils import poll_until
-from trove import tests
-from trove.tests.api.instances import assert_unprocessable
-from trove.tests.api.instances import EPHEMERAL_SUPPORT
+from trove.tests.api.instances import GROUP as INSTANCE_GROUP
 from trove.tests.api.instances import instance_info
+from trove.tests.api.instances import GROUP_START
+from trove.tests.api.instances import assert_unprocessable
 from trove.tests.api.instances import VOLUME_SUPPORT
-from trove.tests.config import CONFIG
-import trove.tests.util as testsutil
-from trove.tests.util.check import TypeCheck
-from trove.tests.util import LocalSqlClient
+from trove.tests.api.instances import EPHEMERAL_SUPPORT
 from trove.tests.util.server_connection import create_server_connection
+from trove.common.utils import poll_until
+import trove.tests.util as testsutil
+from trove.tests.config import CONFIG
+from trove.tests.util import LocalSqlClient
+from sqlalchemy import exc as sqlalchemy_exc
+from trove.tests.util.check import TypeCheck
+from sqlalchemy.sql.expression import text
 
+GROUP = "dbaas.api.instances.actions"
+GROUP_REBOOT = "dbaas.api.instances.actions.reboot"
+GROUP_RESTART = "dbaas.api.instances.actions.restart"
+GROUP_STOP_MYSQL = "dbaas.api.instances.actions.stop"
 MYSQL_USERNAME = "test_user"
 MYSQL_PASSWORD = "abcde"
+# stored in test conf
+SERVICE_ID = '123'
 FAKE_MODE = CONFIG.fake_mode
 # If true, then we will actually log into the database.
 USE_IP = not FAKE_MODE
+# If true, then we will actually search for the process
+USE_LOCAL_OVZ = CONFIG.use_local_ovz
 
 
 class MySqlConnection(object):
@@ -59,40 +70,23 @@ class MySqlConnection(object):
         self.client = LocalSqlClient(sql_engine, use_flush=False)
 
     def is_connected(self):
-        cmd = "SELECT 1;"
         try:
             with self.client:
-                self.client.execute(cmd)
+                self.client.execute(text("""SELECT "Hello.";"""))
             return True
-        except Exception as e:
-            print(
-                "Failed to execute command: %s, error: %s" % (cmd, str(e))
-            )
-            return False
-
-    def execute(self, cmd):
-        try:
-            with self.client:
-                self.client.execute(cmd)
-            return True
-        except Exception as e:
-            print(
-                "Failed to execute command: %s, error: %s" % (cmd, str(e))
-            )
+        except (sqlalchemy_exc.OperationalError,
+                sqlalchemy_exc.DisconnectionError,
+                sqlalchemy_exc.TimeoutError):
             return False
+        except Exception as ex:
+            print("EX WAS:")
+            print(type(ex))
+            print(ex)
+            raise ex
 
 
-# Use default value from trove.common.cfg, and it could be overridden by
-# a environment variable when the tests run.
-def get_resize_timeout():
-    value_from_env = os.environ.get("TROVE_RESIZE_TIME_OUT", None)
-    if value_from_env:
-        return int(value_from_env)
-
-    return cfg.CONF.resize_time_out
-
-
-TIME_OUT_TIME = get_resize_timeout()
+TIME_OUT_TIME = 15 * 60
+USER_WAS_DELETED = False
 
 
 class ActionTestBase(object):
@@ -117,10 +111,6 @@ class ActionTestBase(object):
     def instance_address(self):
         return instance_info.get_address()
 
-    @property
-    def instance_mgmt_address(self):
-        return instance_info.get_address(mgmt=True)
-
     @property
     def instance_id(self):
         return instance_info.id
@@ -141,40 +131,28 @@ class ActionTestBase(object):
             time.sleep(5)
 
     def ensure_mysql_is_running(self):
-        if USE_IP:
-            self.connection.connect()
-            asserts.assert_true(self.connection.is_connected(),
-                                "Unable to connect to MySQL.")
-
-            self.proc_id = self.find_mysql_proc_on_instance()
-            asserts.assert_is_not_none(self.proc_id,
-                                       "MySQL process can not be found.")
-
-        asserts.assert_is_not_none(self.instance)
-        asserts.assert_true(self.instance.status in CONFIG.running_status)
+        """Make sure MySQL is accessible before restarting."""
+        with Checker() as check:
+            if USE_IP:
+                self.connection.connect()
+                check.true(self.connection.is_connected(),
+                           "Able to connect to MySQL.")
+                self.proc_id = self.find_mysql_proc_on_instance()
+                check.true(self.proc_id is not None,
+                           "MySQL process can not be found.")
+            instance = self.instance
+            check.false(instance is None)
+            check.equal(instance.status, "ACTIVE")
 
     def find_mysql_proc_on_instance(self):
-        server = create_server_connection(
-            self.instance_id,
-            ip_address=self.instance_mgmt_address
-        )
-        container_exist_cmd = 'sudo docker ps -q'
-        pid_cmd = "sudo docker inspect database -f '{{.State.Pid}}'"
-
+        server = create_server_connection(self.instance_id)
+        cmd = "ps aux | grep /usr/sbin/mysqld " \
+              "| awk '{print $2}'"
+        stdout, stderr = server.execute(cmd)
         try:
-            server.execute(container_exist_cmd)
-        except Exception as err:
-            asserts.fail("Failed to execute command: %s, error: %s" %
-                         (container_exist_cmd, str(err)))
-
-        try:
-            stdout = server.execute(pid_cmd)
             return int(stdout)
         except ValueError:
             return None
-        except Exception as err:
-            asserts.fail("Failed to execute command: %s, error: %s" %
-                         (pid_cmd, str(err)))
 
     def log_current_users(self):
         users = self.dbaas.users.list(self.instance_id)
@@ -196,7 +174,7 @@ class ActionTestBase(object):
         return expected
 
 
-@test(depends_on_groups=[tests.DBAAS_API_INSTANCES])
+@test(depends_on_groups=[GROUP_START])
 def create_user():
     """Create a test user so that subsequent tests can log in."""
     helper = ActionTestBase()
@@ -217,26 +195,24 @@ class RebootTestBase(ActionTestBase):
     def call_reboot(self):
         raise NotImplementedError()
 
+    def wait_for_broken_connection(self):
+        """Wait until our connection breaks."""
+        if not USE_IP:
+            return
+        if not hasattr(self, "connection"):
+            return
+        poll_until(self.connection.is_connected,
+                   lambda connected: not connected,
+                   time_out=TIME_OUT_TIME)
+
     def wait_for_successful_restart(self):
-        """Wait until status becomes running.
-
-        Reboot is an async operation, make sure the instance is rebooting
-        before active.
-        """
-        def _is_rebooting():
-            instance = self.instance
-            if instance.status == "REBOOT":
-                return True
-            return False
-
-        poll_until(_is_rebooting, time_out=TIME_OUT_TIME)
-
+        """Wait until status becomes running."""
         def is_finished_rebooting():
             instance = self.instance
-            asserts.assert_not_equal(instance.status, "ERROR")
-            if instance.status in CONFIG.running_status:
-                return True
-            return False
+            if instance.status == "REBOOT":
+                return False
+            asserts.assert_equal("ACTIVE", instance.status)
+            return True
 
         poll_until(is_finished_rebooting, time_out=TIME_OUT_TIME)
 
@@ -249,15 +225,36 @@ class RebootTestBase(ActionTestBase):
 
     def successful_restart(self):
         """Restart MySQL via the REST API successfully."""
+        self.fix_mysql()
         self.call_reboot()
+        self.wait_for_broken_connection()
         self.wait_for_successful_restart()
         self.assert_mysql_proc_is_different()
 
+    def mess_up_mysql(self):
+        """Ruin MySQL's ability to restart."""
+        server = create_server_connection(self.instance_id)
+        cmd = "sudo cp /dev/null /var/lib/mysql/ib_logfile%d"
+        instance_info.dbaas_admin.management.stop(self.instance_id)
+        for index in range(2):
+            server.execute(cmd % index)
+
+    def fix_mysql(self):
+        """Fix MySQL's ability to restart."""
+        if not FAKE_MODE:
+            server = create_server_connection(self.instance_id)
+            cmd = "sudo rm /var/lib/mysql/ib_logfile%d"
+            # We want to stop mysql so that upstart does not keep trying to
+            # respawn it and block the guest agent from accessing the logs.
+            instance_info.dbaas_admin.management.stop(self.instance_id)
+            for index in range(2):
+                server.execute(cmd % index)
+
     def wait_for_failure_status(self):
         """Wait until status becomes running."""
         def is_finished_rebooting():
             instance = self.instance
-            if instance.status in ['REBOOT', 'ACTIVE', 'HEALTHY']:
+            if instance.status == "REBOOT" or instance.status == "ACTIVE":
                 return False
             # The reason we check for BLOCKED as well as SHUTDOWN is because
             # Upstart might try to bring mysql back up after the borked
@@ -267,21 +264,24 @@ class RebootTestBase(ActionTestBase):
 
         poll_until(is_finished_rebooting, time_out=TIME_OUT_TIME)
 
-    def wait_for_status(self, status, timeout=60, sleep_time=5):
-        def is_status():
-            instance = self.instance
-            if instance.status in status:
-                return True
-            return False
+    def unsuccessful_restart(self):
+        """Restart MySQL via the REST when it should fail, assert it does."""
+        assert not FAKE_MODE
+        self.mess_up_mysql()
+        self.call_reboot()
+        self.wait_for_broken_connection()
+        self.wait_for_failure_status()
 
-        poll_until(is_status, time_out=timeout, sleep_time=sleep_time)
+    def restart_normally(self):
+        """Fix iblogs and reboot normally."""
+        self.fix_mysql()
+        self.test_successful_restart()
 
 
-@test(groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
-      depends_on_groups=[tests.DBAAS_API_DATABASES],
-      depends_on=[create_user])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_RESTART],
+      depends_on_groups=[GROUP_START], depends_on=[create_user])
 class RestartTests(RebootTestBase):
-    """Test restarting MySQL."""
+    """Tests restarting MySQL."""
 
     def call_reboot(self):
         self.instance.restart()
@@ -296,16 +296,24 @@ class RestartTests(RebootTestBase):
         """Make sure MySQL is accessible before restarting."""
         self.ensure_mysql_is_running()
 
-    @test(depends_on=[test_ensure_mysql_is_running])
+    @test(depends_on=[test_ensure_mysql_is_running], enabled=not FAKE_MODE)
+    def test_unsuccessful_restart(self):
+        """Restart MySQL via the REST when it should fail, assert it does."""
+        if FAKE_MODE:
+            raise SkipTest("Cannot run this in fake mode.")
+        self.unsuccessful_restart()
+
+    @test(depends_on=[test_set_up],
+          runs_after=[test_ensure_mysql_is_running, test_unsuccessful_restart])
     def test_successful_restart(self):
         """Restart MySQL via the REST API successfully."""
         self.successful_restart()
 
 
-@test(groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
-      depends_on_classes=[RestartTests])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_STOP_MYSQL],
+      depends_on_groups=[GROUP_START], depends_on=[create_user])
 class StopTests(RebootTestBase):
-    """Test stopping MySQL."""
+    """Tests which involve stopping MySQL."""
 
     def call_reboot(self):
         self.instance.restart()
@@ -321,14 +329,13 @@ class StopTests(RebootTestBase):
 
     @test(depends_on=[test_ensure_mysql_is_running])
     def test_stop_mysql(self):
-        """Stops MySQL by admin."""
+        """Stops MySQL."""
         instance_info.dbaas_admin.management.stop(self.instance_id)
-
-        # The instance status will only be updated by guest agent.
-        self.wait_for_status(['SHUTDOWN'], timeout=90, sleep_time=10)
+        self.wait_for_broken_connection()
+        self.wait_for_failure_status()
 
     @test(depends_on=[test_stop_mysql])
-    def test_volume_info_while_mysql_is_down(self):
+    def test_instance_get_shows_volume_info_while_mysql_is_down(self):
         """
         Confirms the get call behaves appropriately while an instance is
         down.
@@ -343,16 +350,17 @@ class StopTests(RebootTestBase):
             check.true(isinstance(instance.volume.get('size', None), int))
             check.true(isinstance(instance.volume.get('used', None), float))
 
-    @test(depends_on=[test_volume_info_while_mysql_is_down])
-    def test_successful_restart_from_shutdown(self):
+    @test(depends_on=[test_set_up],
+          runs_after=[test_instance_get_shows_volume_info_while_mysql_is_down])
+    def test_successful_restart_when_in_shutdown_state(self):
         """Restart MySQL via the REST API successfully when MySQL is down."""
         self.successful_restart()
 
 
-@test(groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
-      depends_on_classes=[StopTests])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_REBOOT],
+      depends_on_groups=[GROUP_START], depends_on=[RestartTests, create_user])
 class RebootTests(RebootTestBase):
-    """Test restarting instance."""
+    """Tests restarting instance."""
 
     def call_reboot(self):
         instance_info.dbaas_admin.management.reboot(self.instance_id)
@@ -365,33 +373,47 @@ class RebootTests(RebootTestBase):
 
     @test
     def test_ensure_mysql_is_running(self):
-        """Make sure MySQL is accessible before rebooting."""
+        """Make sure MySQL is accessible before restarting."""
         self.ensure_mysql_is_running()
 
-    @after_class(depends_on=[test_ensure_mysql_is_running])
-    def test_successful_reboot(self):
-        """MySQL process is different after rebooting."""
+    @test(depends_on=[test_ensure_mysql_is_running])
+    def test_unsuccessful_restart(self):
+        """Restart MySQL via the REST when it should fail, assert it does."""
         if FAKE_MODE:
             raise SkipTest("Cannot run this in fake mode.")
+        self.unsuccessful_restart()
+
+    @after_class(depends_on=[test_set_up])
+    def test_successful_restart(self):
+        """Restart MySQL via the REST API successfully."""
         self.successful_restart()
 
 
-@test(groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
-      depends_on_classes=[RebootTests])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP,
+              GROUP + ".resize.instance"],
+      depends_on_groups=[GROUP_START], depends_on=[create_user],
+      runs_after=[RebootTests])
 class ResizeInstanceTest(ActionTestBase):
-    """Test resizing instance."""
+
+    """
+    Integration Test cases for resize instance
+    """
     @property
     def flavor_id(self):
         return instance_info.dbaas_flavor_href
 
+    def get_flavor_href(self, flavor_id=2):
+        res = instance_info.dbaas.find_flavor_and_self_href(flavor_id)
+        dbaas_flavor, dbaas_flavor_href = res
+        return dbaas_flavor_href
+
     def wait_for_resize(self):
         def is_finished_resizing():
             instance = self.instance
             if instance.status == "RESIZE":
                 return False
-            asserts.assert_true(instance.status in CONFIG.running_status)
+            asserts.assert_equal("ACTIVE", instance.status)
             return True
-
         poll_until(is_finished_resizing, time_out=TIME_OUT_TIME)
 
     @before_class
@@ -401,6 +423,7 @@ class ResizeInstanceTest(ActionTestBase):
             self.connection.connect()
             asserts.assert_true(self.connection.is_connected(),
                                 "Should be able to connect before resize.")
+        self.user_was_deleted = False
 
     @test
     def test_instance_resize_same_size_should_fail(self):
@@ -411,82 +434,76 @@ class ResizeInstanceTest(ActionTestBase):
     def test_instance_resize_to_ephemeral_in_volume_support_should_fail(self):
         flavor_name = CONFIG.values.get('instance_bigger_eph_flavor_name',
                                         'eph.rd-smaller')
-        flavor_id = None
-        for item in instance_info.flavors:
-            if item.name == flavor_name:
-                flavor_id = item.id
-
-        asserts.assert_is_not_none(flavor_id)
+        flavors = self.dbaas.find_flavors_by_name(flavor_name)
 
         def is_active():
-            return self.instance.status in CONFIG.running_status
-
+            return self.instance.status == 'ACTIVE'
         poll_until(is_active, time_out=TIME_OUT_TIME)
-        asserts.assert_true(self.instance.status in CONFIG.running_status)
+        asserts.assert_equal(self.instance.status, 'ACTIVE')
 
+        self.get_flavor_href(
+            flavor_id=self.expected_old_flavor_id)
         asserts.assert_raises(HTTPNotImplemented,
                               self.dbaas.instances.resize_instance,
-                              self.instance_id, flavor_id)
+                              self.instance_id, flavors[0].id)
 
     @test(enabled=EPHEMERAL_SUPPORT)
     def test_instance_resize_to_non_ephemeral_flavor_should_fail(self):
         flavor_name = CONFIG.values.get('instance_bigger_flavor_name',
                                         'm1-small')
-        flavor_id = None
-        for item in instance_info.flavors:
-            if item.name == flavor_name:
-                flavor_id = item.id
-
-        asserts.assert_is_not_none(flavor_id)
+        flavors = self.dbaas.find_flavors_by_name(flavor_name)
         asserts.assert_raises(BadRequest, self.dbaas.instances.resize_instance,
-                              self.instance_id, flavor_id)
+                              self.instance_id, flavors[0].id)
 
     def obtain_flavor_ids(self):
         old_id = self.instance.flavor['id']
         self.expected_old_flavor_id = old_id
+        res = instance_info.dbaas.find_flavor_and_self_href(old_id)
+        self.expected_dbaas_flavor, _dontcare_ = res
         if EPHEMERAL_SUPPORT:
             flavor_name = CONFIG.values.get('instance_bigger_eph_flavor_name',
                                             'eph.rd-smaller')
         else:
             flavor_name = CONFIG.values.get('instance_bigger_flavor_name',
                                             'm1.small')
-
-        new_flavor = None
-        for item in instance_info.flavors:
-            if item.name == flavor_name:
-                new_flavor = item
-                break
-
-        asserts.assert_is_not_none(new_flavor)
-
+        flavors = self.dbaas.find_flavors_by_name(flavor_name)
+        asserts.assert_equal(len(flavors), 1,
+                             "Number of flavors with name '%s' "
+                             "found was '%d'." % (flavor_name,
+                                                  len(flavors)))
+        flavor = flavors[0]
         self.old_dbaas_flavor = instance_info.dbaas_flavor
-        instance_info.dbaas_flavor = new_flavor
-        self.expected_new_flavor_id = new_flavor.id
+        instance_info.dbaas_flavor = flavor
+        asserts.assert_true(flavor is not None,
+                            "Flavor '%s' not found!" % flavor_name)
+        flavor_href = self.dbaas.find_flavor_self_href(flavor)
+        asserts.assert_true(flavor_href is not None,
+                            "Flavor href '%s' not found!" % flavor_name)
+        self.expected_new_flavor_id = flavor.id
 
     @test(depends_on=[test_instance_resize_same_size_should_fail])
     def test_status_changed_to_resize(self):
-        """test_status_changed_to_resize"""
         self.log_current_users()
         self.obtain_flavor_ids()
         self.dbaas.instances.resize_instance(
             self.instance_id,
-            self.expected_new_flavor_id)
+            self.get_flavor_href(flavor_id=self.expected_new_flavor_id))
         asserts.assert_equal(202, self.dbaas.last_http_code)
 
-        # (WARNING) IF THE RESIZE IS WAY TOO FAST THIS WILL FAIL
+        #(WARNING) IF THE RESIZE IS WAY TOO FAST THIS WILL FAIL
         assert_unprocessable(
             self.dbaas.instances.resize_instance,
             self.instance_id,
-            self.expected_new_flavor_id)
+            self.get_flavor_href(flavor_id=self.expected_new_flavor_id))
 
     @test(depends_on=[test_status_changed_to_resize])
     @time_out(TIME_OUT_TIME)
     def test_instance_returns_to_active_after_resize(self):
-        """test_instance_returns_to_active_after_resize"""
         self.wait_for_resize()
 
     @test(depends_on=[test_instance_returns_to_active_after_resize,
-                      test_status_changed_to_resize])
+                      test_status_changed_to_resize],
+          groups=["dbaas.usage"])
     def test_resize_instance_usage_event_sent(self):
         expected = self._build_expected_msg()
         expected['old_instance_size'] = self.old_dbaas_flavor.ram
@@ -502,28 +519,74 @@ class ResizeInstanceTest(ActionTestBase):
         # a resize. The code below is an attempt to catch this while proceeding
         # with the rest of the test (note the use of runs_after).
         if USE_IP:
-            users = self.dbaas.users.list(self.instance_id)
-            usernames = [user.name for user in users]
-            if MYSQL_USERNAME not in usernames:
+            self.connection.connect()
+            if not self.connection.is_connected():
+                # Ok, this is def. a failure, but before we toss up an error
+                # lets recreate to see how far we can get.
+                CONFIG.get_report().log(
+                    "Having to recreate the test_user! Resizing killed it!")
+                self.log_current_users()
                 self.create_user()
-                asserts.fail("Resize made the test user disappear.")
+                fail("Somehow, the resize made the test user disappear.")
 
     @test(depends_on=[test_instance_returns_to_active_after_resize],
           runs_after=[resize_should_not_delete_users])
     def test_make_sure_mysql_is_running_after_resize(self):
         self.ensure_mysql_is_running()
 
-    @test(depends_on=[test_make_sure_mysql_is_running_after_resize])
+    @test(depends_on=[test_instance_returns_to_active_after_resize],
+          runs_after=[test_make_sure_mysql_is_running_after_resize])
     def test_instance_has_new_flavor_after_resize(self):
-        actual = self.instance.flavor['id']
-        asserts.assert_equal(actual, self.expected_new_flavor_id)
+        actual = self.get_flavor_href(self.instance.flavor['id'])
+        expected = self.get_flavor_href(flavor_id=self.expected_new_flavor_id)
+        asserts.assert_equal(actual, expected)
+
+    @test(depends_on=[test_instance_has_new_flavor_after_resize])
+    @time_out(TIME_OUT_TIME)
+    def test_resize_down(self):
+        expected_dbaas_flavor = self.expected_dbaas_flavor
+
+        def is_active():
+            return self.instance.status == 'ACTIVE'
+        poll_until(is_active, time_out=TIME_OUT_TIME)
+        asserts.assert_equal(self.instance.status, 'ACTIVE')
+
+        old_flavor_href = self.get_flavor_href(
+            flavor_id=self.expected_old_flavor_id)
+
+        self.dbaas.instances.resize_instance(self.instance_id, old_flavor_href)
+        asserts.assert_equal(202, self.dbaas.last_http_code)
+        self.old_dbaas_flavor = instance_info.dbaas_flavor
+        instance_info.dbaas_flavor = expected_dbaas_flavor
+        self.wait_for_resize()
+        asserts.assert_equal(str(self.instance.flavor['id']),
+                             str(self.expected_old_flavor_id))
+
+    @test(depends_on=[test_resize_down],
+          groups=["dbaas.usage"])
+    def test_resize_instance_down_usage_event_sent(self):
+        expected = self._build_expected_msg()
+        expected['old_instance_size'] = self.old_dbaas_flavor.ram
+        instance_info.consumer.check_message(instance_info.id,
+                                             'trove.instance.modify_flavor',
+                                             **expected)
 
 
-@test(depends_on_classes=[ResizeInstanceTest],
-      groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP,
+              GROUP + ".resize.instance"],
+      depends_on_groups=[GROUP_START], depends_on=[create_user],
+      runs_after=[RebootTests, ResizeInstanceTest])
+def resize_should_not_delete_users():
+    if USER_WAS_DELETED:
+        fail("Somehow, the resize made the test user disappear.")
+
+
+@test(runs_after=[ResizeInstanceTest], depends_on=[create_user],
+      groups=[GROUP, tests.INSTANCES],
       enabled=VOLUME_SUPPORT)
-class ResizeInstanceVolumeTest(ActionTestBase):
-    """Resize the volume of the instance."""
+class ResizeInstanceVolume(ActionTestBase):
+    """Resize the volume of the instance """
+
     @before_class
     def setUp(self):
         self.set_up()
@@ -541,31 +604,28 @@ class ResizeInstanceVolumeTest(ActionTestBase):
     @test
     @time_out(60)
     def test_volume_resize(self):
-        """test_volume_resize"""
         instance_info.dbaas.instances.resize_volume(instance_info.id,
                                                     self.new_volume_size)
 
     @test(depends_on=[test_volume_resize])
+    @time_out(300)
     def test_volume_resize_success(self):
-        """test_volume_resize_success"""
 
         def check_resize_status():
             instance = instance_info.dbaas.instances.get(instance_info.id)
-            if instance.status in CONFIG.running_status:
+            if instance.status == "ACTIVE":
                 return True
-            elif instance.status in ["RESIZE", "SHUTDOWN"]:
+            elif instance.status == "RESIZE":
                 return False
             else:
-                asserts.fail("Status should not be %s" % instance.status)
+                fail("Status should not be %s" % instance.status)
 
-        poll_until(check_resize_status, sleep_time=5, time_out=300,
-                   initial_delay=5)
+        poll_until(check_resize_status, sleep_time=2, time_out=300)
         instance = instance_info.dbaas.instances.get(instance_info.id)
         asserts.assert_equal(instance.volume['size'], self.new_volume_size)
 
     @test(depends_on=[test_volume_resize_success])
     def test_volume_filesystem_resize_success(self):
-        """test_volume_filesystem_resize_success"""
         # The get_volume_filesystem_size is a mgmt call through the guestagent
         # and the volume resize occurs through the fake nova-volume.
         # Currently the guestagent fakes don't have access to the nova fakes so
@@ -579,9 +639,8 @@ class ResizeInstanceVolumeTest(ActionTestBase):
         # cinder volume but it should round to it. (e.g. round(1.9) == 2)
         asserts.assert_equal(round(new_volume_fs_size), self.new_volume_size)
 
-    @test(depends_on=[test_volume_resize_success])
+    @test(depends_on=[test_volume_resize_success], groups=["dbaas.usage"])
     def test_resize_volume_usage_event_sent(self):
-        """test_resize_volume_usage_event_sent"""
         expected = self._build_expected_msg()
         expected['volume_size'] = self.new_volume_size
         expected['old_volume_size'] = self.old_volume_size
@@ -589,15 +648,67 @@ class ResizeInstanceVolumeTest(ActionTestBase):
                                              'trove.instance.modify_volume',
                                              **expected)
 
-    @test(depends_on=[test_volume_resize_success])
+    @test
+    @time_out(300)
     def test_volume_resize_success_databases(self):
-        """test_volume_resize_success_databases"""
         databases = instance_info.dbaas.databases.list(instance_info.id)
         db_list = []
         for database in databases:
             db_list.append(database.name)
         for name in self.expected_dbs:
             if name not in db_list:
-                asserts.fail(
-                    "Database %s was not found after the volume resize. "
-                    "Returned list: %s" % (name, databases))
+                fail("Database %s was not found after the volume resize. "
+                     "Returned list: %s" % (name, databases))
+
+
+# This tests the ability of the guest to upgrade itself.
+# It is necessarily tricky because we need to be able to upload a new copy of
+# the guest into an apt-repo in the middle of the test.
+# "guest-update-test" is where the knowledge of how to do this is set in the
+# test conf. If it is not specified this test never runs.
+UPDATE_GUEST_CONF = CONFIG.values.get("guest-update-test", None)
+
+
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP + ".update_guest"],
+      depends_on=[create_user],
+      depends_on_groups=[GROUP_START])
+class UpdateGuest(object):
+
+    def get_version(self):
+        info = instance_info.dbaas_admin.diagnostics.get(instance_info.id)
+        return info.version
+
+    @before_class(enabled=UPDATE_GUEST_CONF is not None)
+    def check_version_is_old(self):
+        """Make sure we have the old version before proceeding."""
+        self.old_version = self.get_version()
+        self.next_version = UPDATE_GUEST_CONF["next-version"]
+        asserts.assert_not_equal(self.old_version, self.next_version)
+
+    @test(enabled=UPDATE_GUEST_CONF is not None)
+    def upload_update_to_repo(self):
+        cmds = UPDATE_GUEST_CONF["install-repo-cmd"]
+        testsutil.execute(*cmds, run_as_root=True, root_helper="sudo")
+
+    @test(enabled=UPDATE_GUEST_CONF is not None,
+          depends_on=[upload_update_to_repo])
+    def update_and_wait_to_finish(self):
+        instance_info.dbaas_admin.management.update(instance_info.id)
+
+        def finished():
+            current_version = self.get_version()
+            if current_version == self.next_version:
+                return True
+            # The only valid thing for it to be aside from next_version is
+            # old version.
+            assert_equal(current_version, self.old_version)
+        poll_until(finished, sleep_time=1, time_out=3 * 60)
+
+    @test(enabled=UPDATE_GUEST_CONF is not None,
+          depends_on=[upload_update_to_repo])
+    @time_out(30)
+    def update_again(self):
+        """Test the wait time of a pointless update."""
+        instance_info.dbaas_admin.management.update(instance_info.id)
+        # Make sure this isn't taking too long.
+        instance_info.dbaas_admin.diagnostics.get(instance_info.id)
