@@ -16,39 +16,24 @@
 #    under the License.
 #
 
-from datetime import datetime
-
 from nose.tools import assert_equal
 from nose.tools import assert_true
-from oslo_utils import timeutils
+
 from proboscis import before_class
 from proboscis import test
-from troveclient.compat import exceptions
 
-from trove.common import cfg
-from trove.tests.fakes import limits as fake_limits
+from trove.openstack.common import timeutils
 from trove.tests.util import create_dbaas_client
+from troveclient.compat import exceptions
+from datetime import datetime
 from trove.tests.util.users import Users
-
-
-CONF = cfg.CONF
+from trove.tests.config import CONFIG
 
 GROUP = "dbaas.api.limits"
-DEFAULT_RATE = CONF.http_get_rate
-
-DEFAULT_MAX_VOLUMES = CONF.max_volumes_per_tenant
-DEFAULT_MAX_INSTANCES = CONF.max_instances_per_tenant
-DEFAULT_MAX_BACKUPS = CONF.max_backups_per_tenant
-DEFAULT_MAX_RAM = CONF.max_ram_per_tenant
-
-
-def ensure_limits_are_not_faked(func):
-    def _cd(*args, **kwargs):
-        fake_limits.ENABLED = True
-        try:
-            return func(*args, **kwargs)
-        finally:
-            fake_limits.ENABLED = False
+DEFAULT_RATE = 200
+DEFAULT_MAX_VOLUMES = 100
+DEFAULT_MAX_INSTANCES = 55
+DEFAULT_MAX_BACKUPS = 5
 
 
 @test(groups=[GROUP])
@@ -90,41 +75,39 @@ class Limits(object):
         dt_now = datetime.now()
         return dt_next.time() < dt_now.time()
 
-    # def _get_limits_as_dict(self, limits):
-    #     d = {}
-    #     for limit in limits:
-    #         d[l.verb] = limit
-    #     return d
+    def _get_limits_as_dict(self, limits):
+        d = {}
+        for l in limits:
+            d[l.verb] = l
+        return d
 
-    # @test
-    # @ensure_limits_are_not_faked
-    # def test_limits_index(self):
-    #     """Test_limits_index."""
+    @test
+    def test_limits_index(self):
+        """test_limits_index"""
 
-    #     limits = self.rd_client.limits.list()
-    #     d = self._get_limits_as_dict(limits)
+        limits = self.rd_client.limits.list()
+        d = self._get_limits_as_dict(limits)
 
-    #     # remove the abs_limits from the rate limits
-    #     abs_limits = d.pop("ABSOLUTE", None)
-    #     assert_equal(abs_limits.verb, "ABSOLUTE")
-    #     assert_equal(int(abs_limits.max_instances), DEFAULT_MAX_INSTANCES)
-    #     assert_equal(int(abs_limits.max_backups), DEFAULT_MAX_BACKUPS)
-    #     assert_equal(int(abs_limits.max_volumes), DEFAULT_MAX_VOLUMES)
-    #     assert_equal(int(abs_limits.max_ram), DEFAULT_MAX_RAM)
+        # remove the abs_limits from the rate limits
+        abs_limits = d.pop("ABSOLUTE", None)
+        assert_equal(abs_limits.verb, "ABSOLUTE")
+        assert_equal(int(abs_limits.max_instances), DEFAULT_MAX_INSTANCES)
+        assert_equal(int(abs_limits.max_backups), DEFAULT_MAX_BACKUPS)
+        if CONFIG.trove_volume_support:
+            assert_equal(int(abs_limits.max_volumes), DEFAULT_MAX_VOLUMES)
 
-    #     for k in d:
-    #         assert_equal(d[k].verb, k)
-    #         assert_equal(d[k].unit, "MINUTE")
-    #         assert_true(int(d[k].remaining) <= DEFAULT_RATE)
-    #         assert_true(d[k].nextAvailable is not None)
+        for k in d:
+            assert_equal(d[k].verb, k)
+            assert_equal(d[k].unit, "MINUTE")
+            assert_true(int(d[k].remaining) <= DEFAULT_RATE)
+            assert_true(d[k].nextAvailable is not None)
 
     @test
-    @ensure_limits_are_not_faked
     def test_limits_get_remaining(self):
-        """Test_limits_get_remaining."""
+        """test_limits_get_remaining"""
 
         limits = ()
-        for i in range(5):
+        for i in xrange(5):
             limits = self.rd_client.limits.list()
 
         d = self._get_limits_as_dict(limits)
@@ -133,17 +116,16 @@ class Limits(object):
 
         assert_equal(int(abs_limits.max_instances), DEFAULT_MAX_INSTANCES)
         assert_equal(int(abs_limits.max_backups), DEFAULT_MAX_BACKUPS)
-        assert_equal(int(abs_limits.max_volumes), DEFAULT_MAX_VOLUMES)
-        assert_equal(int(abs_limits.max_ram), DEFAULT_MAX_RAM)
+        if CONFIG.trove_volume_support:
+            assert_equal(int(abs_limits.max_volumes), DEFAULT_MAX_VOLUMES)
         assert_equal(get.verb, "GET")
         assert_equal(get.unit, "MINUTE")
         assert_true(int(get.remaining) <= DEFAULT_RATE - 5)
         assert_true(get.nextAvailable is not None)
 
     @test
-    @ensure_limits_are_not_faked
     def test_limits_exception(self):
-        """Test_limits_exception."""
+        """test_limits_exception"""
 
         # use a different user to avoid throttling tests run out of order
         rate_user_exceeded = self._get_user('rate_limit_exceeded')
@@ -151,7 +133,7 @@ class Limits(object):
 
         get = None
         encountered = False
-        for i in range(DEFAULT_RATE + 50):
+        for i in xrange(DEFAULT_RATE + 50):
             try:
                 limits = rd_client.limits.list()
                 d = self._get_limits_as_dict(limits)
@@ -164,10 +146,9 @@ class Limits(object):
                              DEFAULT_MAX_INSTANCES)
                 assert_equal(int(abs_limits.max_backups),
                              DEFAULT_MAX_BACKUPS)
-                assert_equal(int(abs_limits.max_volumes),
-                             DEFAULT_MAX_VOLUMES)
-                assert_equal(int(abs_limits.max_ram,),
-                             DEFAULT_MAX_RAM)
+                if CONFIG.trove_volume_support:
+                    assert_equal(int(abs_limits.max_volumes),
+                                 DEFAULT_MAX_VOLUMES)
 
             except exceptions.OverLimit:
                 encountered = True
