@@ -12,34 +12,34 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from proboscis.asserts import assert_equal
-from proboscis.asserts import assert_raises
-from proboscis import before_class
-from proboscis.check import Check
-from proboscis import SkipTest
-from proboscis import test
-import six
 from troveclient.compat import exceptions
 
-from trove.common.utils import poll_until
-from trove.tests.api.instances import CreateInstance
-from trove.tests.api.instances import GROUP_START
-from trove.tests.api.instances import GROUP_TEST
-from trove.tests.api.instances import instance_info
+from proboscis import before_class
+from proboscis import test
+from proboscis.asserts import assert_equal
+from proboscis.asserts import assert_raises
+from proboscis.check import Check
+from proboscis import SkipTest
+
 from trove.tests.config import CONFIG
-from trove.tests.util.check import CollectionCheck
-from trove.tests.util.check import TypeCheck
 from trove.tests.util import create_client
 from trove.tests.util import create_dbaas_client
 from trove.tests.util.users import Requirements
+from trove.tests.util.check import CollectionCheck
+from trove.tests.util.check import TypeCheck
 
+from trove.tests.api.instances import CreateInstance
+from trove.tests.api.instances import instance_info
+from trove.tests.api.instances import GROUP_START
+from trove.tests.api.instances import GROUP_TEST
+from trove.common.utils import poll_until
 
 GROUP = "dbaas.api.mgmt.instances"
 
 
 @test(groups=[GROUP])
 def mgmt_index_requires_admin_account():
-    """Verify that an admin context is required to call this function."""
+    """Verify that an admin context is required to call this function. """
     client = create_client(is_admin=False)
     assert_raises(exceptions.Unauthorized, client.management.index)
 
@@ -47,24 +47,24 @@ def mgmt_index_requires_admin_account():
 # These functions check some dictionaries in the returned response.
 def flavor_check(flavor):
     with CollectionCheck("flavor", flavor) as check:
-        check.has_element("id", six.string_types)
+        check.has_element("id", basestring)
         check.has_element("links", list)
 
 
 def datastore_check(datastore):
     with CollectionCheck("datastore", datastore) as check:
-        check.has_element("type", six.string_types)
-        check.has_element("version", six.string_types)
+        check.has_element("type", basestring)
+        check.has_element("version", basestring)
 
 
 def guest_status_check(guest_status):
     with CollectionCheck("guest_status", guest_status) as check:
-        check.has_element("state_description", six.string_types)
+        check.has_element("state_description", basestring)
 
 
 def volume_check(volume):
     with CollectionCheck("volume", volume) as check:
-        check.has_element("id", six.string_types)
+        check.has_element("id", basestring)
         check.has_element("size", int)
         check.has_element("used", float)
         check.has_element("total", float)
@@ -72,7 +72,7 @@ def volume_check(volume):
 
 @test(depends_on_groups=[GROUP_START], groups=[GROUP, GROUP_TEST])
 def mgmt_instance_get():
-    """Tests the mgmt instances index method."""
+    """Tests the mgmt instances index method. """
     reqs = Requirements(is_admin=True)
     user = CONFIG.users.find_user(reqs)
     client = create_dbaas_client(user)
@@ -81,35 +81,32 @@ def mgmt_instance_get():
     # a global.
     id = instance_info.id
     api_instance = mgmt.show(id)
-    datastore = getattr(api_instance, 'datastore')
-    datastore_type = datastore.get('type')
 
     # Print out all fields for extra info if the test fails.
     for name in dir(api_instance):
         print(str(name) + "=" + str(getattr(api_instance, name)))
     with TypeCheck("instance", api_instance) as instance:
-        instance.has_field('created', six.string_types)
+        instance.has_field('created', basestring)
         instance.has_field('deleted', bool)
         # If the instance hasn't been deleted, this should be false... but
         # lets avoid creating more ordering work.
-        instance.has_field('deleted_at', (six.string_types, None))
+        instance.has_field('deleted_at', (basestring, None))
         instance.has_field('flavor', dict, flavor_check)
         instance.has_field('datastore', dict, datastore_check)
         instance.has_field('guest_status', dict, guest_status_check)
-        instance.has_field('id', six.string_types)
+        instance.has_field('id', basestring)
         instance.has_field('links', list)
-        instance.has_field('name', six.string_types)
-        # instance.has_field('server_status', six.string_types)
-        instance.has_field('status', six.string_types)
-        instance.has_field('tenant_id', six.string_types)
-        instance.has_field('updated', six.string_types)
+        instance.has_field('name', basestring)
+        #instance.has_field('server_status', basestring)
+        instance.has_field('status', basestring)
+        instance.has_field('tenant_id', basestring)
+        instance.has_field('updated', basestring)
         # Can be None if no volume is given on this instance.
-        volume_support = CONFIG.get(datastore_type, 'mysql')['volume_support']
-        if volume_support:
+        if CONFIG.trove_volume_support:
             instance.has_field('volume', dict, volume_check)
         else:
             instance.has_field('volume', None)
-        # TODO(tim-simpson): Validate additional fields, assert
+        #TODO(tim-simpson): Validate additional fields, assert
         # no extra fields exist.
     if api_instance.server is not None:
         print("the real content of server: %s" % dir(api_instance.server))
@@ -121,23 +118,23 @@ def mgmt_instance_get():
         with CollectionCheck("server", api_instance.server) as server:
             server.has_element("addresses", dict)
             server.has_element("deleted", bool)
-            server.has_element("deleted_at", (six.string_types, None))
-            server.has_element("host", six.string_types)
-            server.has_element("id", six.string_types)
+            server.has_element("deleted_at", (basestring, None))
+            server.has_element("host", basestring)
+            server.has_element("id", basestring)
             server.has_element("local_id", int)
-            server.has_element("name", six.string_types)
-            server.has_element("status", six.string_types)
-            server.has_element("tenant_id", six.string_types)
+            server.has_element("name", basestring)
+            server.has_element("status", basestring)
+            server.has_element("tenant_id", basestring)
 
-    if (volume_support and
+    if (CONFIG.trove_volume_support and
             CONFIG.trove_main_instance_has_volume):
         with CollectionCheck("volume", api_instance.volume) as volume:
             volume.has_element("attachments", list)
-            volume.has_element("availability_zone", six.string_types)
-            volume.has_element("created_at", (six.string_types, None))
-            volume.has_element("id", six.string_types)
+            volume.has_element("availability_zone", basestring)
+            volume.has_element("created_at", (basestring, None))
+            volume.has_element("id", basestring)
             volume.has_element("size", int)
-            volume.has_element("status", six.string_types)
+            volume.has_element("status", basestring)
 
 
 @test(groups=["fake." + GROUP])
@@ -154,24 +151,14 @@ class WhenMgmtInstanceGetIsCalledButServerIsNotReady(object):
         # Fake volume will fail if the size is 13.
         # TODO(tim.simpson): This would be a lot nicer looking if we used a
         #                    traditional mock framework.
-        datastore = {'type': 'mysql', 'version': '5.5'}
-        body = {'datastore': datastore}
-        vol_support = CONFIG.get(datastore['type'], 'mysql')['volume_support']
-        if vol_support:
-            body.update({'size': 13})
-
-        shared_network = CONFIG.get('shared_network', None)
-        if shared_network:
-            nics = [{'net-id': shared_network}]
-
+        body = None
+        if CONFIG.trove_volume_support:
+            body = {'size': 13}
         response = self.client.instances.create(
             'test_SERVER_ERROR',
             instance_info.dbaas_flavor_href,
             body,
-            [], [],
-            nics=nics
-        )
-
+            [])
         poll_until(lambda: self.client.instances.get(response.id),
                    lambda instance: instance.status == 'ERROR',
                    time_out=10)
@@ -188,31 +175,31 @@ class WhenMgmtInstanceGetIsCalledButServerIsNotReady(object):
         for name in dir(api_instance):
             print(str(name) + "=" + str(getattr(api_instance, name)))
         with TypeCheck("instance", api_instance) as instance:
-            instance.has_field('created', six.string_types)
+            instance.has_field('created', basestring)
             instance.has_field('deleted', bool)
             # If the instance hasn't been deleted, this should be false... but
             # lets avoid creating more ordering work.
-            instance.has_field('deleted_at', (six.string_types, None))
+            instance.has_field('deleted_at', (basestring, None))
             instance.has_field('flavor', dict, flavor_check)
             instance.has_field('datastore', dict, datastore_check)
             instance.has_field('guest_status', dict, guest_status_check)
-            instance.has_field('id', six.string_types)
+            instance.has_field('id', basestring)
             instance.has_field('links', list)
-            instance.has_field('name', six.string_types)
-            # instance.has_field('server_status', six.string_types)
-            instance.has_field('status', six.string_types)
-            instance.has_field('tenant_id', six.string_types)
-            instance.has_field('updated', six.string_types)
+            instance.has_field('name', basestring)
+            #instance.has_field('server_status', basestring)
+            instance.has_field('status', basestring)
+            instance.has_field('tenant_id', basestring)
+            instance.has_field('updated', basestring)
             # Can be None if no volume is given on this instance.
             instance.has_field('server', None)
             instance.has_field('volume', None)
-            # TODO(tim-simpson): Validate additional fields,
+            #TODO(tim-simpson): Validate additional fields,
             # assert no extra fields exist.
 
 
 @test(depends_on_classes=[CreateInstance], groups=[GROUP])
 class MgmtInstancesIndex(object):
-    """Tests the mgmt instances index method."""
+    """Tests the mgmt instances index method. """
 
     @before_class
     def setUp(self):
@@ -240,9 +227,7 @@ class MgmtInstancesIndex(object):
             'task_description',
             'tenant_id',
             'updated',
-            'region'
         ]
-
         if CONFIG.trove_volume_support:
             expected_fields.append('volume')
 
@@ -264,7 +249,6 @@ class MgmtInstancesIndex(object):
         Make sure that the deleted= filter works as expected, and no instances
         are excluded.
         """
-
         if not hasattr(self.client.management.index, 'deleted'):
             raise SkipTest("instance index must have a deleted "
                            "label for this test")
