@@ -12,37 +12,35 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from unittest import mock
-
-from novaclient.v2.servers import Server
-from proboscis import after_class
-from proboscis.asserts import assert_equal
-from proboscis.asserts import assert_raises
-from proboscis import before_class
-from proboscis import SkipTest
-from proboscis import test
-
+import mox
+import trove.common.instance as tr_instance
 from trove.backup import models as backup_models
-from trove.backup import state
 from trove.common.context import TroveContext
-from trove.common import exception
-from trove.extensions.mgmt.instances.models import MgmtInstance
-from trove.extensions.mgmt.instances.service import MgmtInstanceController
+from trove.instance.tasks import InstanceTasks
 from trove.instance import models as imodels
 from trove.instance.models import DBInstance
-from trove.instance import service_status as srvstatus
-from trove.instance.tasks import InstanceTasks
-from trove.tests.config import CONFIG
+from trove.extensions.mgmt.instances.models import MgmtInstance
 from trove.tests.util import create_dbaas_client
 from trove.tests.util import test_config
 from trove.tests.util.users import Requirements
 
+from novaclient.v1_1.servers import Server
+
+from proboscis import test
+from proboscis import before_class
+from proboscis import after_class
+from proboscis.asserts import assert_equal
+from proboscis.asserts import assert_raises
+from trove.common import exception
+from trove.extensions.mgmt.instances.service import MgmtInstanceController
+
 GROUP = "dbaas.api.mgmt.action.reset-task-status"
 
 
 class MgmtInstanceBase(object):
 
     def setUp(self):
+        self.mock = mox.Mox()
         self._create_instance()
         self.controller = MgmtInstanceController()
 
@@ -60,13 +58,13 @@ class MgmtInstanceBase(object):
             tenant_id=self.tenant_id,
             volume_size=None,
             task_status=InstanceTasks.NONE)
-        self.server = mock.MagicMock(spec=Server)
+        self.server = self.mock.CreateMock(Server)
         self.instance = imodels.Instance(
             self.context,
             self.db_info,
             self.server,
             datastore_status=imodels.InstanceServiceStatus(
-                srvstatus.ServiceStatuses.RUNNING))
+                tr_instance.ServiceStatuses.RUNNING))
 
     def _make_request(self, path='/', context=None, **kwargs):
         from webob import Request
@@ -81,7 +79,6 @@ class MgmtInstanceBase(object):
 
 @test(groups=[GROUP])
 class RestartTaskStatusTests(MgmtInstanceBase):
-
     @before_class
     def setUp(self):
         super(RestartTaskStatusTests, self).setUp()
@@ -103,15 +100,18 @@ class RestartTaskStatusTests(MgmtInstanceBase):
         return req, body
 
     def reset_task_status(self):
-        with mock.patch.object(MgmtInstance, 'load') as mock_load:
-            mock_load.return_value = self.instance
-            req, body = self._make_request(context=self.context)
-            self.controller = MgmtInstanceController()
-            resp = self.controller.action(req, body, self.tenant_id,
-                                          self.db_info.id)
+        self.mock.StubOutWithMock(MgmtInstance, 'load')
+        MgmtInstance.load(context=self.context,
+                          id=self.db_info.id).AndReturn(self.instance)
+        self.mock.ReplayAll()
 
-            mock_load.assert_called_once_with(context=self.context,
-                                              id=self.db_info.id)
+        req, body = self._make_request(context=self.context)
+        self.controller = MgmtInstanceController()
+        resp = self.controller.action(req, body, self.tenant_id,
+                                      self.db_info.id)
+
+        self.mock.UnsetStubs()
+        self.mock.VerifyAll()
         return resp
 
     @test
@@ -137,17 +137,12 @@ class RestartTaskStatusTests(MgmtInstanceBase):
 
     @test
     def mgmt_reset_task_status_clears_backups(self):
-        if CONFIG.fake_mode:
-            raise SkipTest("Test requires an instance.")
-
         self.reset_task_status()
         self._reload_db_info()
         assert_equal(self.db_info.task_status, InstanceTasks.NONE)
 
         user = test_config.users.find_user(Requirements(is_admin=False))
         dbaas = create_dbaas_client(user)
-        admin = test_config.users.find_user(Requirements(is_admin=True))
-        admin_dbaas = create_dbaas_client(admin)
         result = dbaas.instances.backups(self.db_info.id)
         assert_equal(0, len(result))
 
@@ -156,7 +151,7 @@ class RestartTaskStatusTests(MgmtInstanceBase):
             name="forever_new",
             description="forever new",
             tenant_id=self.tenant_id,
-            state=state.BackupState.NEW,
+            state=backup_models.BackupState.NEW,
             instance_id=self.db_info.id,
             deleted=False)
 
@@ -164,7 +159,7 @@ class RestartTaskStatusTests(MgmtInstanceBase):
             name="forever_build",
             description="forever build",
             tenant_id=self.tenant_id,
-            state=state.BackupState.BUILDING,
+            state=backup_models.BackupState.BUILDING,
             instance_id=self.db_info.id,
             deleted=False)
 
@@ -172,38 +167,33 @@ class RestartTaskStatusTests(MgmtInstanceBase):
             name="forever_completed",
             description="forever completed",
             tenant_id=self.tenant_id,
-            state=state.BackupState.COMPLETED,
+            state=backup_models.BackupState.COMPLETED,
             instance_id=self.db_info.id,
             deleted=False)
 
-        # List the backups for this instance.
-        # There ought to be three in the admin tenant, but
-        # none in a different user's tenant.
+        # List the backups for this instance. There ought to be three!
         result = dbaas.instances.backups(self.db_info.id)
-        assert_equal(0, len(result))
-        result = admin_dbaas.instances.backups(self.db_info.id)
         assert_equal(3, len(result))
         self.backups_to_clear = result
 
         # Reset the task status.
         self.reset_task_status()
         self._reload_db_info()
-        result = admin_dbaas.instances.backups(self.db_info.id)
+        result = dbaas.instances.backups(self.db_info.id)
         assert_equal(3, len(result))
         for backup in result:
             if backup.name == 'forever_completed':
                 assert_equal(backup.status,
-                             state.BackupState.COMPLETED)
+                             backup_models.BackupState.COMPLETED)
             else:
-                assert_equal(backup.status, state.BackupState.FAILED)
+                assert_equal(backup.status, backup_models.BackupState.FAILED)
 
     @test(runs_after=[mgmt_reset_task_status_clears_backups])
     def clear_test_backups(self):
         for backup in self.backups_to_clear:
             found_backup = backup_models.DBBackup.find_by(id=backup.id)
             found_backup.delete()
-        admin = test_config.users.find_user(Requirements(is_admin=True))
-        admin_dbaas = create_dbaas_client(admin)
-        if not CONFIG.fake_mode:
-            result = admin_dbaas.instances.backups(self.db_info.id)
-            assert_equal(0, len(result))
+        user = test_config.users.find_user(Requirements(is_admin=False))
+        dbaas = create_dbaas_client(user)
+        result = dbaas.instances.backups(self.db_info.id)
+        assert_equal(0, len(result))
