@@ -17,20 +17,18 @@
 #
 
 from collections import deque
-import six
-
-from proboscis import after_class
-from proboscis import asserts
-from proboscis import before_class
 from proboscis import test
-
-from trove.common.utils import poll_until
+from proboscis import asserts
+from proboscis import after_class
+from proboscis import before_class
+from trove.tests.config import CONFIG
 from trove.tests.api.instances import instance_info
 from trove.tests.api.instances import VOLUME_SUPPORT
-from trove.tests.config import CONFIG
+
+from trove.tests.util.users import Requirements
 from trove.tests.util import assert_contains
 from trove.tests.util import create_dbaas_client
-from trove.tests.util.users import Requirements
+from trove.common.utils import poll_until
 
 
 @test(groups=["dbaas.api.mgmt.malformed_json"])
@@ -43,20 +41,12 @@ class MalformedJson(object):
         volume = None
         if VOLUME_SUPPORT:
             volume = {"size": 1}
-        shared_network = CONFIG.get('shared_network', None)
-        if shared_network:
-            nics = [{'net-id': shared_network}]
-
         self.instance = self.dbaas.instances.create(
             name="qe_instance",
             flavor_id=instance_info.dbaas_flavor_href,
-            datastore=instance_info.dbaas_datastore,
-            datastore_version=instance_info.dbaas_datastore_version,
             volume=volume,
             databases=[{"name": "firstdb", "character_set": "latin2",
-                        "collate": "latin2_general_ci"}],
-            nics=nics
-        )
+                        "collate": "latin2_general_ci"}])
 
     @after_class
     def tearDown(self):
@@ -75,14 +65,10 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Create instance failed with code %s,"
                                  " exception %s" % (httpCode, e))
-            if six.PY3:
-                databases = "'%s'" % databases
-                users = "'%s'" % users
-            else:
-                databases = "u'%s'" % databases
-                users = "u'%s'" % users
+            databases = "u'foo'"
+            users = "u'bar'"
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error:",
                  "instance['databases'] %s is not of type 'array'" % databases,
                  "instance['users'] %s is not of type 'array'" % users,
@@ -99,15 +85,11 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Create database failed with code %s, "
                                  "exception %s" % (httpCode, e))
-            if six.PY3:
-                _bad_db_data = "'%s'" % _bad_db_data
-            else:
-                _bad_db_data = "u'%s'" % _bad_db_data
-            asserts.assert_equal(
-                str(e),
-                "Validation error: "
-                "databases %s is not of type 'array' (HTTP 400)" %
-                _bad_db_data)
+            _bad_db_data = "u'{foo}'"
+            asserts.assert_equal(e.message,
+                                 "Validation error: "
+                                 "databases %s is not of type 'array'" %
+                                 _bad_db_data)
 
     @test
     def test_bad_user_data(self):
@@ -132,7 +114,7 @@ class MalformedJson(object):
                                  "exception %s" % (httpCode, e))
             err_1 = format_path(deque(('users', 0)))
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error:",
                  "%(err_1)s 'name' is a required property" % {'err_1': err_1},
                  "%(err_1)s 'password' is a required property"
@@ -149,7 +131,7 @@ class MalformedJson(object):
 
         poll_until(_check_instance_status)
         try:
-            self.dbaas.instances.resize_instance(self.instance.id, "")
+            self.dbaas.instances.resize_instance(self.instance.id, "bad data")
         except Exception as e:
             resp, body = self.dbaas.client.last_response
             httpCode = resp.status
@@ -176,17 +158,14 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Resize instance failed with code %s, "
                                  "exception %s" % (httpCode, e))
-            if six.PY3:
-                data = "'bad data'"
-            else:
-                data = "u'bad data'"
+            data = "u'bad data'"
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error:",
                  "resize['volume']['size'] %s is not valid under "
                  "any of the given schemas" % data,
                  "%s is not of type 'integer'" % data,
-                 "%s does not match '^0*[1-9]+[0-9]*$'" % data])
+                 "%s does not match '[0-9]+'" % data])
 
     @test
     def test_bad_change_user_password(self):
@@ -209,12 +188,9 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Change usr/passwd failed with code %s, "
                                  "exception %s" % (httpCode, e))
-            if six.PY3:
-                password = "'%s'" % password
-            else:
-                password = "u'%s'" % password
+            password = "u''"
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error: users[0] 'password' "
                  "is a required property",
                  "users[0]['name'] %s is too short" % password,
@@ -262,8 +238,7 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 404,
                                  "Revoke user access failed w/code %s, "
                                  "exception %s" % (httpCode, e))
-            asserts.assert_equal(str(e), "The resource could not be found."
-                                         " (HTTP 404)")
+            asserts.assert_equal(e.message, "The resource could not be found.")
 
     @test
     def test_bad_body_flavorid_create_instance(self):
@@ -281,7 +256,7 @@ class MalformedJson(object):
                                  "exception %s" % (httpCode, e))
             flavorId = [u'?']
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error:",
                  "instance['flavorRef'] %s is not valid "
                  "under any of the given schemas" % flavorId,
@@ -306,19 +281,13 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Create instance failed with code %s, "
                                  "exception %s" % (httpCode, e))
-            if six.PY3:
-                datastore = "'%s'" % datastore
-                datastore_version = "'%s'" % datastore_version
-            else:
-                datastore = "u'%s'" % datastore
-                datastore_version = "u'%s'" % datastore_version
             assert_contains(
-                str(e),
+                e.message,
                 ["Validation error:",
                  "instance['datastore']['type']"
-                 " %s does not match"
+                 " u'%s' does not match"
                  " '^.*[0-9a-zA-Z]+.*$'" % datastore,
-                 "instance['datastore']['version'] %s "
+                 "instance['datastore']['version'] u'%s' "
                  "does not match '^.*[0-9a-zA-Z]+.*$'" % datastore_version])
 
     @test
@@ -334,12 +303,8 @@ class MalformedJson(object):
             asserts.assert_equal(httpCode, 400,
                                  "Create instance failed with code %s, "
                                  "exception %s" % (httpCode, e))
-            if six.PY3:
-                volsize = "'%s'" % volsize
-            else:
-                volsize = "u'%s'" % volsize
-            print("DEBUG DEV: %s" % str(e))
-            asserts.assert_equal(str(e),
+            volsize = "u'h3ll0'"
+            asserts.assert_equal(e.message,
                                  "Validation error: "
                                  "instance['volume'] %s is not of "
-                                 "type 'object' (HTTP 400)" % volsize)
+                                 "type 'object'" % volsize)
