@@ -12,32 +12,44 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+
+from troveclient.compat import exceptions
+
 from nose.plugins.skip import SkipTest
-import proboscis
+from proboscis import before_class
+from proboscis import test
 from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_false
 from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_raises
 from proboscis.asserts import assert_true
-from proboscis import test
-from troveclient.compat import exceptions
 
 from trove import tests
-from trove.tests.api import instances
+from trove.tests.api.users import TestUsers
+from trove.tests.api.instances import instance_info
+from trove.tests import util
 from trove.tests.util import test_config
+from trove.tests.api.databases import TestMysqlAccess
 
 
-@test(groups=[tests.DBAAS_API_USERS_ROOT],
-      depends_on_groups=[tests.DBAAS_API_INSTANCES])
+GROUP = "dbaas.api.root"
+
+
+@test(depends_on_classes=[TestMysqlAccess],
+      runs_after=[TestUsers],
+      groups=[tests.DBAAS_API, GROUP, tests.INSTANCES])
 class TestRoot(object):
-    root_enabled_timestamp = 'Never'
+    """
+    Test the root operations
+    """
 
-    @proboscis.before_class
+    root_enabled_timestamp = 'Never'
+    system_users = ['root', 'debian_sys_maint']
+
+    @before_class
     def setUp(self):
-        # Reuse the instance created previously.
-        self.id = instances.instance_info.id
-        self.dbaas = instances.instance_info.dbaas
-        self.dbaas_admin = instances.instance_info.dbaas_admin
+        self.dbaas = util.create_dbaas_client(instance_info.user)
+        self.dbaas_admin = util.create_dbaas_client(instance_info.admin_user)
 
     def _verify_root_timestamp(self, id):
         reh = self.dbaas_admin.management.root_enabled_history(id)
@@ -46,15 +58,16 @@ class TestRoot(object):
         assert_equal(id, reh.id)
 
     def _root(self):
-        self.dbaas.root.create(self.id)
+        global root_password
+        self.dbaas.root.create(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
         reh = self.dbaas_admin.management.root_enabled_history
-        self.root_enabled_timestamp = reh(self.id).enabled
+        self.root_enabled_timestamp = reh(instance_info.id).enabled
 
     @test
     def test_root_initially_disabled(self):
-        """Test that root is disabled."""
-        enabled = self.dbaas.root.is_root_enabled(self.id)
+        """Test that root is disabled"""
+        enabled = self.dbaas.root.is_root_enabled(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
 
         is_enabled = enabled
@@ -66,18 +79,18 @@ class TestRoot(object):
     def test_create_user_os_admin_failure(self):
         users = [{"name": "os_admin", "password": "12345"}]
         assert_raises(exceptions.BadRequest, self.dbaas.users.create,
-                      self.id, users)
+                      instance_info.id, users)
 
     @test
     def test_delete_user_os_admin_failure(self):
         assert_raises(exceptions.BadRequest, self.dbaas.users.delete,
-                      self.id, "os_admin")
+                      instance_info.id, "os_admin")
 
     @test(depends_on=[test_root_initially_disabled],
           enabled=not test_config.values['root_removed_from_instance_api'])
     def test_root_initially_disabled_details(self):
         """Use instance details to test that root is disabled."""
-        instance = self.dbaas.instances.get(self.id)
+        instance = self.dbaas.instances.get(instance_info.id)
         assert_true(hasattr(instance, 'rootEnabled'),
                     "Instance has no rootEnabled property.")
         assert_false(instance.rootEnabled, "Root SHOULD NOT be enabled.")
@@ -85,18 +98,10 @@ class TestRoot(object):
 
     @test(depends_on=[test_root_initially_disabled_details])
     def test_root_disabled_in_mgmt_api(self):
-        """Verifies in the management api that the timestamp exists."""
-        self._verify_root_timestamp(self.id)
+        """Verifies in the management api that the timestamp exists"""
+        self._verify_root_timestamp(instance_info.id)
 
     @test(depends_on=[test_root_initially_disabled_details])
-    def test_root_disable_when_root_not_enabled(self):
-        reh = self.dbaas_admin.management.root_enabled_history
-        self.root_enabled_timestamp = reh(self.id).enabled
-        assert_raises(exceptions.NotFound, self.dbaas.root.delete,
-                      self.id)
-        self._verify_root_timestamp(self.id)
-
-    @test(depends_on=[test_root_disable_when_root_not_enabled])
     def test_enable_root(self):
         self._root()
 
@@ -110,14 +115,14 @@ class TestRoot(object):
         Tests that despite having enabled root, user root doesn't appear
         in the users list for the instance.
         """
-        users = self.dbaas.users.list(self.id)
+        users = self.dbaas.users.list(instance_info.id)
         usernames = [user.name for user in users]
         assert_true('root' not in usernames)
 
     @test(depends_on=[test_enable_root])
     def test_root_now_enabled(self):
         """Test that root is now enabled."""
-        enabled = self.dbaas.root.is_root_enabled(self.id)
+        enabled = self.dbaas.root.is_root_enabled(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
         assert_true(enabled, "Root SHOULD be enabled.")
 
@@ -125,12 +130,12 @@ class TestRoot(object):
           enabled=not test_config.values['root_removed_from_instance_api'])
     def test_root_now_enabled_details(self):
         """Use instance details to test that root is now enabled."""
-        instance = self.dbaas.instances.get(self.id)
+        instance = self.dbaas.instances.get(instance_info.id)
         assert_true(hasattr(instance, 'rootEnabled'),
                     "Instance has no rootEnabled property.")
         assert_true(instance.rootEnabled, "Root SHOULD be enabled.")
         assert_not_equal(self.root_enabled_timestamp, 'Never')
-        self._verify_root_timestamp(self.id)
+        self._verify_root_timestamp(instance_info.id)
 
     @test(depends_on=[test_root_now_enabled_details])
     def test_reset_root(self):
@@ -144,7 +149,7 @@ class TestRoot(object):
     @test(depends_on=[test_reset_root])
     def test_root_still_enabled(self):
         """Test that after root was reset it's still enabled."""
-        enabled = self.dbaas.root.is_root_enabled(self.id)
+        enabled = self.dbaas.root.is_root_enabled(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
         assert_true(enabled, "Root SHOULD still be enabled.")
 
@@ -154,23 +159,15 @@ class TestRoot(object):
         """Use instance details to test that after root was reset,
             it's still enabled.
         """
-        instance = self.dbaas.instances.get(self.id)
+        instance = self.dbaas.instances.get(instance_info.id)
         assert_true(hasattr(instance, 'rootEnabled'),
                     "Instance has no rootEnabled property.")
         assert_true(instance.rootEnabled, "Root SHOULD still be enabled.")
         assert_not_equal(self.root_enabled_timestamp, 'Never')
-        self._verify_root_timestamp(self.id)
+        self._verify_root_timestamp(instance_info.id)
 
     @test(depends_on=[test_enable_root])
     def test_root_cannot_be_deleted(self):
         """Even if root was enabled, the user root cannot be deleted."""
         assert_raises(exceptions.BadRequest, self.dbaas.users.delete,
-                      self.id, "root")
-
-    @test(depends_on=[test_root_still_enabled_details])
-    def test_root_disable(self):
-        reh = self.dbaas_admin.management.root_enabled_history
-        self.root_enabled_timestamp = reh(self.id).enabled
-        self.dbaas.root.delete(self.id)
-        assert_equal(204, self.dbaas.last_http_code)
-        self._verify_root_timestamp(self.id)
+                      instance_info.id, "root")
