@@ -14,16 +14,22 @@
 
 from random import choice
 
+from troveclient.compat import exceptions
+
 from proboscis import after_class
-from proboscis import asserts
 from proboscis import before_class
 from proboscis import test
-from troveclient.compat import exceptions
+from proboscis import asserts
 
 from trove import tests
 from trove.tests.api.instances import instance_info
 from trove.tests import util
 from trove.tests.util import test_config
+from trove.tests.api.users import TestUsers
+
+GROUP = "dbaas.api.useraccess"
+GROUP_POSITIVE = GROUP + ".positive"
+GROUP_NEGATIVE = GROUP + ".negative"
 
 FAKE = test_config.values['fake_mode']
 
@@ -118,10 +124,14 @@ class UserAccessBase(object):
         self._test_access(self.users, [])
 
 
-@test(depends_on_groups=[tests.DBAAS_API_USERS],
-      groups=[tests.DBAAS_API_USERS_ACCESS])
+@test(depends_on_classes=[TestUsers],
+      groups=[tests.DBAAS_API, GROUP, tests.INSTANCES],
+      runs_after=[TestUsers])
 class TestUserAccessPasswordChange(UserAccessBase):
-    """Test that change_password works."""
+    """
+    Test that change_password works.
+    """
+
     @before_class
     def setUp(self):
         super(TestUserAccessPasswordChange, self).set_up()
@@ -186,29 +196,32 @@ class TestUserAccessPasswordChange(UserAccessBase):
         user = self._pick_a_user()
         password = user["password"]
         self.dbaas.users.change_passwords(instance_info.id, [user])
-
-        asserts.assert_equal(202, self.dbaas.last_http_code)
         self._check_mysql_connection(user["name"], password)
 
     @test(depends_on=[test_change_password])
     def test_change_password_back(self):
-        """Test change and restore user password."""
         user = self._pick_a_user()
         old_password = user["password"]
         new_password = "NEWPASSWORD"
 
         user["password"] = new_password
         self.dbaas.users.change_passwords(instance_info.id, [user])
-
-        asserts.assert_equal(202, self.dbaas.last_http_code)
         self._check_mysql_connection(user["name"], new_password)
 
         user["password"] = old_password
         self.dbaas.users.change_passwords(instance_info.id, [user])
-
-        asserts.assert_equal(202, self.dbaas.last_http_code)
         self._check_mysql_connection(user["name"], old_password)
 
+    @test(depends_on=[test_change_password_back])
+    def test_change_password_twice(self):
+        # Changing the password twice isn't a problem.
+        user = self._pick_a_user()
+        password = "NEWPASSWORD"
+        user["password"] = password
+        self.dbaas.users.change_passwords(instance_info.id, [user])
+        self.dbaas.users.change_passwords(instance_info.id, [user])
+        self._check_mysql_connection(user["name"], password)
+
     @after_class(always_run=True)
     def tearDown(self):
         for database in self.databases:
@@ -218,10 +231,13 @@ class TestUserAccessPasswordChange(UserAccessBase):
             self.dbaas.users.delete(instance_info.id, username)
 
 
-@test(depends_on_classes=[TestUserAccessPasswordChange],
-      groups=[tests.DBAAS_API_USERS_ACCESS])
+@test(depends_on_classes=[TestUsers],
+      groups=[tests.DBAAS_API, GROUP, GROUP_POSITIVE, tests.INSTANCES],
+      runs_after=[TestUsers])
 class TestUserAccessPositive(UserAccessBase):
-    """Test the creation and deletion of user grants."""
+    """
+    Test the creation and deletion of user grants.
+    """
 
     @before_class
     def setUp(self):
@@ -353,9 +369,13 @@ class TestUserAccessPositive(UserAccessBase):
 
 
 @test(depends_on_classes=[TestUserAccessPositive],
-      groups=[tests.DBAAS_API_USERS_ACCESS])
+      groups=[tests.DBAAS_API, GROUP, GROUP_NEGATIVE, tests.INSTANCES],
+      depends_on=[TestUserAccessPositive])
 class TestUserAccessNegative(UserAccessBase):
-    """Negative tests for the creation and deletion of user grants."""
+    """
+    Negative tests for the creation and deletion of user grants.
+    """
+
     @before_class
     def setUp(self):
         super(TestUserAccessNegative, self).set_up()
@@ -458,7 +478,7 @@ class TestUserAccessNegative(UserAccessBase):
 
     @test
     def test_user_empty_with_host(self):
-        # self._negative_user_test("", self.databases, 400, 400, 400, 400)
+        #self._negative_user_test("", self.databases, 400, 400, 400, 400)
         # Try and fail to create the user.
         empty_user = {"name": "", "host": "%",
                       "password": "password", "databases": []}
