@@ -13,46 +13,35 @@
 #    under the License.
 
 import time
-from urllib import parse as urllib_parse
+
+from troveclient.compat import exceptions
 
 from proboscis import after_class
+from proboscis import before_class
+from proboscis import test
 from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_false
 from proboscis.asserts import assert_raises
 from proboscis.asserts import assert_true
 from proboscis.asserts import fail
-from proboscis import before_class
-from proboscis import test
-from troveclient.compat import exceptions
 
 from trove import tests
+from trove.tests.api.databases import TestDatabases
 from trove.tests.api.instances import instance_info
 from trove.tests import util
 from trove.tests.util import test_config
+from trove.tests.api.databases import TestMysqlAccess
 
+import urllib
+
+
+GROUP = "dbaas.api.users"
 FAKE = test_config.values['fake_mode']
 
 
-@test(depends_on_groups=[tests.DBAAS_API_USERS_ROOT],
-      groups=[tests.DBAAS_API_USERS],
-      enabled=not test_config.values['fake_mode'])
-class TestMysqlAccessNegative(object):
-    """Make sure that MySQL server was secured."""
-    @test
-    def test_mysql_admin(self):
-        """Ensure we aren't allowed access with os_admin and wrong password."""
-        util.mysql_connection().assert_fails(
-            instance_info.get_address(), "os_admin", "asdfd-asdf234")
-
-    @test
-    def test_mysql_root(self):
-        """Ensure we aren't allowed access with root and wrong password."""
-        util.mysql_connection().assert_fails(
-            instance_info.get_address(), "root", "dsfgnear")
-
-
-@test(depends_on_classes=[TestMysqlAccessNegative],
-      groups=[tests.DBAAS_API_USERS])
+@test(depends_on_classes=[TestMysqlAccess],
+      groups=[tests.DBAAS_API, GROUP, tests.INSTANCES],
+      runs_after=[TestDatabases])
 class TestUsers(object):
     """
     Test the creation and deletion of users
@@ -81,7 +70,7 @@ class TestUsers(object):
             self.dbaas.databases.create(instance_info.id, databases)
         except exceptions.BadRequest as e:
             if "Validation error" in e.message:
-                raise
+                raise e
         if not FAKE:
             time.sleep(5)
 
@@ -102,7 +91,7 @@ class TestUsers(object):
         users.append({"name": self.username, "password": self.password,
                       "databases": [{"name": self.db1}]})
         users.append({"name": self.username1, "password": self.password1,
-                      "databases": [{"name": self.db1}, {"name": self.db2}]})
+                     "databases": [{"name": self.db1}, {"name": self.db2}]})
         self.dbaas.users.create(instance_info.id, users)
         assert_equal(202, self.dbaas.last_http_code)
 
@@ -117,7 +106,7 @@ class TestUsers(object):
 
     @test(depends_on=[test_create_users])
     def test_create_users_list(self):
-        # tests for users that should be listed
+        #tests for users that should be listed
         users = self.dbaas.users.list(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
         found = False
@@ -134,7 +123,7 @@ class TestUsers(object):
         users.append({"name": self.username, "password": self.password,
                       "databases": [{"name": self.db1}]})
         users.append({"name": self.username1, "password": self.password1,
-                      "databases": [{"name": self.db1}, {"name": self.db2}]})
+                     "databases": [{"name": self.db1}, {"name": self.db2}]})
         assert_raises(exceptions.BadRequest, self.dbaas.users.create,
                       instance_info.id, users)
         assert_equal(400, self.dbaas.last_http_code)
@@ -160,7 +149,7 @@ class TestUsers(object):
 
     @test(depends_on=[test_create_users_list])
     def test_create_users_list_system(self):
-        # tests for users that should not be listed
+        #tests for users that should not be listed
         users = self.dbaas.users.list(instance_info.id)
         assert_equal(200, self.dbaas.last_http_code)
         for user in self.system_users:
@@ -199,7 +188,8 @@ class TestUsers(object):
 
     @test(depends_on=[test_create_users_list, test_delete_users])
     def test_hostnames_make_users_unique(self):
-        """test_hostnames_make_users_unique."""
+        # These tests rely on test_delete_users as they create users only
+        # they use.
         username = "testuser_unique"
         hostnames = ["192.168.0.1", "192.168.0.2"]
         users = [{"name": username, "password": "password", "databases": [],
@@ -209,14 +199,13 @@ class TestUsers(object):
         # Nothing wrong with creating two users with the same name, so long
         # as their hosts are different.
         self.dbaas.users.create(instance_info.id, users)
-
         for hostname in hostnames:
             self.dbaas.users.delete(instance_info.id, username,
                                     hostname=hostname)
 
     @test()
     def test_updateduser_newname_host_unique(self):
-        # The updated_username@hostname should not exist already
+        #The updated_username@hostname should not exist already
         users = []
         old_name = "testuser1"
         hostname = "192.168.0.1"
@@ -379,6 +368,24 @@ class TestUsers(object):
                       instance_info.id, users)
         assert_equal(400, self.dbaas.last_http_code)
 
+    @test(enabled=False)
+    #TODO(hub_cap): Make this test work once python-routes is updated, if ever.
+    def test_delete_user_with_period_in_name(self):
+        """Attempt to create/destroy a user with a period in its name"""
+        users = []
+        username_with_period = "user.name"
+        users.append({"name": username_with_period, "password": self.password,
+                      "databases": [{"name": self.db1}]})
+        self.dbaas.users.create(instance_info.id, users)
+        assert_equal(202, self.dbaas.last_http_code)
+        if not FAKE:
+            time.sleep(5)
+
+        self.check_database_for_user(username_with_period, self.password,
+                                     [self.db1])
+        self.dbaas.users.delete(instance_info.id, username_with_period)
+        assert_equal(202, self.dbaas.last_http_code)
+
     @test
     def test_invalid_password(self):
         users = [{"name": "anouser", "password": "sdf,;",
@@ -419,7 +426,7 @@ class TestUsers(object):
         assert_true(len(users) <= limit)
         assert_true(users.next is not None)
         expected_marker = "%s@%s" % (users[-1].name, users[-1].host)
-        expected_marker = urllib_parse.quote(expected_marker)
+        expected_marker = urllib.quote(expected_marker)
         assert_equal(marker, expected_marker)
         marker = users.next
 
