@@ -12,21 +12,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from proboscis.asserts import assert_equal
 from proboscis import before_class
-from proboscis import SkipTest
 from proboscis import test
-from troveclient.compat.exceptions import ClientException
+from proboscis.asserts import assert_equal
+from proboscis import SkipTest
 
+from troveclient.compat.exceptions import ClientException
 from trove import tests
-from trove.tests.util import create_dbaas_client
 from trove.tests.util import test_config
+from trove.tests.util import create_dbaas_client
 from trove.tests.util.users import Requirements
 
+GROUP = "dbaas.api.versions"
 
-@test(groups=[tests.DBAAS_API_VERSIONS])
+
+@test(groups=[tests.DBAAS_API, GROUP, tests.PRE_INSTANCES, 'DBAAS_VERSIONS'],
+      depends_on_groups=["services.initialize"])
 class Versions(object):
-    """Test listing all versions and verify the current version."""
+    """Test listing all versions and verify the current version"""
 
     @before_class
     def setUp(self):
@@ -36,7 +39,6 @@ class Versions(object):
 
     @test
     def test_list_versions_index(self):
-        """test_list_versions_index"""
         versions = self.client.versions.index(test_config.version_url)
         assert_equal(1, len(versions))
         assert_equal("CURRENT", versions[0].status,
