@@ -16,6 +16,12 @@
 """Common code to help in faking the models."""
 
 from novaclient import exceptions as nova_exceptions
+from trove.common import cfg
+from trove.openstack.common import log as logging
+
+
+CONF = cfg.CONF
+LOG = logging.getLogger(__name__)
 
 
 def authorize(context):
