@@ -13,19 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import re
+from trove.openstack.common import log as logging
 import time
+import re
 
 import eventlet
-from oslo_log import log as logging
-
 from trove.common import exception as rd_exception
-from trove.instance import service_status as srvstatus
+from trove.common import instance as rd_instance
 from trove.tests.util import unquote_user_host
 
 DB = {}
 LOG = logging.getLogger(__name__)
-BACKUP_SIZE = 0.14
 
 
 class FakeGuest(object):
@@ -62,11 +60,11 @@ class FakeGuest(object):
         }
 
     def update_guest(self):
-        LOG.debug("Updating guest %s", self.id)
+        LOG.debug("Updating guest %s" % self.id)
         self.version += 1
 
     def _check_username(self, username):
-        unsupported_chars = re.compile(r"""^\s|\s$|'|"|;|`|,|/|\\""")
+        unsupported_chars = re.compile("^\s|\s$|'|\"|;|`|,|/|\\\\")
         if (not username or
                 unsupported_chars.search(username) or
                 ("%r" % username).find("\\") != -1):
@@ -92,9 +90,9 @@ class FakeGuest(object):
         LOG.debug("Updating attributes")
         self._check_username(username)
         if (username, hostname) not in self.users:
-            raise rd_exception.UserNotFound(
-                "User %s@%s cannot be found on the instance."
-                % (username, hostname))
+                raise rd_exception.UserNotFound(
+                    "User %s@%s cannot be found on the instance."
+                    % (username, hostname))
         new_name = user_attrs.get('name')
         new_host = user_attrs.get('host')
         new_password = user_attrs.get('password')
@@ -139,6 +137,9 @@ class FakeGuest(object):
         if database['_name'] in self.dbs:
             del self.dbs[database['_name']]
 
+    def delete_queue(self):
+        pass
+
     def enable_root(self):
         self.root_was_enabled = True
         return self._create_user({
@@ -148,20 +149,6 @@ class FakeGuest(object):
             "_databases": [],
         })
 
-    def enable_root_with_password(self, root_password=None):
-        self.root_was_enabled = True
-        return self._create_user({
-            "_name": "root",
-            "_host": "%",
-            "_password": "12345",
-            "_databases": [],
-        })
-
-    def disable_root(self):
-        self.delete_user({
-            "_name": "root",
-            "_host": "%"})
-
     def delete_user(self, user):
         username = user['_name']
         self._check_username(username)
@@ -221,13 +208,12 @@ class FakeGuest(object):
 
     def prepare(self, memory_mb, packages, databases, users, device_path=None,
                 mount_point=None, backup_info=None, config_contents=None,
-                root_password=None, overrides=None, cluster_config=None,
-                snapshot=None, modules=None):
-        from trove.guestagent.models import AgentHeartBeat
+                root_password=None, overrides=None):
         from trove.instance.models import DBInstance
         from trove.instance.models import InstanceServiceStatus
-        LOG.debug("users... %s", users)
-        LOG.debug("databases... %s", databases)
+        from trove.guestagent.models import AgentHeartBeat
+        LOG.debug("users... %s" % users)
+        LOG.debug("databases... %s" % databases)
         instance_name = DBInstance.find_by(id=self.id).name
         self.create_user(users)
         self.create_database(databases)
@@ -236,18 +222,18 @@ class FakeGuest(object):
         def update_db():
             status = InstanceServiceStatus.find_by(instance_id=self.id)
             if instance_name.endswith('GUEST_ERROR'):
-                status.status = srvstatus.ServiceStatuses.FAILED
+                status.status = rd_instance.ServiceStatuses.FAILED
             else:
-                status.status = srvstatus.ServiceStatuses.HEALTHY
+                status.status = rd_instance.ServiceStatuses.RUNNING
             status.save()
             AgentHeartBeat.create(instance_id=self.id)
-        eventlet.spawn_after(3.5, update_db)
+        eventlet.spawn_after(1.0, update_db)
 
-    def _set_task_status(self, new_status='HEALTHY'):
+    def _set_status(self, new_status='RUNNING'):
         from trove.instance.models import InstanceServiceStatus
         print("Setting status to %s" % new_status)
-        states = {'HEALTHY': srvstatus.ServiceStatuses.HEALTHY,
-                  'SHUTDOWN': srvstatus.ServiceStatuses.SHUTDOWN,
+        states = {'RUNNING': rd_instance.ServiceStatuses.RUNNING,
+                  'SHUTDOWN': rd_instance.ServiceStatuses.SHUTDOWN,
                   }
         status = InstanceServiceStatus.find_by(instance_id=self.id)
         status.status = states[new_status]
@@ -259,18 +245,18 @@ class FakeGuest(object):
         # take a nap.
         print("Sleeping for a second.")
         time.sleep(1)
-        self._set_task_status('HEALTHY')
+        self._set_status('RUNNING')
 
     def reset_configuration(self, config):
         # There's nothing to do here, since there is no config to update.
         pass
 
-    def start_db_with_conf_changes(self, config_contents, ds_version):
+    def start_db_with_conf_changes(self, config_contents):
         time.sleep(2)
-        self._set_task_status('HEALTHY')
+        self._set_status('RUNNING')
 
-    def stop_db(self):
-        self._set_task_status('SHUTDOWN')
+    def stop_db(self, do_not_start_on_reboot=False):
+        self._set_status('SHUTDOWN')
 
     def get_volume_info(self):
         """Return used and total volume filesystem information in GB."""
@@ -311,8 +297,7 @@ class FakeGuest(object):
         return dbs
 
     def create_backup(self, backup_info):
-        from trove.backup.models import Backup
-        from trove.backup.state import BackupState
+        from trove.backup.models import Backup, BackupState
         backup = Backup.get_by_id(context=None,
                                   backup_id=backup_info['id'])
 
@@ -320,9 +305,8 @@ class FakeGuest(object):
             backup.state = BackupState.COMPLETED
             backup.location = 'http://localhost/path/to/backup'
             backup.checksum = 'fake-md5-sum'
-            backup.size = BACKUP_SIZE
             backup.save()
-        eventlet.spawn_after(10, finish_create_backup)
+        eventlet.spawn_after(1.0, finish_create_backup)
 
     def mount_volume(self, device_path=None, mount_point=None):
         pass
@@ -330,7 +314,7 @@ class FakeGuest(object):
     def unmount_volume(self, device_path=None, mount_point=None):
         pass
 
-    def resize_fs(self, device_path=None, mount_point=None, online=False):
+    def resize_fs(self, device_path=None, mount_point=None):
         pass
 
     def update_overrides(self, overrides, remove=False):
@@ -339,40 +323,6 @@ class FakeGuest(object):
     def apply_overrides(self, overrides):
         self.overrides = overrides
 
-    def get_replication_snapshot(self, snapshot_info,
-                                 replica_source_config=None):
-        self.create_backup(snapshot_info)
-        return {
-            'dataset':
-            {
-                'datastore_manager': 'mysql',
-                'dataset_size': '0.0',
-                'volume_size': '10.0',
-                'snapshot_id': None
-            },
-            'replication_strategy': 'replication_strategy',
-            'master': '1',
-            'log_position': '100'
-        }
-
-    def attach_replication_slave(self, snapshot, slave_config):
-        pass
-
-    def backup_required_for_replication(self):
-        return True
-
-    def post_processing_required_for_replication(self):
-        return False
-
-    def module_list(self, context, include_contents=False):
-        return []
-
-    def module_apply(self, context, modules=None):
-        return []
-
-    def module_remove(self, context, module=None):
-        pass
-
 
 def get_or_create(id):
     if id not in DB:
@@ -380,5 +330,5 @@ def get_or_create(id):
     return DB[id]
 
 
-def fake_create_guest_client(context, id, manager=None):
+def fake_create_guest_client(context, id):
     return get_or_create(id)
