@@ -13,16 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
-import uuid
+from novaclient import exceptions as nova_exceptions
+from trove.common.exception import PollTimeOut
+from trove.common import instance as rd_instance
+from trove.openstack.common import log as logging
+from trove.tests.fakes.common import authorize
 
 import eventlet
-from novaclient import exceptions as nova_exceptions
-from oslo_log import log as logging
-
-from trove.common.exception import PollTimeOut
-from trove.instance import service_status as srvstatus
-from trove.tests.fakes.common import authorize
+import uuid
 
 LOG = logging.getLogger(__name__)
 FAKE_HOSTS = ["fake_host_1", "fake_host_2"]
@@ -66,18 +64,13 @@ class FakeFlavors(object):
         self._add(10, 2, "m1.rd-tiny", 512)
         self._add(11, 0, "eph.rd-tiny", 512, 1)
         self._add(12, 20, "eph.rd-smaller", 768, 2)
-        self._add("custom", 25, "custom.small", 512, 1)
 
     def _add(self, *args, **kwargs):
         new_flavor = FakeFlavor(*args, **kwargs)
         self.db[new_flavor.id] = new_flavor
 
     def get(self, id):
-        try:
-            id = int(id)
-        except ValueError:
-            pass
-
+        id = int(id)
         if id not in self.db:
             raise nova_exceptions.NotFound(404, "Flavor id not found %s" % id)
         return self.db[id]
@@ -100,7 +93,7 @@ class FakeServer(object):
     next_local_id = 0
 
     def __init__(self, parent, owner, id, name, image_id, flavor_ref,
-                 volumes, key_name):
+                 block_device_mapping, volumes):
         self.owner = owner  # This is a context.
         self.id = id
         self.parent = parent
@@ -124,7 +117,6 @@ class FakeServer(object):
         setattr(self, 'OS-EXT-AZ:availability_zone', 'nova')
 
         self._info = {'os:volumes': info_vols}
-        self.key_name = key_name
 
     @property
     def addresses(self):
@@ -133,7 +125,7 @@ class FakeServer(object):
     def confirm_resize(self):
         if self.status != "VERIFY_RESIZE":
             raise RuntimeError("Not in resize confirm mode.")
-        self._current_status = "HEALTHY"
+        self._current_status = "ACTIVE"
 
     def revert_resize(self):
         if self.status != "VERIFY_RESIZE":
@@ -142,13 +134,13 @@ class FakeServer(object):
         self.old_host = None
         self.flavor_ref = self.old_flavor_ref
         self.old_flavor_ref = None
-        self._current_status = "HEALTHY"
+        self._current_status = "ACTIVE"
 
     def reboot(self):
-        LOG.debug("Rebooting server %s", self.id)
+        LOG.debug("Rebooting server %s" % (self.id))
 
         def set_to_active():
-            self._current_status = "HEALTHY"
+            self._current_status = "ACTIVE"
             self.parent.schedule_simulate_running_server(self.id, 1.5)
 
         self._current_status = "REBOOT"
@@ -203,7 +195,7 @@ class FakeServer(object):
 
         def set_flavor():
             if self.name.endswith("_RESIZE_ERROR"):
-                self._current_status = "HEALTHY"
+                self._current_status = "ACTIVE"
                 return
             if new_flavor_id is None:
                 # Migrations are flavorless flavor resizes.
@@ -263,16 +255,32 @@ class FakeServers(object):
         """Can this FakeServers, with its context, see some resource?"""
         server = self.db[id]
         return (self.context.is_admin or
-                server.owner.tenant == self.context.project_id)
+                server.owner.tenant == self.context.tenant)
 
     def create(self, name, image_id, flavor_ref, files=None, userdata=None,
-               block_device_mapping_v2=None, security_groups=None,
-               availability_zone=None, nics=None, config_drive=False,
-               scheduler_hints=None, key_name=None):
+               block_device_mapping=None, volume=None, security_groups=None,
+               availability_zone=None, nics=None):
         id = "FAKE_%s" % uuid.uuid4()
-        volumes = self._get_volumes_from_bdm_v2(block_device_mapping_v2)
+        if volume:
+            volume = self.volumes.create(volume['size'], volume['name'],
+                                         volume['description'])
+            while volume.status == "BUILD":
+                eventlet.sleep(0.1)
+            if volume.status != "available":
+                LOG.info(_("volume status = %s") % volume.status)
+                raise nova_exceptions.ClientException("Volume was bad!")
+            mapping = "%s::%s:%s" % (volume.id, volume.size, 1)
+            block_device_mapping = {'vdb': mapping}
+            volumes = [volume]
+            LOG.debug(_("Fake Volume Create %(volumeid)s with "
+                        "status %(volumestatus)s") %
+                      {'volumeid': volume.id, 'volumestatus': volume.status})
+        else:
+            volumes = self._get_volumes_from_bdm(block_device_mapping)
+            for volume in volumes:
+                volume.schedule_status('in-use', 1)
         server = FakeServer(self, self.context, id, name, image_id, flavor_ref,
-                            volumes, key_name)
+                            block_device_mapping, volumes)
         self.db[id] = server
         if name.endswith('SERVER_ERROR'):
             raise nova_exceptions.ClientException("Fake server create error.")
@@ -281,25 +289,35 @@ class FakeServers(object):
             raise nova_exceptions.ClientException("The requested availability "
                                                   "zone is not available.")
 
-        server.schedule_status("HEALTHY", 1)
-        LOG.info("FAKE_SERVERS_DB : %s", str(FAKE_SERVERS_DB))
+        if nics is not None and nics.port_id == 'UNKNOWN':
+            raise nova_exceptions.ClientException("The requested availability "
+                                                  "zone is not available.")
+
+        server.schedule_status("ACTIVE", 1)
+        LOG.info(_("FAKE_SERVERS_DB : %s") % str(FAKE_SERVERS_DB))
         return server
 
-    def _get_volumes_from_bdm_v2(self, block_device_mapping_v2):
+    def _get_volumes_from_bdm(self, block_device_mapping):
         volumes = []
-        if block_device_mapping_v2 is not None:
-            # block_device_mapping_v2 is an array of dicts. Every dict is
-            # a volume attachment, which contains "uuid", "source_type",
-            # "destination_type", "device_name", "volume_size" and
-            # "delete_on_termination".
-            for bdm in block_device_mapping_v2:
-                volume = self.volumes.get(bdm['uuid'])
+        if block_device_mapping is not None:
+            # block_device_mapping is a dictionary, where the key is the
+            # device name on the compute instance and the mapping info is a
+            # set of fields in a string, separated by colons.
+            # For each device, find the volume, and record the mapping info
+            # to another fake object and attach it to the volume
+            # so that the fake API can later retrieve this.
+            for device in block_device_mapping:
+                mapping = block_device_mapping[device]
+                (id, _type, size, delete_on_terminate) = mapping.split(":")
+                volume = self.volumes.get(id)
+                volume.mapping = FakeBlockDeviceMappingInfo(
+                    id, device, _type, size, delete_on_terminate)
                 volumes.append(volume)
         return volumes
 
     def get(self, id):
         if id not in self.db:
-            LOG.error("Couldn't find server id %(id)s, collection=%(db)s",
+            LOG.error(_("Couldn't find server id %(id)s, collection=%(db)s") %
                       {'id': id, 'db': self.db})
             raise nova_exceptions.NotFound(404, "Not found")
         else:
@@ -308,12 +326,18 @@ class FakeServers(object):
             else:
                 raise nova_exceptions.NotFound(404, "Bad permissions")
 
+    def get_server_volumes(self, server_id):
+        """Fake method we've added to grab servers from the volume."""
+        return [volume.mapping
+                for volume in self.get(server_id).volumes
+                if volume.mapping is not None]
+
     def list(self):
         return [v for (k, v) in self.db.items() if self.can_see(v.id)]
 
     def schedule_delete(self, id, time_from_now):
         def delete_server():
-            LOG.info("Simulated event ended, deleting server %s.", id)
+            LOG.info(_("Simulated event ended, deleting server %s.") % id)
             del self.db[id]
         eventlet.spawn_after(time_from_now, delete_server)
 
@@ -323,9 +347,9 @@ class FakeServers(object):
 
         def set_server_running():
             instance = DBInstance.find_by(compute_instance_id=id)
-            LOG.debug("Setting server %s to running", instance.id)
+            LOG.debug(_("Setting server %s to running") % instance.id)
             status = InstanceServiceStatus.find_by(instance_id=instance.id)
-            status.status = srvstatus.ServiceStatuses.RUNNING
+            status.status = rd_instance.ServiceStatuses.RUNNING
             status.save()
         eventlet.spawn_after(time_from_now, set_server_running)
 
@@ -355,10 +379,30 @@ class FakeRdServers(object):
         return [FakeRdServer(server) for server in self.servers.list()]
 
 
+class FakeServerVolumes(object):
+
+    def __init__(self, context):
+        self.context = context
+
+    def get_server_volumes(self, server_id):
+        class ServerVolumes(object):
+            def __init__(self, block_device_mapping):
+                LOG.debug(_("block_device_mapping = %s") %
+                          block_device_mapping)
+                device = block_device_mapping['vdb']
+                (self.volumeId,
+                    self.type,
+                    self.size,
+                    self.delete_on_terminate) = device.split(":")
+        fake_servers = FakeServers(self.context, FLAVORS)
+        server = fake_servers.get(server_id)
+        return [ServerVolumes(server.block_device_mapping)]
+
+
 class FakeVolume(object):
 
     def __init__(self, parent, owner, id, size, name,
-                 description, volume_type, availability_zone):
+                 description):
         self.attachments = []
         self.parent = parent
         self.owner = owner  # This is a context.
@@ -370,8 +414,6 @@ class FakeVolume(object):
         # For some reason we grab this thing from device then call it mount
         # point.
         self.device = "vdb"
-        self.volume_type = volume_type
-        self.availability_zone = availability_zone
 
     def __repr__(self):
         msg = ("FakeVolume(id=%s, size=%s, name=%s, "
@@ -380,6 +422,10 @@ class FakeVolume(object):
                   self.description, self._current_status)
         return (msg % params)
 
+    @property
+    def availability_zone(self):
+        return "fake-availability-zone"
+
     @property
     def created_at(self):
         return "2001-01-01-12:30:30"
@@ -429,11 +475,11 @@ class FakeVolumes(object):
         """Can this FakeVolumes, with its context, see some resource?"""
         server = self.db[id]
         return (self.context.is_admin or
-                server.owner.tenant == self.context.project_id)
+                server.owner.tenant == self.context.tenant)
 
     def get(self, id):
         if id not in self.db:
-            LOG.error("Couldn't find volume id %(id)s, collection=%(db)s",
+            LOG.error(_("Couldn't find volume id %(id)s, collection=%(db)s") %
                       {'id': id, 'db': self.db})
             raise nova_exceptions.NotFound(404, "Not found")
         else:
@@ -442,11 +488,10 @@ class FakeVolumes(object):
             else:
                 raise nova_exceptions.NotFound(404, "Bad permissions")
 
-    def create(self, size, name=None, description=None, volume_type=None,
-               availability_zone=None):
+    def create(self, size, name=None, description=None):
         id = "FAKE_VOL_%s" % uuid.uuid4()
         volume = FakeVolume(self, self.context, id, size, name,
-                            description, volume_type, availability_zone)
+                            description)
         self.db[id] = volume
         if size == 9:
             volume.schedule_status("error", 2)
@@ -454,17 +499,17 @@ class FakeVolumes(object):
             raise Exception("No volume for you!")
         else:
             volume.schedule_status("available", 2)
-        LOG.debug("Fake volume created %(volumeid)s with "
-                  "status %(volumestatus)s",
+        LOG.debug(_("Fake volume created %(volumeid)s with "
+                    "status %(volumestatus)s") %
                   {'volumeid': volume.id, 'volumestatus': volume.status})
-        LOG.info("FAKE_VOLUMES_DB : %s", FAKE_VOLUMES_DB)
+        LOG.info("FAKE_VOLUMES_DB : %s" % FAKE_VOLUMES_DB)
         return volume
 
     def list(self, detailed=True):
         return [self.db[key] for key in self.db]
 
     def extend(self, volume_id, new_size):
-        LOG.debug("Resize volume id (%(volumeid)s) to size (%(size)s)",
+        LOG.debug(_("Resize volume id (%(volumeid)s) to size (%(size)s)") %
                   {'volumeid': volume_id, 'size': new_size})
         volume = self.get(volume_id)
 
@@ -477,7 +522,7 @@ class FakeVolumes(object):
             volume.size = new_size
         eventlet.spawn_after(1.0, finish_resize)
 
-    def delete_server_volume(self, server_id, volume_id):
+    def detach(self, volume_id):
         volume = self.get(volume_id)
 
         if volume._current_status != 'in-use':
@@ -489,7 +534,7 @@ class FakeVolumes(object):
             volume._current_status = "available"
         eventlet.spawn_after(1.0, finish_detach)
 
-    def create_server_volume(self, server_id, volume_id, device_path):
+    def attach(self, volume_id, server_id, device_path):
         volume = self.get(volume_id)
 
         if volume._current_status != "available":
@@ -563,7 +608,7 @@ class FakeHost(object):
         """
         self.instances = []
         self.percentUsed = 0
-        self.totalRAM = 32000  # 16384
+        self.totalRAM = 2004  # 16384
         self.usedRAM = 0
         for server in self.servers.list():
             print(server)
@@ -575,11 +620,11 @@ class FakeHost(object):
                 'name': server.name,
                 'status': server.status
             })
-            if (str(server.flavor_ref).startswith('http:') or
-               str(server.flavor_ref).startswith('https:')):
-                flavor = FLAVORS.get_by_href(server.flavor_ref)
-            else:
+            try:
                 flavor = FLAVORS.get(server.flavor_ref)
+            except ValueError:
+                # Maybe flavor_ref isn't an int?
+                flavor = FLAVORS.get_by_href(server.flavor_ref)
             ram = flavor.ram
             self.usedRAM += ram
         decimal = float(self.usedRAM) / float(self.totalRAM)
@@ -589,9 +634,7 @@ class FakeHost(object):
 class FakeHosts(object):
 
     def __init__(self, servers):
-        # Use an ordered dict to make the results of the fake api call
-        # return in the same order for the example generator.
-        self.hosts = collections.OrderedDict()
+        self.hosts = {}
         for host in FAKE_HOSTS:
             self.add_host(FakeHost(host, servers))
 
@@ -687,9 +730,6 @@ class FakeSecurityGroups(object):
         self.securityGroups[secGrp.get_id()] = secGrp
         return secGrp
 
-    def delete(self, group_id):
-        pass
-
     def list(self):
         pass
 
@@ -737,43 +777,6 @@ class FakeSecurityGroupRules(object):
             del self.securityGroupRules[id]
 
 
-class FakeServerGroup(object):
-
-    def __init__(self, name=None, policies=None, context=None):
-        self.name = name
-        self.description = description
-        self.id = "FAKE_SRVGRP_%s" % uuid.uuid4()
-        self.policies = policies or {}
-
-    def get_id(self):
-        return self.id
-
-    def data(self):
-        return {
-            'id': self.id,
-            'name': self.name,
-            'policies': self.policies
-        }
-
-
-class FakeServerGroups(object):
-
-    def __init__(self, context=None):
-        self.context = context
-        self.server_groups = {}
-
-    def create(self, name=None, policies=None):
-        server_group = FakeServerGroup(name, policies, context=self.context)
-        self.server_groups[server_group.get_id()] = server_group
-        return server_group
-
-    def delete(self, group_id):
-        pass
-
-    def list(self):
-        return self.server_groups
-
-
 class FakeClient(object):
 
     def __init__(self, context):
@@ -788,7 +791,9 @@ class FakeClient(object):
         self.rdservers = FakeRdServers(self.servers)
         self.security_groups = FakeSecurityGroups(context)
         self.security_group_rules = FakeSecurityGroupRules(context)
-        self.server_groups = FakeServerGroups(context)
+
+    def get_server_volumes(self, server_id):
+        return self.servers.get_server_volumes(server_id)
 
     def rescan_server_volume(self, server, volume_id):
         LOG.info("FAKE rescanning volume.")
@@ -801,6 +806,7 @@ def get_client_data(context):
     if context not in CLIENT_DATA:
         nova_client = FakeClient(context)
         volume_client = FakeClient(context)
+        nova_client.volumes = volume_client
         volume_client.servers = nova_client
         CLIENT_DATA[context] = {
             'nova': nova_client,
@@ -809,13 +815,13 @@ def get_client_data(context):
     return CLIENT_DATA[context]
 
 
-def fake_create_nova_client(context, region_name=None):
+def fake_create_nova_client(context):
     return get_client_data(context)['nova']
 
 
-def fake_create_nova_volume_client(context, region_name=None):
+def fake_create_nova_volume_client(context):
     return get_client_data(context)['volume']
 
 
-def fake_create_cinder_client(context, region_name=None):
+def fake_create_cinder_client(context):
     return get_client_data(context)['volume']
