@@ -13,19 +13,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import http
-from hashlib import md5
-from unittest.mock import MagicMock, patch
+import httplib
 import json
 import os
 import socket
-import swiftclient
-import swiftclient.client as swift_client
 import uuid
+import logging
+import swiftclient.client as swift_client
+import swiftclient
+from hashlib import md5
+from mock import MagicMock
 
-from oslo_log import log as logging
 from swiftclient import client as swift
 
+from trove.openstack.common.gettextutils import _  # noqa
 
 LOG = logging.getLogger(__name__)
 
@@ -36,16 +37,14 @@ class FakeSwiftClient(object):
         pass
 
     @classmethod
-    def Connection(cls, *args, **kargs):
-        LOG.debug("fake FakeSwiftClient Connection")
+    def Connection(self, *args, **kargs):
+        LOG.debug(_("fake FakeSwiftClient Connection"))
         return FakeSwiftConnection()
 
 
 class FakeSwiftConnection(object):
-    """Logging calls instead of executing."""
-    MANIFEST_QUERY_STRING_PUT = 'multipart-manifest=put'
-    MANIFEST_QUERY_STRING_DELETE = 'multipart-manifest=delete'
-    COPY_OBJECT_HEADER_KEY = 'X-Copy-From'
+    """Logging calls instead of executing"""
+    MANIFEST_HEADER_KEY = 'X-Object-Manifest'
     url = 'http://mockswift/v1'
 
     def __init__(self, *args, **kwargs):
@@ -55,14 +54,14 @@ class FakeSwiftConnection(object):
 
     def get_auth(self):
         return (
-            "http://127.0.0.1:8080/v1/AUTH_c7b038976df24d96bf1980f5da17bd89",
-            'MIINrwYJKoZIhvcNAQcCoIINoDCCDZwCAQExCTAHBgUrDgMCGjCCDIgGCSqGSIb3'
-            'DQEHAaCCDHkEggx1eyJhY2Nlc3MiOiB7InRva2VuIjogeyJpc3N1ZWRfYXQiOiAi'
-            'MjAxMy0wMy0xOFQxODoxMzoyMC41OTMyNzYiLCAiZXhwaXJlcyI6ICIyMDEzLTAz'
-            'LTE5VDE4OjEzOjIwWiIsICJpZCI6ICJwbGFjZWhvbGRlciIsICJ0ZW5hbnQiOiB7'
-            'ImVuYWJsZWQiOiB0cnVlLCAiZGVzY3JpcHRpb24iOiBudWxsLCAibmFtZSI6ICJy'
-            'ZWRkd2FyZiIsICJpZCI6ICJjN2IwMzg5NzZkZjI0ZDk2YmYxOTgwZjVkYTE3YmQ4'
-            'OSJ9fSwgInNlcnZpY2VDYXRhbG9nIjogW3siZW5kcG9pbnRzIjogW3siYWRtaW5')
+            u"http://127.0.0.1:8080/v1/AUTH_c7b038976df24d96bf1980f5da17bd89",
+            u'MIINrwYJKoZIhvcNAQcCoIINoDCCDZwCAQExCTAHBgUrDgMCGjCCDIgGCSqGSIb3'
+            u'DQEHAaCCDHkEggx1eyJhY2Nlc3MiOiB7InRva2VuIjogeyJpc3N1ZWRfYXQiOiAi'
+            u'MjAxMy0wMy0xOFQxODoxMzoyMC41OTMyNzYiLCAiZXhwaXJlcyI6ICIyMDEzLTAz'
+            u'LTE5VDE4OjEzOjIwWiIsICJpZCI6ICJwbGFjZWhvbGRlciIsICJ0ZW5hbnQiOiB7'
+            u'ImVuYWJsZWQiOiB0cnVlLCAiZGVzY3JpcHRpb24iOiBudWxsLCAibmFtZSI6ICJy'
+            u'ZWRkd2FyZiIsICJpZCI6ICJjN2IwMzg5NzZkZjI0ZDk2YmYxOTgwZjVkYTE3YmQ4'
+            u'OSJ9fSwgInNlcnZpY2VDYXRhbG9nIjogW3siZW5kcG9pbnRzIjogW3siYWRtaW5')
 
     def get_account(self):
         return ({'content-length': '2', 'accept-ranges': 'bytes',
@@ -75,25 +74,23 @@ class FakeSwiftConnection(object):
                  'x-account-object-count': '0'}, [])
 
     def head_container(self, container):
-        LOG.debug("fake head_container(%s)", container)
+        LOG.debug(_("fake head_container(%s)") % container)
         if container == 'missing_container':
             raise swift.ClientException('fake exception',
-                                        http_status=http.HTTPStatus.NOT_FOUND)
+                                        http_status=httplib.NOT_FOUND)
         elif container == 'unauthorized_container':
-            raise swift.ClientException(
-                'fake exception',
-                http_status=http.HTTPStatus.UNAUTHORIZED
-            )
+            raise swift.ClientException('fake exception',
+                                        http_status=httplib.UNAUTHORIZED)
         elif container == 'socket_error_on_head':
             raise socket.error(111, 'ECONNREFUSED')
         pass
 
     def put_container(self, container):
-        LOG.debug("fake put_container(%s)", container)
+        LOG.debug(_("fake put_container(%s)") % container)
         pass
 
     def get_container(self, container, **kwargs):
-        LOG.debug("fake get_container(%s)", container)
+        LOG.debug(_("fake get_container(%s)") % container)
         fake_header = None
         fake_body = [{'name': 'backup_001'},
                      {'name': 'backup_002'},
@@ -101,15 +98,15 @@ class FakeSwiftConnection(object):
         return fake_header, fake_body
 
     def head_object(self, container, name):
-        LOG.debug("fake put_container(%(container)s, %(name)s)",
+        LOG.debug(_("fake put_container(%(container)s, %(name)s)") %
                   {'container': container, 'name': name})
         checksum = md5()
-        if self.manifest_name == name:
-            for object_name in sorted(self.container_objects):
+        if self.manifest_prefix and self.manifest_name == name:
+            for object_name in sorted(self.container_objects.iterkeys()):
                 object_checksum = md5(self.container_objects[object_name])
                 # The manifest file etag for a HEAD or GET is the checksum of
                 # the concatenated checksums.
-                checksum.update(object_checksum.hexdigest().encode())
+                checksum.update(object_checksum.hexdigest())
             # this is included to test bad swift segment etags
             if name.startswith("bad_manifest_etag_"):
                 return {'etag': '"this_is_an_intentional_bad_manifest_etag"'}
@@ -123,7 +120,7 @@ class FakeSwiftConnection(object):
         return {'etag': '"%s"' % checksum.hexdigest()}
 
     def get_object(self, container, name, resp_chunk_size=None):
-        LOG.debug("fake get_object(%(container)s, %(name)s)",
+        LOG.debug(_("fake get_object(%(container)s, %(name)s)") %
                   {'container': container, 'name': name})
         if container == 'socket_error_on_get':
             raise socket.error(111, 'ECONNREFUSED')
@@ -161,31 +158,23 @@ class FakeSwiftConnection(object):
         return (fake_header, fake_object_body)
 
     def put_object(self, container, name, contents, **kwargs):
-        LOG.debug("fake put_object(%(container)s, %(name)s)",
+        LOG.debug(_("fake put_object(%(container)s, %(name)s)") %
                   {'container': container, 'name': name})
         if container == 'socket_error_on_put':
             raise socket.error(111, 'ECONNREFUSED')
         headers = kwargs.get('headers', {})
-        query_string = kwargs.get('query_string', '')
         object_checksum = md5()
-        if query_string == self.MANIFEST_QUERY_STRING_PUT:
+        if self.MANIFEST_HEADER_KEY in headers:
             # the manifest prefix format is <container>/<prefix> where
             # container is where the object segments are in and prefix is the
             # common prefix for all segments.
+            self.manifest_prefix = headers.get(self.MANIFEST_HEADER_KEY)
             self.manifest_name = name
-            if isinstance(contents, str):
-                object_checksum.update(contents.encode('utf-8'))
-            else:
-                object_checksum.update(contents)
-        elif self.COPY_OBJECT_HEADER_KEY in headers:
-            # this is a copy object operation
-            source_path = headers.get(self.COPY_OBJECT_HEADER_KEY)
-            source_name = source_path.split('/')[1]
-            self.container_objects[name] = self.container_objects[source_name]
+            object_checksum.update(contents)
         else:
             if hasattr(contents, 'read'):
                 chunk_size = 128
-                object_content = b""
+                object_content = ""
                 chunk = contents.read(chunk_size)
                 while chunk:
                     object_content += chunk
@@ -203,46 +192,18 @@ class FakeSwiftConnection(object):
         return object_checksum.hexdigest()
 
     def post_object(self, container, name, headers={}):
-        LOG.debug("fake post_object(%(container)s, %(name)s, %(head)s)",
+        LOG.debug(_("fake post_object(%(container)s, %(name)s, %(head)s)") %
                   {'container': container, 'name': name, 'head': str(headers)})
 
     def delete_object(self, container, name):
-        LOG.debug("fake delete_object(%(container)s, %(name)s)",
+        LOG.debug(_("fake delete_object(%(container)s, %(name)s)") %
                   {'container': container, 'name': name})
         if container == 'socket_error_on_delete':
             raise socket.error(111, 'ECONNREFUSED')
         pass
 
 
-class Patcher(object):
-    """Objects that need to mock global symbols throughout their existence
-    should extend this base class.
-    The object acts as a context manager which, when used in conjunction with
-    the 'with' statement, terminates all running patchers when it leaves the
-    scope.
-    """
-
-    def __init__(self):
-        self.__patchers = None
-
-    def __enter__(self):
-        self.__patchers = []
-        return self
-
-    def __exit__(self, type, value, traceback):
-        # Stop patchers in the LIFO order.
-        while self.__patchers:
-            self.__patchers.pop().stop()
-
-    def _start_patcher(self, patcher):
-        """All patchers started by this method will be automatically
-        terminated on __exit__().
-        """
-        self.__patchers.append(patcher)
-        return patcher.start()
-
-
-class SwiftClientStub(Patcher):
+class SwiftClientStub(object):
     """
     Component for controlling behavior of Swift Client Stub.  Instantiated
     before tests are invoked in "fake" mode.  Invoke methods to control
@@ -296,7 +257,6 @@ class SwiftClientStub(Patcher):
     """
 
     def __init__(self):
-        super(SwiftClientStub, self).__init__()
         self._connection = swift_client.Connection()
         self._containers = {}
         self._containers_list = []
@@ -336,26 +296,18 @@ class SwiftClientStub(Patcher):
                      'content-type': 'application/json; charset=utf-8',
                      'x-account-object-count': '0'}, self._containers_list)
 
-        get_auth_return_value = (
-            "http://127.0.0.1:8080/v1/AUTH_c7b038976df24d96bf1980f5da17bd89",
-            'MIINrwYJKoZIhvcNAQcCoIINoDCCDZwCAQExCTAHBgUrDgMCGjCCDIgGCSqGSIb3'
-            'DQEHAaCCDHkEggx1eyJhY2Nlc3MiOiB7InRva2VuIjogeyJpc3N1ZWRfYXQiOiAi'
-            'MjAxMy0wMy0xOFQxODoxMzoyMC41OTMyNzYiLCAiZXhwaXJlcyI6ICIyMDEzLTAz'
-            'LTE5VDE4OjEzOjIwWiIsICJpZCI6ICJwbGFjZWhvbGRlciIsICJ0ZW5hbnQiOiB7'
-            'ImVuYWJsZWQiOiB0cnVlLCAiZGVzY3JpcHRpb24iOiBudWxsLCAibmFtZSI6ICJy'
-            'ZWRkd2FyZiIsICJpZCI6ICJjN2IwMzg5NzZkZjI0ZDk2YmYxOTgwZjVkYTE3YmQ4'
-            'OSJ9fSwgInNlcnZpY2VDYXRhbG9nIjogW3siZW5kcG9pbnRzIjogW3siYWRtaW5')
-
-        get_auth_patcher = patch.object(
-            swift_client.Connection, 'get_auth',
-            MagicMock(return_value=get_auth_return_value))
-        self._start_patcher(get_auth_patcher)
-
-        get_account_patcher = patch.object(
-            swift_client.Connection, 'get_account',
-            MagicMock(return_value=account_resp()))
-        self._start_patcher(get_account_patcher)
-
+        swift_client.Connection.get_auth = MagicMock(return_value=(
+            u"http://127.0.0.1:8080/v1/AUTH_c7b038976df24d96bf1980f5da17bd89",
+            u'MIINrwYJKoZIhvcNAQcCoIINoDCCDZwCAQExCTAHBgUrDgMCGjCCDIgGCSqGSIb3'
+            u'DQEHAaCCDHkEggx1eyJhY2Nlc3MiOiB7InRva2VuIjogeyJpc3N1ZWRfYXQiOiAi'
+            u'MjAxMy0wMy0xOFQxODoxMzoyMC41OTMyNzYiLCAiZXhwaXJlcyI6ICIyMDEzLTAz'
+            u'LTE5VDE4OjEzOjIwWiIsICJpZCI6ICJwbGFjZWhvbGRlciIsICJ0ZW5hbnQiOiB7'
+            u'ImVuYWJsZWQiOiB0cnVlLCAiZGVzY3JpcHRpb24iOiBudWxsLCAibmFtZSI6ICJy'
+            u'ZWRkd2FyZiIsICJpZCI6ICJjN2IwMzg5NzZkZjI0ZDk2YmYxOTgwZjVkYTE3YmQ4'
+            u'OSJ9fSwgInNlcnZpY2VDYXRhbG9nIjogW3siZW5kcG9pbnRzIjogW3siYWRtaW5')
+        )
+        swift_client.Connection.get_account = MagicMock(
+            return_value=account_resp())
         return self
 
     def _create_container(self, container_name):
@@ -399,9 +351,7 @@ class SwiftClientStub(Patcher):
                     self._objects[container])
 
         # if this is called multiple times then nothing happens
-        put_container_patcher = patch.object(swift_client.Connection,
-                                             'put_container')
-        self._start_patcher(put_container_patcher)
+        swift_client.Connection.put_container = MagicMock(return_value=None)
 
         def side_effect_func(*args, **kwargs):
             if args[0] in self._containers:
@@ -412,10 +362,8 @@ class SwiftClientStub(Patcher):
 
         self._create_container(container_name)
         # return container headers
-        get_container_patcher = patch.object(
-            swift_client.Connection, 'get_container',
-            MagicMock(side_effect=side_effect_func))
-        self._start_patcher(get_container_patcher)
+        swift_client.Connection.get_container = MagicMock(
+            side_effect=side_effect_func)
 
         return self
 
@@ -463,10 +411,8 @@ class SwiftClientStub(Patcher):
         :param contents: the contents of the object
         """
 
-        put_object_patcher = patch.object(
-            swift_client.Connection, 'put_object',
-            MagicMock(return_value=uuid.uuid1()))
-        self._start_patcher(put_object_patcher)
+        swift_client.Connection.put_object = MagicMock(
+            return_value=uuid.uuid1())
 
         def side_effect_func(*args, **kwargs):
             if (args[0] in self._containers and
@@ -486,10 +432,8 @@ class SwiftClientStub(Patcher):
                 raise swiftclient.ClientException('Resource Not Found',
                                                   http_status=404)
 
-        get_object_patcher = patch.object(
-            swift_client.Connection, 'get_object',
-            MagicMock(side_effect=side_effect_func))
-        self._start_patcher(get_object_patcher)
+        swift_client.Connection.get_object = MagicMock(
+            side_effect=side_effect_func)
 
         self._remove_object(name, self._objects[container])
         self._objects[container].append(
@@ -527,10 +471,8 @@ class SwiftClientStub(Patcher):
             else:
                 return None
 
-        delete_object_patcher = patch.object(
-            swift_client.Connection, 'delete_object',
-            MagicMock(side_effect=side_effect_func))
-        self._start_patcher(delete_object_patcher)
+        swift_client.Connection.delete_object = MagicMock(
+            side_effect=side_effect_func)
 
         self._remove_object(name, self._objects[container])
         return self
