@@ -17,52 +17,48 @@
 Tests dealing with HTTP rate-limiting.
 """
 
-
-import io
-from http import client as http_client
-from unittest.mock import Mock, MagicMock, patch
-from oslo_serialization import jsonutils
+import httplib
+import StringIO
+from trove.quota.models import Quota
+import testtools
 import webob
 
+from mock import Mock, MagicMock
 from trove.common import limits
 from trove.common.limits import Limit
-from trove.limits.service import LimitsController
 from trove.limits import views
-from trove.quota.models import Quota
+from trove.limits.service import LimitsController
+from trove.openstack.common import jsonutils
 from trove.quota.quota import QUOTAS
-from trove.tests.unittests import trove_testtools
 
 TEST_LIMITS = [
     Limit("GET", "/delayed", "^/delayed", 1, limits.PER_MINUTE),
     Limit("POST", "*", ".*", 7, limits.PER_MINUTE),
-    Limit("POST", "/mgmt", "^/mgmt", 3, limits.PER_MINUTE),
     Limit("PUT", "*", "", 10, limits.PER_MINUTE),
 ]
 
 
-class BaseLimitTestSuite(trove_testtools.TestCase):
+class BaseLimitTestSuite(testtools.TestCase):
     """Base test suite which provides relevant stubs and time abstraction."""
 
     def setUp(self):
         super(BaseLimitTestSuite, self).setUp()
-        self.context = trove_testtools.TroveTestContext(self)
         self.absolute_limits = {"max_instances": 55,
                                 "max_volumes": 100,
-                                "max_ram": 200,
                                 "max_backups": 40}
 
 
 class LimitsControllerTest(BaseLimitTestSuite):
-
     def setUp(self):
         super(LimitsControllerTest, self).setUp()
 
-    @patch.object(QUOTAS, 'get_all_quotas_by_tenant', return_value={})
-    def test_limit_index_empty(self, quotas_mock):
+    def test_limit_index_empty(self):
         limit_controller = LimitsController()
 
         req = MagicMock()
-        req.environ = {'trove.context': self.context}
+        req.environ = {}
+
+        QUOTAS.get_all_quotas_by_tenant = MagicMock(return_value={})
 
         view = limit_controller.index(req, "test_tenant_id")
         expected = {'limits': [{'verb': 'ABSOLUTE'}]}
@@ -115,10 +111,6 @@ class LimitsControllerTest(BaseLimitTestSuite):
                                          resource="instances",
                                          hard_limit=100),
 
-                      "ram": Quota(tenant_id=tenant_id,
-                                   resource="ram",
-                                   hard_limit=200),
-
                       "backups": Quota(tenant_id=tenant_id,
                                        resource="backups",
                                        hard_limit=40),
@@ -128,66 +120,64 @@ class LimitsControllerTest(BaseLimitTestSuite):
                                        hard_limit=55)}
 
         req = MagicMock()
-        req.environ = {"trove.limits": limits, 'trove.context': self.context}
+        req.environ = {"trove.limits": limits}
 
-        with patch.object(QUOTAS, 'get_all_quotas_by_tenant',
-                          return_value=abs_limits):
+        QUOTAS.get_all_quotas_by_tenant = MagicMock(return_value=abs_limits)
 
-            view = limit_controller.index(req, tenant_id)
+        view = limit_controller.index(req, tenant_id)
 
-            expected = {
-                'limits': [
-                    {
-                        'max_instances': 100,
-                        'max_backups': 40,
-                        'max_ram': 200,
-                        'verb': 'ABSOLUTE',
-                        'max_volumes': 55
-                    },
-                    {
-                        'regex': '.*',
-                        'nextAvailable': '2011-07-21T18:17:06Z',
-                        'uri': '*',
-                        'value': 10,
-                        'verb': 'POST',
-                        'remaining': 2,
-                        'unit': 'MINUTE'
-                    },
-                    {
-                        'regex': '.*',
-                        'nextAvailable': '2011-07-21T18:17:06Z',
-                        'uri': '*',
-                        'value': 10,
-                        'verb': 'PUT',
-                        'remaining': 2,
-                        'unit': 'MINUTE'
-                    },
-                    {
-                        'regex': '.*',
-                        'nextAvailable': '2011-07-21T18:17:06Z',
-                        'uri': '*',
-                        'value': 10,
-                        'verb': 'DELETE',
-                        'remaining': 2,
-                        'unit': 'MINUTE'
-                    },
-                    {
-                        'regex': '.*',
-                        'nextAvailable': '2011-07-21T18:17:06Z',
-                        'uri': '*',
-                        'value': 10,
-                        'verb': 'GET',
-                        'remaining': 2,
-                        'unit': 'MINUTE'
-                    }
-                ]
-            }
+        expected = {
+            'limits': [
+                {
+                    'max_instances': 100,
+                    'max_backups': 40,
+                    'verb': 'ABSOLUTE',
+                    'max_volumes': 55
+                },
+                {
+                    'regex': '.*',
+                    'nextAvailable': '2011-07-21T18:17:06Z',
+                    'uri': '*',
+                    'value': 10,
+                    'verb': 'POST',
+                    'remaining': 2,
+                    'unit': 'MINUTE'
+                },
+                {
+                    'regex': '.*',
+                    'nextAvailable': '2011-07-21T18:17:06Z',
+                    'uri': '*',
+                    'value': 10,
+                    'verb': 'PUT',
+                    'remaining': 2,
+                    'unit': 'MINUTE'
+                },
+                {
+                    'regex': '.*',
+                    'nextAvailable': '2011-07-21T18:17:06Z',
+                    'uri': '*',
+                    'value': 10,
+                    'verb': 'DELETE',
+                    'remaining': 2,
+                    'unit': 'MINUTE'
+                },
+                {
+                    'regex': '.*',
+                    'nextAvailable': '2011-07-21T18:17:06Z',
+                    'uri': '*',
+                    'value': 10,
+                    'verb': 'GET',
+                    'remaining': 2,
+                    'unit': 'MINUTE'
+                }
+            ]
+        }
 
-            self.assertEqual(expected, view._data)
+        self.assertEqual(expected, view._data)
 
 
 class TestLimiter(limits.Limiter):
-    """Note: This was taken from Nova."""
+    """Note: This was taken from Nova"""
     pass
 
 
@@ -227,20 +217,20 @@ class LimitMiddlewareTest(BaseLimitTestSuite):
 
         request = webob.Request.blank("/")
         response = request.get_response(self.app)
-        self.assertEqual(413, response.status_int)
+        self.assertEqual(response.status_int, 413)
 
-        self.assertIn('Retry-After', response.headers)
+        self.assertTrue('Retry-After' in response.headers)
         retry_after = int(response.headers['Retry-After'])
         self.assertAlmostEqual(retry_after, 60, 1)
 
         body = jsonutils.loads(response.body)
         expected = "Only 1 GET request(s) can be made to * every minute."
         value = body["overLimit"]["details"].strip()
-        self.assertEqual(expected, value)
+        self.assertEqual(value, expected)
 
-        self.assertIn("retryAfter", body["overLimit"])
+        self.assertTrue("retryAfter" in body["overLimit"])
         retryAfter = body["overLimit"]["retryAfter"]
-        self.assertEqual("60", retryAfter)
+        self.assertEqual(retryAfter, "60")
 
 
 class LimitTest(BaseLimitTestSuite):
@@ -254,7 +244,7 @@ class LimitTest(BaseLimitTestSuite):
 
         limit._get_time = MagicMock(return_value=0.0)
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
         self.assertEqual(0, limit.next_request)
         self.assertEqual(0, limit.last_request)
 
@@ -264,7 +254,7 @@ class LimitTest(BaseLimitTestSuite):
         limit._get_time = MagicMock(return_value=0.0)
 
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
 
         delay = limit("GET", "/anything")
         self.assertEqual(1, delay)
@@ -274,7 +264,7 @@ class LimitTest(BaseLimitTestSuite):
         limit._get_time = MagicMock(return_value=4.0)
 
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
         self.assertEqual(4, limit.next_request)
         self.assertEqual(4, limit.last_request)
 
@@ -313,38 +303,36 @@ class ParseLimitsTest(BaseLimitTestSuite):
     def test_multiple_rules(self):
         # Test that parse_limits() handles multiple rules correctly.
         try:
-            result = limits.Limiter.parse_limits(
-                '(get, *, .*, 20, minute);'
-                '(PUT, /foo*, /foo.*, 10, hour);'
-                '(POST, /bar*, /bar.*, 5, second);'
-                '(Say, /derp*, /derp.*, 1, day)'
-            )
+            l = limits.Limiter.parse_limits('(get, *, .*, 20, minute);'
+                                            '(PUT, /foo*, /foo.*, 10, hour);'
+                                            '(POST, /bar*, /bar.*, 5, second);'
+                                            '(Say, /derp*, /derp.*, 1, day)')
         except ValueError as e:
             assert False, str(e)
 
         # Make sure the number of returned limits are correct
-        self.assertEqual(4, len(result))
+        self.assertEqual(len(l), 4)
 
         # Check all the verbs...
         expected = ['GET', 'PUT', 'POST', 'SAY']
-        self.assertEqual(expected, [t.verb for t in result])
+        self.assertEqual([t.verb for t in l], expected)
 
         # ...the URIs...
         expected = ['*', '/foo*', '/bar*', '/derp*']
-        self.assertEqual(expected, [t.uri for t in result])
+        self.assertEqual([t.uri for t in l], expected)
 
         # ...the regexes...
         expected = ['.*', '/foo.*', '/bar.*', '/derp.*']
-        self.assertEqual(expected, [t.regex for t in result])
+        self.assertEqual([t.regex for t in l], expected)
 
         # ...the values...
         expected = [20, 10, 5, 1]
-        self.assertEqual(expected, [t.value for t in result])
+        self.assertEqual([t.value for t in l], expected)
 
         # ...and the units...
         expected = [limits.PER_MINUTE, limits.PER_HOUR,
                     limits.PER_SECOND, limits.PER_DAY]
-        self.assertEqual(expected, [t.unit for t in result])
+        self.assertEqual([t.unit for t in l], expected)
 
 
 class LimiterTest(BaseLimitTestSuite):
@@ -366,7 +354,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def _check(self, num, verb, url, username=None):
         """Check and yield results from checks."""
-        for x in range(num):
+        for x in xrange(num):
             yield self.limiter.check_for_delay(verb, url, username)[0]
 
     def _check_sum(self, num, verb, url, username=None):
@@ -380,17 +368,17 @@ class LimiterTest(BaseLimitTestSuite):
         didn"t set.
         """
         delay = self.limiter.check_for_delay("GET", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_no_delay_PUT(self):
         # Simple test to ensure no delay on a single call for a known limit.
         delay = self.limiter.check_for_delay("PUT", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_delay_PUT(self):
         """
         Ensure the 11th PUT will result in a delay of 6.0 seconds until
-        the next request will be granted.
+        the next request will be granced.
         """
         expected = [None] * 10 + [6.0]
         results = list(self._check(11, "PUT", "/anything"))
@@ -400,7 +388,7 @@ class LimiterTest(BaseLimitTestSuite):
     def test_delay_POST(self):
         """
         Ensure the 8th POST will result in a delay of 6.0 seconds until
-        the next request will be granted.
+        the next request will be granced.
         """
         expected = [None] * 7
         results = list(self._check(7, "POST", "/anything"))
@@ -410,23 +398,10 @@ class LimiterTest(BaseLimitTestSuite):
         results = self._check_sum(1, "POST", "/anything")
         self.assertAlmostEqual(expected, results, 8)
 
-    def test_delay_POST_mgmt(self):
-        """
-        Ensure the 4th mgmt POST will result in a delay of 6.0 seconds until
-        the next request will be granted.
-        """
-        expected = [None] * 3
-        results = list(self._check(3, "POST", "/mgmt"))
-        self.assertEqual(expected, results)
-
-        expected = 60.0 / 3.0
-        results = self._check_sum(1, "POST", "/mgmt")
-        self.assertAlmostEqual(expected, results, 4)
-
     def test_delay_GET(self):
         # Ensure the 11th GET will result in NO delay.
         expected = [None] * 11
-        results = list(self._check(11, "GET", "/mgmt"))
+        results = list(self._check(11, "GET", "/anything"))
 
         self.assertEqual(expected, results)
 
@@ -460,7 +435,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def test_user_limit(self):
         # Test user-specific limits.
-        self.assertEqual([], self.limiter.levels['user3'])
+        self.assertEqual(self.limiter.levels['user3'], [])
 
     def test_multiple_users(self):
         # Tests involving multiple users.
@@ -505,7 +480,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
     def _request_data(self, verb, path):
         """Get data describing a limit request verb/path."""
-        return jsonutils.dump_as_bytes({"verb": verb, "path": path})
+        return jsonutils.dumps({"verb": verb, "path": path})
 
     def _request(self, verb, url, username=None):
         """Make sure that POSTing to the given url causes the given username
@@ -522,39 +497,39 @@ class WsgiLimiterTest(BaseLimitTestSuite):
         response = request.get_response(self.app)
 
         if "X-Wait-Seconds" in response.headers:
-            self.assertEqual(403, response.status_int)
+            self.assertEqual(response.status_int, 403)
             return response.headers["X-Wait-Seconds"]
 
-        self.assertEqual(204, response.status_int)
+        self.assertEqual(response.status_int, 204)
 
     def test_invalid_methods(self):
         # Only POSTs should work.
         for method in ["GET", "PUT", "DELETE", "HEAD", "OPTIONS"]:
             request = webob.Request.blank("/", method=method)
             response = request.get_response(self.app)
-            self.assertEqual(405, response.status_int)
+            self.assertEqual(response.status_int, 405)
 
     def test_good_url(self):
         delay = self._request("GET", "/something")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
     def test_escaping(self):
         delay = self._request("GET", "/something/jump%20up")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
     def test_response_to_delays(self):
         delay = self._request("GET", "/delayed")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed")
         self.assertAlmostEqual(float(delay), 60, 1)
 
     def test_response_to_delays_usernames(self):
         delay = self._request("GET", "/delayed", "user1")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed", "user2")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed", "user1")
         self.assertAlmostEqual(float(delay), 60, 1)
@@ -565,21 +540,21 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
 class FakeHttplibSocket(object):
     """
-    Fake `http_client.HTTPResponse` replacement.
+    Fake `httplib.HTTPResponse` replacement.
     """
 
     def __init__(self, response_string):
         """Initialize new `FakeHttplibSocket`."""
-        self._buffer = io.BytesIO(response_string)
+        self._buffer = StringIO.StringIO(response_string)
 
-    def makefile(self, _mode, *args):
+    def makefile(self, _mode, _other):
         """Returns the socket's internal buffer."""
         return self._buffer
 
 
 class FakeHttplibConnection(object):
     """
-    Fake `http_client.HTTPConnection`.
+    Fake `httplib.HTTPConnection`.
     """
 
     def __init__(self, app, host):
@@ -589,11 +564,11 @@ class FakeHttplibConnection(object):
         self.app = app
         self.host = host
 
-    def request(self, method, path, body=b"", headers=None):
+    def request(self, method, path, body="", headers=None):
         """
         Requests made via this connection actually get translated and routed
         into our WSGI app, we then wait for the response and turn it back into
-        an `http_client.HTTPResponse`.
+        an `httplib.HTTPResponse`.
         """
         if not headers:
             headers = {}
@@ -606,9 +581,8 @@ class FakeHttplibConnection(object):
 
         resp = str(req.get_response(self.app))
         resp = "HTTP/1.0 %s" % resp
-        resp = resp.encode("utf-8")
         sock = FakeHttplibSocket(resp)
-        self.http_response = http_client.HTTPResponse(sock)
+        self.http_response = httplib.HTTPResponse(sock)
         self.http_response.begin()
 
     def getresponse(self):
@@ -622,7 +596,7 @@ def wire_HTTPConnection_to_WSGI(host, app):
 
     After calling this method, when any code calls
 
-    http_client.HTTPConnection(host)
+    httplib.HTTPConnection(host)
 
     the connection object will be a fake.  Its requests will be sent directly
     to the given WSGI app rather than through a socket.
@@ -650,9 +624,8 @@ def wire_HTTPConnection_to_WSGI(host, app):
             else:
                 return self.wrapped(connection_host, *args, **kwargs)
 
-    oldHTTPConnection = http_client.HTTPConnection
-    http_client.HTTPConnection = HTTPConnectionDecorator(
-        http_client.HTTPConnection)
+    oldHTTPConnection = httplib.HTTPConnection
+    httplib.HTTPConnection = HTTPConnectionDecorator(httplib.HTTPConnection)
     return oldHTTPConnection
 
 
@@ -664,7 +637,7 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
     def setUp(self):
         """
         Do some nifty HTTP/WSGI magic which allows for WSGI to be called
-        directly by something like the `http_client` library.
+        directly by something like the `httplib` library.
         """
         super(WsgiLimiterProxyTest, self).setUp()
         self.app = limits.WsgiLimiter(TEST_LIMITS)
@@ -675,28 +648,27 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
     def test_200(self):
         # Successful request test.
         delay = self.proxy.check_for_delay("GET", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_403(self):
         # Forbidden request test.
         delay = self.proxy.check_for_delay("GET", "/delayed")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
         delay, error = self.proxy.check_for_delay("GET", "/delayed")
         error = error.strip()
 
         self.assertAlmostEqual(float(delay), 60, 1)
-        self.assertEqual(b"403 Forbidden\n\nOnly 1 GET request(s) can be"
-                         b" made to /delayed every minute.", error)
+        self.assertEqual(error, "403 Forbidden\n\nOnly 1 GET request(s) can be"
+                                " made to /delayed every minute.")
 
     def tearDown(self):
         # restore original HTTPConnection object
-        http_client.HTTPConnection = self.oldHTTPConnection
+        httplib.HTTPConnection = self.oldHTTPConnection
         super(WsgiLimiterProxyTest, self).tearDown()
 
 
-class LimitsViewTest(trove_testtools.TestCase):
-
+class LimitsViewTest(testtools.TestCase):
     def setUp(self):
         super(LimitsViewTest, self).setUp()
 
@@ -748,8 +720,7 @@ class LimitsViewTest(trove_testtools.TestCase):
         self.assertEqual(expected, data)
 
 
-class LimitsViewsTest(trove_testtools.TestCase):
-
+class LimitsViewsTest(testtools.TestCase):
     def setUp(self):
         super(LimitsViewsTest, self).setUp()
 
@@ -804,7 +775,7 @@ class LimitsViewsTest(trove_testtools.TestCase):
                 "resetTime": 1311272226
             }
         ]
-        abs_view = {"instances": 55, "volumes": 100, "backups": 40, 'ram': 200}
+        abs_view = {"instances": 55, "volumes": 100, "backups": 40}
 
         view_data = views.LimitViews(abs_view, rate_limits)
         self.assertIsNotNone(view_data)
@@ -812,7 +783,6 @@ class LimitsViewsTest(trove_testtools.TestCase):
         data = view_data.data()
         expected = {'limits': [{'max_instances': 55,
                                 'max_backups': 40,
-                                'max_ram': 200,
                                 'verb': 'ABSOLUTE',
                                 'max_volumes': 100},
                                {'regex': '.*',
