@@ -13,18 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from unittest.mock import Mock, patch
-from testtools.matchers import Equals, Is, Not
-import webob.exc
-
-from trove.common import base_wsgi
-from trove.common import exception
-from trove.common import wsgi
-from trove.tests.unittests import trove_testtools
+import trove.common.wsgi as wsgi
 import webob
 
+import testtools
+from testtools.matchers import Equals, Is, Not
 
-class TestWsgi(trove_testtools.TestCase):
+
+class TestWsgi(testtools.TestCase):
     def test_process_request(self):
         middleware = wsgi.ContextMiddleware("test_trove")
         req = webob.BaseRequest({})
@@ -33,8 +29,7 @@ class TestWsgi(trove_testtools.TestCase):
         req.headers = {
             'X-User': 'do not use - deprecated',
             'X-User-ID': user_id,
-            'X-Auth-Token': token,
-            'X-Service-Catalog': '[]'
+            'X-Auth-Token': token
         }
         req.environ = {}
         # invocation
@@ -44,19 +39,3 @@ class TestWsgi(trove_testtools.TestCase):
         self.assertThat(ctx, Not(Is(None)))
         self.assertThat(ctx.user, Equals(user_id))
         self.assertThat(ctx.auth_token, Equals(token))
-        self.assertEqual(0, len(ctx.service_catalog))
-
-
-class TestController(trove_testtools.TestCase):
-
-    @patch.object(base_wsgi.Resource, 'execute_action',
-                  side_effect=exception.RootHistoryNotFound())
-    @patch.object(wsgi.Controller, 'delete', create=True)
-    @patch.object(wsgi.Controller, 'validate_request')
-    def test_exception_root_history_notfound(self, *args):
-        controller = wsgi.Controller()
-        resource = controller.create_resource()
-        req = Mock()
-        result = resource.execute_action('delete', req)
-        self.assertIsInstance(result.wrapped_exc,
-                              webob.exc.HTTPNotFound)
