@@ -11,19 +11,16 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import testtools
+from designateclient.v1.domains import Domain
+from designateclient.v1.records import Record
+from trove.dns.designate import driver
+from mock import MagicMock
 import base64
 import hashlib
 
-from designateclient.v1.domains import Domain
-from designateclient.v1.records import Record
-from mock import MagicMock
-from mock import patch
 
-from trove.dns.designate import driver
-from trove.tests.unittests import trove_testtools
-
-
-class DesignateObjectConverterTest(trove_testtools.TestCase):
+class DesignateObjectConverterTest(testtools.TestCase):
 
     def setUp(self):
         super(DesignateObjectConverterTest, self).setUp()
@@ -63,7 +60,7 @@ class DesignateObjectConverterTest(trove_testtools.TestCase):
         self.assertEqual(zone, converted_record.dns_zone)
 
 
-class DesignateDriverTest(trove_testtools.TestCase):
+class DesignateDriverTest(testtools.TestCase):
 
     def setUp(self):
         super(DesignateDriverTest, self).setUp()
@@ -82,97 +79,97 @@ class DesignateDriverTest(trove_testtools.TestCase):
                                ttl=1800, priority=2),
                         Record(name='record3', type='A', data='10.0.0.3',
                                ttl=3600, priority=1)]
-        self.create_des_client_patch = patch.object(
-            driver, 'create_designate_client', MagicMock(return_value=None))
-        self.create_des_client_mock = self.create_des_client_patch.start()
-        self.addCleanup(self.create_des_client_patch.stop)
 
     def tearDown(self):
         super(DesignateDriverTest, self).tearDown()
 
     def test_get_entries_by_name(self):
         zone = driver.DesignateDnsZone('123', 'www.example.com')
-        with patch.object(driver.DesignateDriver, '_get_records',
-                          MagicMock(return_value=self.records)):
-            dns_driver = driver.DesignateDriver()
-            entries = dns_driver.get_entries_by_name('record2', zone)
-            self.assertEqual(1, len(entries), 'More than one record found')
-            entry = entries[0]
-            self.assertEqual('record2', entry.name)
-            self.assertEqual('CNAME', entry.type)
-            self.assertEqual('10.0.0.2', entry.content)
-            self.assertEqual(1800, entry.ttl)
-            self.assertEqual(2, entry.priority)
-            zone = entry.dns_zone
-            self.assertEqual('123', zone.id)
-            self.assertEqual('www.example.com', zone.name)
+        driver.create_designate_client = MagicMock(return_value=None)
+        driver.DesignateDriver._get_records = MagicMock(
+            return_value=self.records)
+        dns_driver = driver.DesignateDriver()
+        entries = dns_driver.get_entries_by_name('record2', zone)
+        self.assertTrue(len(entries) == 1, 'More than one record found')
+        entry = entries[0]
+        self.assertEqual('record2', entry.name)
+        self.assertEqual('CNAME', entry.type)
+        self.assertEqual('10.0.0.2', entry.content)
+        self.assertEqual(1800, entry.ttl)
+        self.assertEqual(2, entry.priority)
+        zone = entry.dns_zone
+        self.assertEqual('123', zone.id)
+        self.assertEqual('www.example.com', zone.name)
 
     def test_get_entries_by_name_not_found(self):
         zone = driver.DesignateDnsZone('123', 'www.example.com')
-        with patch.object(driver.DesignateDriver, '_get_records',
-                          MagicMock(return_value=self.records)):
-            dns_driver = driver.DesignateDriver()
-            entries = dns_driver.get_entries_by_name('record_not_found', zone)
-            self.assertEqual(0, len(entries), 'Some records were returned')
+        driver.create_designate_client = MagicMock(return_value=None)
+        driver.DesignateDriver._get_records = MagicMock(
+            return_value=self.records)
+        dns_driver = driver.DesignateDriver()
+        entries = dns_driver.get_entries_by_name('record_not_found', zone)
+        self.assertTrue(len(entries) == 0, 'Some records were returned')
 
     def test_get_entries_by_content(self):
         zone = driver.DesignateDnsZone('123', 'www.example.com')
-        with patch.object(driver.DesignateDriver, '_get_records',
-                          MagicMock(return_value=self.records)):
-            dns_driver = driver.DesignateDriver()
-            entries = dns_driver.get_entries_by_content('10.0.0.1', zone)
-            self.assertEqual(1, len(entries), 'More than one record found')
-            entry = entries[0]
-            self.assertEqual('record1', entry.name)
-            self.assertEqual('A', entry.type)
-            self.assertEqual('10.0.0.1', entry.content)
-            self.assertEqual(3600, entry.ttl)
-            self.assertEqual(1, entry.priority)
-            zone = entry.dns_zone
-            self.assertEqual('123', zone.id)
-            self.assertEqual('www.example.com', zone.name)
+        driver.create_designate_client = MagicMock(return_value=None)
+        driver.DesignateDriver._get_records = MagicMock(
+            return_value=self.records)
+        dns_driver = driver.DesignateDriver()
+        entries = dns_driver.get_entries_by_content('10.0.0.1', zone)
+        self.assertTrue(len(entries) == 1, 'More than one record found')
+        entry = entries[0]
+        self.assertEqual('record1', entry.name)
+        self.assertEqual('A', entry.type)
+        self.assertEqual('10.0.0.1', entry.content)
+        self.assertEqual(3600, entry.ttl)
+        self.assertEqual(1, entry.priority)
+        zone = entry.dns_zone
+        self.assertEqual('123', zone.id)
+        self.assertEqual('www.example.com', zone.name)
 
     def test_get_entries_by_content_not_found(self):
         zone = driver.DesignateDnsZone('123', 'www.example.com')
-        with patch.object(driver.DesignateDriver, '_get_records',
-                          MagicMock(return_value=self.records)):
-            dns_driver = driver.DesignateDriver()
-            entries = dns_driver.get_entries_by_content('127.0.0.1', zone)
-            self.assertEqual(0, len(entries), 'Some records were returned')
+        driver.create_designate_client = MagicMock(return_value=None)
+        driver.DesignateDriver._get_records = MagicMock(
+            return_value=self.records)
+        dns_driver = driver.DesignateDriver()
+        entries = dns_driver.get_entries_by_content('127.0.0.1', zone)
+        self.assertTrue(len(entries) == 0, 'Some records were returned')
 
     def test_get_dnz_zones(self):
         client = MagicMock()
-        self.create_des_client_mock.return_value = client
+        driver.create_designate_client = MagicMock(return_value=client)
         client.domains.list = MagicMock(return_value=self.domains)
         dns_driver = driver.DesignateDriver()
         zones = dns_driver.get_dns_zones()
-        self.assertEqual(3, len(zones))
+        self.assertTrue(len(zones) == 3)
         for x in range(0, 3):
             self.assertDomainsAreEqual(self.domains[x], zones[x])
 
     def test_get_dnz_zones_by_name(self):
         client = MagicMock()
-        self.create_des_client_mock.return_value = client
+        driver.create_designate_client = MagicMock(return_value=client)
         client.domains.list = MagicMock(return_value=self.domains)
         dns_driver = driver.DesignateDriver()
         zones = dns_driver.get_dns_zones('www.trove.com')
-        self.assertEqual(1, len(zones))
+        self.assertTrue(len(zones) == 1)
         self.assertDomainsAreEqual(self.domains[1], zones[0])
 
     def test_get_dnz_zones_not_found(self):
         client = MagicMock()
-        self.create_des_client_mock.return_value = client
+        driver.create_designate_client = MagicMock(return_value=client)
         client.domains.list = MagicMock(return_value=self.domains)
         dns_driver = driver.DesignateDriver()
         zones = dns_driver.get_dns_zones('www.notfound.com')
-        self.assertEqual(0, len(zones))
+        self.assertTrue(len(zones) == 0)
 
     def assertDomainsAreEqual(self, expected, actual):
         self.assertEqual(expected.name, actual.name)
         self.assertEqual(expected.id, actual.id)
 
 
-class DesignateInstanceEntryFactoryTest(trove_testtools.TestCase):
+class DesignateInstanceEntryFactoryTest(testtools.TestCase):
 
     def setUp(self):
         super(DesignateInstanceEntryFactoryTest, self).setUp()
