@@ -12,23 +12,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import testtools
+from mock import Mock, MagicMock
+from trove.guestagent import models
+from trove.common import utils
+from trove.db.sqlalchemy import api as dbapi
+from trove.db import models as dbmodels
 from datetime import datetime
 
-from mock import Mock, MagicMock, patch
 
-from trove.common import timeutils
-from trove.common import utils
-from trove.db import models as dbmodels
-from trove.db.sqlalchemy import api as dbapi
-from trove.guestagent import models
-from trove.tests.unittests import trove_testtools
-
-
-class AgentHeartBeatTest(trove_testtools.TestCase):
+class AgentHeartBeatTest(testtools.TestCase):
     def setUp(self):
         super(AgentHeartBeatTest, self).setUp()
         self.origin_get_db_api = dbmodels.get_db_api
-        self.origin_utcnow = timeutils.utcnow
+        self.origin_utcnow = utils.utcnow
+        self.origin_DatabaseModelBase = dbmodels.DatabaseModelBase
         self.origin_db_api_save = dbapi.save
         self.origin_is_valid = dbmodels.DatabaseModelBase.is_valid
         self.origin_generate_uuid = utils.generate_uuid
@@ -36,7 +34,8 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
     def tearDown(self):
         super(AgentHeartBeatTest, self).tearDown()
         dbmodels.get_db_api = self.origin_get_db_api
-        timeutils.utcnow = self.origin_utcnow
+        utils.utcnow = self.origin_utcnow
+        dbmodels.DatabaseModelBase = self.origin_DatabaseModelBase
         dbapi.save = self.origin_db_api_save
         dbmodels.DatabaseModelBase.is_valid = self.origin_is_valid
         utils.generate_uuid = self.origin_generate_uuid
@@ -51,16 +50,16 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         self.assertEqual(3,
                          dbmodels.DatabaseModelBase.is_valid.call_count)
 
-    @patch('trove.db.models.DatabaseModelBase')
-    def test_save(self, dmb_mock):
-        timeutils.utcnow = Mock()
+    def test_save(self):
+        utils.utcnow = Mock()
+        dbmodels.DatabaseModelBase = Mock
         dbmodels.get_db_api = MagicMock(
             return_value=dbmodels.DatabaseModelBase)
         dbapi.save = Mock()
         dbmodels.DatabaseModelBase.is_valid = Mock(return_value=True)
         self.heartBeat = models.AgentHeartBeat()
         self.heartBeat.save()
-        self.assertEqual(1, timeutils.utcnow.call_count)
+        self.assertEqual(1, utils.utcnow.call_count)
 
     def test_is_active(self):
         models.AGENT_HEARTBEAT = 10000000000
