@@ -12,20 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from mock import Mock
-from mock import patch
+import testtools
+from mock import Mock, MagicMock
 from trove.guestagent import service
-from trove.tests.unittests import trove_testtools
 
 
-class ServiceTest(trove_testtools.TestCase):
+class ServiceTest(testtools.TestCase):
     def setUp(self):
         super(ServiceTest, self).setUp()
 
     def tearDown(self):
         super(ServiceTest, self).tearDown()
 
-    @patch.object(service.API, '_instance_router')
-    def test_app_factory(self, instance_router_mock):
+    def test_app_factory(self):
+        service.API._instance_router = MagicMock()
         service.app_factory(Mock)
-        self.assertEqual(1, instance_router_mock.call_count)
+        self.assertEqual(1, service.API._instance_router.call_count)
