@@ -12,17 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from testtools.matchers import Equals
+from testtools import TestCase
 from testtools.matchers import Is
-from trove.common.exception import DatabaseForUserNotInDatabaseListError
+from testtools.matchers import Equals
 from trove.common.exception import DatabaseInitialDatabaseDuplicateError
+from trove.common.exception import DatabaseForUserNotInDatabaseListError
 from trove.common.exception import DatabaseInitialUserDuplicateError
-from trove.extensions.mysql.common import populate_users
 from trove.extensions.mysql.common import populate_validated_databases
-from trove.tests.unittests import trove_testtools
+from trove.extensions.mysql.common import populate_users
 
 
-class MySqlCommonTest(trove_testtools.TestCase):
+class MySqlCommonTest(TestCase):
 
     def setUp(self):
         super(MySqlCommonTest, self).setUp()
@@ -81,18 +81,10 @@ class MySqlCommonTest(trove_testtools.TestCase):
         self.assertRaises(DatabaseInitialUserDuplicateError,
                           populate_users, users)
 
-    def test_populate_unique_users_unique_host(self):
-        users = [{'name': 'bob', 'password': 'x', 'host': '127.0.0.1'},
-                 {'name': 'tom', 'password': 'x', 'host': '128.0.0.1'}]
-        result = populate_users(users)
-        self.assertThat(len(result), Is(2))
-
     def test_populate_users_intermingled(self):
         users = [{'name': 'bob', 'password': 'x', 'host': '127.0.0.1'},
-                 {'name': 'tom', 'password': 'y', 'host': '127.0.0.1'},
-                 {'name': 'bob', 'password': 'z', 'host': '127.0.0.1'},
-                 {'name': 'bob', 'password': 'x', 'host': '128.0.0.1'},
-                 {'name': 'tom', 'password': 'x', 'host': '128.0.0.1'}]
+                 {'name': 'tom', 'password': 'y', 'host': '128.0.0.1'},
+                 {'name': 'bob', 'password': 'z', 'host': '127.0.0.1'}]
         self.assertRaises(DatabaseInitialUserDuplicateError,
                           populate_users, users)
 
