@@ -11,39 +11,34 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from unittest.mock import Mock, MagicMock, patch
-from testtools import skipIf
-
-from trove.common import cfg
-from trove.common import exception
-from trove.db.models import DatabaseModelBase
-from trove.extensions.mgmt.quota.service import QuotaController
+import testtools
+from mock import Mock, MagicMock, patch
+from trove.quota.quota import DbQuotaDriver
+from trove.quota.models import Resource
 from trove.quota.models import Quota
 from trove.quota.models import QuotaUsage
 from trove.quota.models import Reservation
-from trove.quota.models import Resource
-from trove.quota.quota import DbQuotaDriver
-from trove.quota.quota import QUOTAS
+from trove.db.models import DatabaseModelBase
+from trove.extensions.mgmt.quota.service import QuotaController
+from trove.common import exception
+from trove.common import cfg
 from trove.quota.quota import run_with_quotas
-from trove.tests.unittests import trove_testtools
+from trove.quota.quota import QUOTAS
 """
 Unit tests for the classes and functions in DbQuotaDriver.py.
 """
 
 CONF = cfg.CONF
 resources = {
-
-    Resource.INSTANCES: Resource(Resource.INSTANCES,
-                                 'max_instances_per_tenant'),
-    Resource.VOLUMES: Resource(Resource.VOLUMES, 'max_volumes_per_tenant')
+    Resource.INSTANCES: Resource(Resource.INSTANCES, 'max_instances_per_user'),
+    Resource.VOLUMES: Resource(Resource.VOLUMES, 'max_volumes_per_user'),
 }
 
 FAKE_TENANT1 = "123456"
 FAKE_TENANT2 = "654321"
 
 
-class Run_with_quotasTest(trove_testtools.TestCase):
+class Run_with_quotasTest(testtools.TestCase):
 
     def setUp(self):
         super(Run_with_quotasTest, self).setUp()
@@ -82,7 +77,7 @@ class Run_with_quotasTest(trove_testtools.TestCase):
         self.assertTrue(f.called)
 
 
-class QuotaControllerTest(trove_testtools.TestCase):
+class QuotaControllerTest(testtools.TestCase):
 
     def setUp(self):
         super(QuotaControllerTest, self).setUp()
@@ -109,7 +104,7 @@ class QuotaControllerTest(trove_testtools.TestCase):
             body = {'quotas': {'instances': None}}
             result = self.controller.update(self.req, body, FAKE_TENANT1,
                                             FAKE_TENANT2)
-            self.assertEqual(0, quota.save.call_count)
+            self.assertEqual(quota.save.call_count, 0)
             self.assertEqual(200, result.status)
 
     def test_update_resource_instance(self):
@@ -119,12 +114,13 @@ class QuotaControllerTest(trove_testtools.TestCase):
             body = {'quotas': {'instances': 2}}
             result = self.controller.update(self.req, body, FAKE_TENANT1,
                                             FAKE_TENANT2)
-            self.assertEqual(1, instance_quota.save.call_count)
-            self.assertIn('instances', result._data['quotas'])
+            self.assertEqual(instance_quota.save.call_count, 1)
+            self.assertTrue('instances' in result._data['quotas'])
             self.assertEqual(200, result.status)
             self.assertEqual(2, result._data['quotas']['instances'])
 
-    @skipIf(not CONF.trove_volume_support, 'Volume support is not enabled')
+    @testtools.skipIf(not CONF.trove_volume_support,
+                      'Volume support is not enabled')
     def test_update_resource_volume(self):
         instance_quota = MagicMock(spec=Quota)
         volume_quota = MagicMock(spec=Quota)
@@ -138,23 +134,14 @@ class QuotaControllerTest(trove_testtools.TestCase):
             body = {'quotas': {'instances': None, 'volumes': 10}}
             result = self.controller.update(self.req, body, FAKE_TENANT1,
                                             FAKE_TENANT2)
-            self.assertEqual(0, instance_quota.save.call_count)
-            self.assertNotIn('instances', result._data['quotas'])
-            self.assertEqual(1, volume_quota.save.call_count)
+            self.assertEqual(instance_quota.save.call_count, 0)
+            self.assertFalse('instances' in result._data['quotas'])
+            self.assertEqual(volume_quota.save.call_count, 1)
             self.assertEqual(200, result.status)
             self.assertEqual(10, result._data['quotas']['volumes'])
 
-    def test_update_resource_with_invalid_negative_number(self):
-        quota = MagicMock(spec=Quota)
-        with patch.object(DatabaseModelBase, 'find_by', return_value=quota):
-            body = {'quotas': {'instances': -2}}
-            self.assertRaises(exception.QuotaLimitTooSmall,
-                              self.controller.update,
-                              self.req, body, FAKE_TENANT1,
-                              FAKE_TENANT2)
 
-
-class DbQuotaDriverTest(trove_testtools.TestCase):
+class DbQuotaDriverTest(testtools.TestCase):
 
     def setUp(self):
 
@@ -184,10 +171,9 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
 
     def test_get_defaults(self):
         defaults = self.driver.get_defaults(resources)
-
-        self.assertEqual(CONF.max_instances_per_tenant,
+        self.assertEqual(CONF.max_instances_per_user,
                          defaults[Resource.INSTANCES])
-        self.assertEqual(CONF.max_volumes_per_tenant,
+        self.assertEqual(CONF.max_volumes_per_user,
                          defaults[Resource.VOLUMES])
 
     def test_get_quota_by_tenant(self):
@@ -214,7 +200,7 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
 
         self.assertEqual(FAKE_TENANT1, quota.tenant_id)
         self.assertEqual(Resource.VOLUMES, quota.resource)
-        self.assertEqual(CONF.max_volumes_per_tenant, quota.hard_limit)
+        self.assertEqual(CONF.max_volumes_per_user, quota.hard_limit)
 
     def test_get_all_quotas_by_tenant(self):
 
@@ -248,12 +234,11 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.assertEqual(FAKE_TENANT1, quotas[Resource.INSTANCES].tenant_id)
         self.assertEqual(Resource.INSTANCES,
                          quotas[Resource.INSTANCES].resource)
-
-        self.assertEqual(CONF.max_instances_per_tenant,
+        self.assertEqual(CONF.max_instances_per_user,
                          quotas[Resource.INSTANCES].hard_limit)
         self.assertEqual(FAKE_TENANT1, quotas[Resource.VOLUMES].tenant_id)
         self.assertEqual(Resource.VOLUMES, quotas[Resource.VOLUMES].resource)
-        self.assertEqual(CONF.max_volumes_per_tenant,
+        self.assertEqual(CONF.max_volumes_per_user,
                          quotas[Resource.VOLUMES].hard_limit)
 
     def test_get_all_quotas_by_tenant_with_one_default(self):
@@ -273,7 +258,7 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.assertEqual(22, quotas[Resource.INSTANCES].hard_limit)
         self.assertEqual(FAKE_TENANT1, quotas[Resource.VOLUMES].tenant_id)
         self.assertEqual(Resource.VOLUMES, quotas[Resource.VOLUMES].resource)
-        self.assertEqual(CONF.max_volumes_per_tenant,
+        self.assertEqual(CONF.max_volumes_per_user,
                          quotas[Resource.VOLUMES].hard_limit)
 
     def test_get_quota_usage_by_tenant(self):
@@ -395,34 +380,6 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.assertEqual(0, usages[Resource.VOLUMES].in_use)
         self.assertEqual(0, usages[Resource.VOLUMES].reserved)
 
-    def test_check_quota_with_unlimited_quota(self):
-
-        FAKE_QUOTA_USAGE = [QuotaUsage(id=1,
-                                       tenant_id=FAKE_TENANT1,
-                                       resource=Resource.INSTANCES,
-                                       in_use=1,
-                                       reserved=2),
-                            QuotaUsage(id=2,
-                                       tenant_id=FAKE_TENANT1,
-                                       resource=Resource.VOLUMES,
-                                       in_use=1,
-                                       reserved=1)]
-        FAKE_QUOTAS = [Quota(tenant_id=FAKE_TENANT1,
-                             resource=Resource.INSTANCES,
-                             hard_limit=-1),
-                       Quota(tenant_id=FAKE_TENANT1,
-                             resource=Resource.VOLUMES,
-                             hard_limit=-1)]
-
-        self.mock_quota_result.all = Mock(return_value=FAKE_QUOTAS)
-        self.mock_usage_result.all = Mock(return_value=FAKE_QUOTA_USAGE)
-        QuotaUsage.save = Mock()
-        Reservation.create = Mock()
-
-        delta = {'instances': 2, 'volumes': 3}
-        self.assertIsNone(self.driver.check_quotas(FAKE_TENANT1, resources,
-                                                   delta))
-
     def test_reserve(self):
 
         FAKE_QUOTAS = [QuotaUsage(id=1,
@@ -441,14 +398,16 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         QuotaUsage.save = Mock()
         Reservation.create = Mock()
 
-        # Set up the deltas with the intention that after the reserve call
-        # the deltas should match usage_id + 1 for both instances and volumes
         delta = {'instances': 2, 'volumes': 3}
         self.driver.reserve(FAKE_TENANT1, resources, delta)
-
-        for _, kw in Reservation.create.call_args_list:
-            self.assertEqual(kw['usage_id'] + 1, kw['delta'])
-            self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
+        _, kw = Reservation.create.call_args_list[0]
+        self.assertEqual(1, kw['usage_id'])
+        self.assertEqual(2, kw['delta'])
+        self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
+        _, kw = Reservation.create.call_args_list[1]
+        self.assertEqual(2, kw['usage_id'])
+        self.assertEqual(3, kw['delta'])
+        self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
 
     def test_reserve_resource_unknown(self):
 
@@ -475,7 +434,7 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.mock_quota_result.all = Mock(return_value=[])
         self.mock_usage_result.all = Mock(return_value=FAKE_QUOTAS)
 
-        delta = {'instances': 1, 'volumes': CONF.max_volumes_per_tenant + 1}
+        delta = {'instances': 1, 'volumes': CONF.max_volumes_per_user + 1}
         self.assertRaises(exception.QuotaExceeded,
                           self.driver.reserve,
                           FAKE_TENANT1,
@@ -498,8 +457,7 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.mock_quota_result.all = Mock(return_value=[])
         self.mock_usage_result.all = Mock(return_value=FAKE_QUOTAS)
 
-        max_inst = CONF.max_instances_per_tenant
-        delta = {'instances': max_inst, 'volumes': 3}
+        delta = {'instances': 5, 'volumes': 3}
         self.assertRaises(exception.QuotaExceeded,
                           self.driver.reserve,
                           FAKE_TENANT1,
@@ -522,8 +480,7 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         self.mock_quota_result.all = Mock(return_value=[])
         self.mock_usage_result.all = Mock(return_value=FAKE_QUOTAS)
 
-        max_inst = CONF.max_instances_per_tenant
-        delta = {'instances': max_inst - 1, 'volumes': 2}
+        delta = {'instances': 4, 'volumes': 2}
         self.assertRaises(exception.QuotaExceeded,
                           self.driver.reserve,
                           FAKE_TENANT1,
@@ -549,14 +506,16 @@ class DbQuotaDriverTest(trove_testtools.TestCase):
         QuotaUsage.save = Mock()
         Reservation.create = Mock()
 
-        # Set up the deltas with the intention that after the reserve call
-        # the deltas should match -usage_id for both instances and volumes
-        delta = {'instances': -1, 'volumes': -2}
+        delta = {'instances': -1, 'volumes': -3}
         self.driver.reserve(FAKE_TENANT1, resources, delta)
-
-        for _, kw in Reservation.create.call_args_list:
-            self.assertEqual(-kw['usage_id'], kw['delta'])
-            self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
+        _, kw = Reservation.create.call_args_list[0]
+        self.assertEqual(1, kw['usage_id'])
+        self.assertEqual(-1, kw['delta'])
+        self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
+        _, kw = Reservation.create.call_args_list[1]
+        self.assertEqual(2, kw['usage_id'])
+        self.assertEqual(-3, kw['delta'])
+        self.assertEqual(Reservation.Statuses.RESERVED, kw['status'])
 
     def test_commit(self):
 
