@@ -16,12 +16,11 @@
 """Like asserts, but does not raise an exception until the end of a block."""
 
 import traceback
-
+from proboscis.asserts import ASSERTION_ERROR
 from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_false
 from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_true
-from proboscis.asserts import ASSERTION_ERROR
 from proboscis.asserts import Check
 
 
@@ -39,7 +38,7 @@ def get_stack_trace_of_caller(level_up):
 def raise_blame_caller(level_up, ex):
     """Raises an exception, changing the stack trace to point to the caller."""
     new_st = get_stack_trace_of_caller(level_up + 2)
-    raise ex.with_traceback(new_st)
+    raise type(ex), ex, new_st
 
 
 class Checker(object):
@@ -69,7 +68,7 @@ class Checker(object):
         self._run_assertion(assert_false, *args, **kwargs)
 
     def not_equal(self, *args, **kwargs):
-        self._run_assertion(assert_not_equal, *args, **kwargs)
+        _run_assertion(assert_not_equal, *args, **kwargs)
 
     def _run_assertion(self, assert_func, *args, **kwargs):
         """
@@ -112,16 +111,16 @@ class AttrCheck(Check):
     def fail(self, msg):
         self.true(False, msg)
 
-    def contains_allowed_attrs(self, list, allowed_attrs, msg=None):
+    def attrs_exist(self, list, expected_attrs, msg=None):
         # Check these attrs only are returned in create response
         for attr in list:
-            if attr not in allowed_attrs:
+            if attr not in expected_attrs:
                 self.fail("%s should not contain '%s'" % (msg, attr))
 
     def links(self, links):
-        allowed_attrs = ['href', 'rel']
+        expected_attrs = ['href', 'rel']
         for link in links:
-            self.contains_allowed_attrs(link, allowed_attrs, msg="Links")
+            self.attrs_exist(link, expected_attrs, msg="Links")
 
 
 class CollectionCheck(Check):
@@ -171,10 +170,10 @@ class TypeCheck(Check):
         self.instance = instance
         super(TypeCheck, self).__init__()
 
-    def _check_type(self, value, attribute_type):
+    def _check_type(value, attribute_type):
         if not isinstance(value, attribute_type):
             self.fail("%s attribute %s is of type %s (expected %s)."
-                      % (self.name, self.attribute_name, type(value),
+                      % (self.name, attribute_name, type(value),
                          attribute_type))
 
     def has_field(self, attribute_name, attribute_type,
