@@ -15,12 +15,11 @@
 
 from collections import defaultdict
 
-from oslo_log import log as logging
-import proboscis.asserts as asserts
-from proboscis.dependencies import SkipTest
-
+import trove.openstack.common.log as logging
 from trove.common import utils
 from trove.tests.config import CONFIG
+import proboscis.asserts as asserts
+from proboscis.dependencies import SkipTest
 
 LOG = logging.getLogger(__name__)
 MESSAGE_QUEUE = defaultdict(list)
@@ -71,14 +70,14 @@ class FakeVerifier(object):
         pass
 
 
-def notify(event_type, payload):
+def notify(context, message):
     """Simple test notify function which saves the messages to global list."""
-    payload['event_type'] = event_type
-    if 'instance_id' in payload and 'server_type' not in payload:
-        LOG.debug('Received Usage Notification: %s' % event_type)
-        resource_id = payload['instance_id']
-        global MESSAGE_QUEUE
-        MESSAGE_QUEUE[resource_id].append(payload)
-        LOG.debug('Message Queue for %(id)s now has %(msg_count)d messages' %
-                  {'id': resource_id,
-                   'msg_count': len(MESSAGE_QUEUE[resource_id])})
+    LOG.debug(_('Received Usage Notification: %s') % message)
+    payload = message.get('payload', None)
+    payload['event_type'] = message['event_type']
+    resource_id = payload['instance_id']
+    global MESSAGE_QUEUE
+    MESSAGE_QUEUE[resource_id].append(payload)
+    LOG.debug(_('Message Queue for %(id)s now has %(msg_count)d messages') %
+              {'id': resource_id,
+               'msg_count': len(MESSAGE_QUEUE[resource_id])})
